Package io.vertx.rxjava3.cassandra
Class CassandraClient
java.lang.Object
io.vertx.rxjava3.cassandra.CassandraClient
- All Implemented Interfaces:
RxDelegate
Eclipse Vert.x Cassandra client.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final TypeArg<CassandraClient>static final StringThe default shared client name. -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionio.reactivex.rxjava3.core.Completableclose()Closes this client.static CassandraClientcreate(io.vertx.rxjava3.core.Vertx vertx) Likecreate(io.vertx.rxjava3.core.Vertx)with default options.static CassandraClientcreate(io.vertx.rxjava3.core.Vertx vertx, CassandraClientOptions options) Create a Cassandra client which maintains its own driver session.static CassandraClientcreateShared(io.vertx.rxjava3.core.Vertx vertx) LikecreateShared(io.vertx.rxjava3.core.Vertx)with default options and client name.static CassandraClientcreateShared(io.vertx.rxjava3.core.Vertx vertx, CassandraClientOptions options) LikecreateShared(io.vertx.rxjava3.core.Vertx)with default client name.static CassandraClientcreateShared(io.vertx.rxjava3.core.Vertx vertx, String clientName) LikecreateShared(io.vertx.rxjava3.core.Vertx)with default options.static CassandraClientcreateShared(io.vertx.rxjava3.core.Vertx vertx, String clientName, CassandraClientOptions options) Create a Cassandra client that shares its driver session with any other client having the same name.booleanio.reactivex.rxjava3.core.Single<ResultSet>execute(com.datastax.oss.driver.api.core.cql.Statement statement) Execute the statement and provide a handler for consuming results.io.reactivex.rxjava3.core.Single<ResultSet>Execute the query and provide a handler for consuming results.io.reactivex.rxjava3.core.Single<List<com.datastax.oss.driver.api.core.cql.Row>>executeWithFullFetch(com.datastax.oss.driver.api.core.cql.Statement statement) Execute the query and provide a handler for consuming results.io.reactivex.rxjava3.core.Single<List<com.datastax.oss.driver.api.core.cql.Row>>executeWithFullFetch(String query) Execute the query and provide a handler for consuming results.inthashCode()booleanio.reactivex.rxjava3.core.Single<com.datastax.oss.driver.api.core.metadata.Metadata>metadata()Get for the session.static CassandraClientio.reactivex.rxjava3.core.Single<com.datastax.oss.driver.api.core.cql.PreparedStatement>prepare(com.datastax.oss.driver.api.core.cql.SimpleStatement statement) Prepares the provided a .io.reactivex.rxjava3.core.Single<com.datastax.oss.driver.api.core.cql.PreparedStatement>Prepares the provided query string.io.reactivex.rxjava3.core.Single<CassandraRowStream>queryStream(com.datastax.oss.driver.api.core.cql.Statement statement) Executes the given SQL statement which returns the results of the query as a read stream.io.reactivex.rxjava3.core.Single<CassandraRowStream>queryStream(String sql) Executes the given SQLSELECTstatement which returns the results of the query as a read stream.io.reactivex.rxjava3.core.CompletablerxClose()Closes this client.io.reactivex.rxjava3.core.Single<ResultSet>rxExecute(com.datastax.oss.driver.api.core.cql.Statement statement) Execute the statement and provide a handler for consuming results.io.reactivex.rxjava3.core.Single<ResultSet>Execute the query and provide a handler for consuming results.io.reactivex.rxjava3.core.Single<List<com.datastax.oss.driver.api.core.cql.Row>>rxExecuteWithFullFetch(com.datastax.oss.driver.api.core.cql.Statement statement) Execute the query and provide a handler for consuming results.io.reactivex.rxjava3.core.Single<List<com.datastax.oss.driver.api.core.cql.Row>>rxExecuteWithFullFetch(String query) Execute the query and provide a handler for consuming results.io.reactivex.rxjava3.core.Single<com.datastax.oss.driver.api.core.metadata.Metadata>Get for the session.io.reactivex.rxjava3.core.Single<com.datastax.oss.driver.api.core.cql.PreparedStatement>rxPrepare(com.datastax.oss.driver.api.core.cql.SimpleStatement statement) Prepares the provided a .io.reactivex.rxjava3.core.Single<com.datastax.oss.driver.api.core.cql.PreparedStatement>Prepares the provided query string.io.reactivex.rxjava3.core.Single<CassandraRowStream>rxQueryStream(com.datastax.oss.driver.api.core.cql.Statement statement) Executes the given SQL statement which returns the results of the query as a read stream.io.reactivex.rxjava3.core.Single<CassandraRowStream>rxQueryStream(String sql) Executes the given SQLSELECTstatement which returns the results of the query as a read stream.toString()
-
Field Details
-
__TYPE_ARG
-
DEFAULT_SHARED_CLIENT_NAME
The default shared client name.- See Also:
-
-
Constructor Details
-
CassandraClient
-
CassandraClient
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
create
Likecreate(io.vertx.rxjava3.core.Vertx)with default options.- Parameters:
vertx-- Returns:
-
create
public static CassandraClient create(io.vertx.rxjava3.core.Vertx vertx, CassandraClientOptions options) Create a Cassandra client which maintains its own driver session.It is not recommended to create several non shared clients in an application.
- Parameters:
vertx- the Vert.x instanceoptions- the options- Returns:
- the client
-
isConnected
public boolean isConnected()- Returns:
- whether this Cassandra client instance is connected
-
execute
Execute the query and provide a handler for consuming results.- Parameters:
query- the query to execute- Returns:
- a future of the result
-
rxExecute
Execute the query and provide a handler for consuming results.- Parameters:
query- the query to execute- Returns:
- a future of the result
-
queryStream
Executes the given SQLSELECTstatement which returns the results of the query as a read stream.- Parameters:
sql- the SQL to execute. For exampleSELECT * FROM table ....- Returns:
- a future of the result
-
rxQueryStream
Executes the given SQLSELECTstatement which returns the results of the query as a read stream.- Parameters:
sql- the SQL to execute. For exampleSELECT * FROM table ....- Returns:
- a future of the result
-
close
public io.reactivex.rxjava3.core.Completable close()Closes this client.- Returns:
- a future of the result
-
rxClose
public io.reactivex.rxjava3.core.Completable rxClose()Closes this client.- Returns:
- a future of the result
-
executeWithFullFetch
public io.reactivex.rxjava3.core.Single<List<com.datastax.oss.driver.api.core.cql.Row>> executeWithFullFetch(String query) Execute the query and provide a handler for consuming results.- Parameters:
query- the query to execute- Returns:
- a future of the result
-
rxExecuteWithFullFetch
public io.reactivex.rxjava3.core.Single<List<com.datastax.oss.driver.api.core.cql.Row>> rxExecuteWithFullFetch(String query) Execute the query and provide a handler for consuming results.- Parameters:
query- the query to execute- Returns:
- a future of the result
-
executeWithFullFetch
public io.reactivex.rxjava3.core.Single<List<com.datastax.oss.driver.api.core.cql.Row>> executeWithFullFetch(com.datastax.oss.driver.api.core.cql.Statement statement) Execute the query and provide a handler for consuming results.- Parameters:
statement- the statement to execute- Returns:
- a future of the result
-
rxExecuteWithFullFetch
public io.reactivex.rxjava3.core.Single<List<com.datastax.oss.driver.api.core.cql.Row>> rxExecuteWithFullFetch(com.datastax.oss.driver.api.core.cql.Statement statement) Execute the query and provide a handler for consuming results.- Parameters:
statement- the statement to execute- Returns:
- a future of the result
-
execute
public io.reactivex.rxjava3.core.Single<ResultSet> execute(com.datastax.oss.driver.api.core.cql.Statement statement) Execute the statement and provide a handler for consuming results.- Parameters:
statement- the statement to execute- Returns:
- a future of the result
-
rxExecute
public io.reactivex.rxjava3.core.Single<ResultSet> rxExecute(com.datastax.oss.driver.api.core.cql.Statement statement) Execute the statement and provide a handler for consuming results.- Parameters:
statement- the statement to execute- Returns:
- a future of the result
-
prepare
public io.reactivex.rxjava3.core.Single<com.datastax.oss.driver.api.core.cql.PreparedStatement> prepare(String query) Prepares the provided query string.- Parameters:
query- the query to prepare- Returns:
- a future of the result
-
rxPrepare
public io.reactivex.rxjava3.core.Single<com.datastax.oss.driver.api.core.cql.PreparedStatement> rxPrepare(String query) Prepares the provided query string.- Parameters:
query- the query to prepare- Returns:
- a future of the result
-
prepare
public io.reactivex.rxjava3.core.Single<com.datastax.oss.driver.api.core.cql.PreparedStatement> prepare(com.datastax.oss.driver.api.core.cql.SimpleStatement statement) Prepares the provided a .- Parameters:
statement- the statement to prepare- Returns:
- a future of the result
-
rxPrepare
public io.reactivex.rxjava3.core.Single<com.datastax.oss.driver.api.core.cql.PreparedStatement> rxPrepare(com.datastax.oss.driver.api.core.cql.SimpleStatement statement) Prepares the provided a .- Parameters:
statement- the statement to prepare- Returns:
- a future of the result
-
queryStream
public io.reactivex.rxjava3.core.Single<CassandraRowStream> queryStream(com.datastax.oss.driver.api.core.cql.Statement statement) Executes the given SQL statement which returns the results of the query as a read stream.- Parameters:
statement- the statement to execute.- Returns:
- a future of the result
-
rxQueryStream
public io.reactivex.rxjava3.core.Single<CassandraRowStream> rxQueryStream(com.datastax.oss.driver.api.core.cql.Statement statement) Executes the given SQL statement which returns the results of the query as a read stream.- Parameters:
statement- the statement to execute.- Returns:
- a future of the result
-
metadata
public io.reactivex.rxjava3.core.Single<com.datastax.oss.driver.api.core.metadata.Metadata> metadata()Get for the session.- Returns:
- a future of the result
-
rxMetadata
public io.reactivex.rxjava3.core.Single<com.datastax.oss.driver.api.core.metadata.Metadata> rxMetadata()Get for the session.- Returns:
- a future of the result
-
newInstance
-