Package io.vertx.rxjava3.cassandra
Class CassandraRowStream
java.lang.Object
io.vertx.rxjava3.cassandra.CassandraRowStream
- All Implemented Interfaces:
RxDelegate,ReadStream<com.datastax.oss.driver.api.core.cql.Row>,StreamBase
public class CassandraRowStream
extends Object
implements RxDelegate, ReadStream<com.datastax.oss.driver.api.core.cql.Row>
A for consumption.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
ConstructorsConstructorDescriptionCassandraRowStream(CassandraRowStream delegate) CassandraRowStream(Object delegate) -
Method Summary
Modifier and TypeMethodDescriptioncom.datastax.oss.driver.api.core.cql.ColumnDefinitionsGet the provided by the backingResultSetfor this stream.endHandler(Handler<Void> handler) Set an end handler.booleanexceptionHandler(Handler<Throwable> handler) Set an exception handler on the read stream.com.datastax.oss.driver.api.core.cql.ExecutionInfoGet the provided by the backingResultSetfor this stream.fetch(long l) Fetch the specifiedamountof elements.Set a data handler.inthashCode()static CassandraRowStreampause()Pause theReadStream, it sets the buffer infetchmode and clears the actual demand.Pipe<com.datastax.oss.driver.api.core.cql.Row>pipe()Pause this stream and return a to transfer the elements of this stream to a destination .io.reactivex.rxjava3.core.CompletablepipeTo(WriteStream<com.datastax.oss.driver.api.core.cql.Row> dst) Pipe thisReadStreamto theWriteStream.resume()Resume reading, and sets the buffer inflowingmode.io.reactivex.rxjava3.core.CompletablerxPipeTo(WriteStream<com.datastax.oss.driver.api.core.cql.Row> dst) Pipe thisReadStreamto theWriteStream.io.reactivex.rxjava3.core.Flowable<com.datastax.oss.driver.api.core.cql.Row>io.reactivex.rxjava3.core.Observable<com.datastax.oss.driver.api.core.cql.Row>toString()
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
CassandraRowStream
-
CassandraRowStream
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceReadStream<com.datastax.oss.driver.api.core.cql.Row>- Specified by:
getDelegatein interfaceRxDelegate- Specified by:
getDelegatein interfaceStreamBase
-
toObservable
public io.reactivex.rxjava3.core.Observable<com.datastax.oss.driver.api.core.cql.Row> toObservable()- Specified by:
toObservablein interfaceReadStream<com.datastax.oss.driver.api.core.cql.Row>
-
toFlowable
public io.reactivex.rxjava3.core.Flowable<com.datastax.oss.driver.api.core.cql.Row> toFlowable()- Specified by:
toFlowablein interfaceReadStream<com.datastax.oss.driver.api.core.cql.Row>
-
pipe
Pause this stream and return a to transfer the elements of this stream to a destination . The stream will be resumed when the pipe will be wired to aWriteStream.- Specified by:
pipein interfaceReadStream<com.datastax.oss.driver.api.core.cql.Row>- Returns:
- a pipe
-
exceptionHandler
Description copied from interface:ReadStreamSet an exception handler on the read stream.- Specified by:
exceptionHandlerin interfaceReadStream<com.datastax.oss.driver.api.core.cql.Row>- Specified by:
exceptionHandlerin interfaceStreamBase- Parameters:
handler- the exception handler- Returns:
- a reference to this, so the API can be used fluently
-
pause
Description copied from interface:ReadStreamPause theReadStream, it sets the buffer infetchmode and clears the actual demand.While it's paused, no data will be sent to the data
handler.- Specified by:
pausein interfaceReadStream<com.datastax.oss.driver.api.core.cql.Row>- Returns:
- a reference to this, so the API can be used fluently
-
resume
Description copied from interface:ReadStreamResume reading, and sets the buffer inflowingmode. If theReadStreamhas been paused, reading will recommence on it.- Specified by:
resumein interfaceReadStream<com.datastax.oss.driver.api.core.cql.Row>- Returns:
- a reference to this, so the API can be used fluently
-
endHandler
Description copied from interface:ReadStreamSet an end handler. Once the stream has ended, and there is no more data to be read, this handler will be called.- Specified by:
endHandlerin interfaceReadStream<com.datastax.oss.driver.api.core.cql.Row>- Returns:
- a reference to this, so the API can be used fluently
-
fetch
Description copied from interface:ReadStreamFetch the specifiedamountof elements. If theReadStreamhas been paused, reading will recommence with the specifiedamountof items, otherwise the specifiedamountwill be added to the current stream demand.- Specified by:
fetchin interfaceReadStream<com.datastax.oss.driver.api.core.cql.Row>- Returns:
- a reference to this, so the API can be used fluently
-
handler
Description copied from interface:ReadStreamSet a data handler. As data is read, the handler will be called with the data.- Specified by:
handlerin interfaceReadStream<com.datastax.oss.driver.api.core.cql.Row>- Returns:
- a reference to this, so the API can be used fluently
-
pipeTo
public io.reactivex.rxjava3.core.Completable pipeTo(WriteStream<com.datastax.oss.driver.api.core.cql.Row> dst) Description copied from interface:ReadStreamPipe thisReadStreamto theWriteStream.Elements emitted by this stream will be written to the write stream until this stream ends or fails.
- Specified by:
pipeToin interfaceReadStream<com.datastax.oss.driver.api.core.cql.Row>- Parameters:
dst- the destination write stream- Returns:
- a future notified when the write stream will be ended with the outcome
-
rxPipeTo
public io.reactivex.rxjava3.core.Completable rxPipeTo(WriteStream<com.datastax.oss.driver.api.core.cql.Row> dst) Description copied from interface:ReadStreamPipe thisReadStreamto theWriteStream.Elements emitted by this stream will be written to the write stream until this stream ends or fails.
- Specified by:
rxPipeToin interfaceReadStream<com.datastax.oss.driver.api.core.cql.Row>- Parameters:
dst- the destination write stream- Returns:
- a future notified when the write stream will be ended with the outcome
-
executionInfo
public com.datastax.oss.driver.api.core.cql.ExecutionInfo executionInfo()Get the provided by the backingResultSetfor this stream.- Returns:
-
columnDefinitions
public com.datastax.oss.driver.api.core.cql.ColumnDefinitions columnDefinitions()Get the provided by the backingResultSetfor this stream.- Returns:
-
newInstance
-