Package io.vertx.rxjava3.cassandra
Class ResultSet
java.lang.Object
io.vertx.rxjava3.cassandra.ResultSet
- All Implemented Interfaces:
RxDelegate
It is like
AsyncResultSet, but adapted for Vert.x.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionio.reactivex.rxjava3.core.Single<List<com.datastax.oss.driver.api.core.cql.Row>>all()The method should not be used concurrently with others likefetchNextPage()orone().Iterable<com.datastax.oss.driver.api.core.cql.Row>booleanio.reactivex.rxjava3.core.Single<ResultSet>com.datastax.oss.driver.api.core.cql.ColumnDefinitionscom.datastax.oss.driver.api.core.cql.ExecutionInfointhashCode()booleanstatic ResultSetnewInstance(ResultSet arg) com.datastax.oss.driver.api.core.cql.Rowone()intio.reactivex.rxjava3.core.Single<List<com.datastax.oss.driver.api.core.cql.Row>>rxAll()The method should not be used concurrently with others likefetchNextPage()orone().io.reactivex.rxjava3.core.Single<ResultSet>toString()boolean
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
ResultSet
-
ResultSet
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
remaining
public int remaining()- Returns:
-
hasMorePages
public boolean hasMorePages()- Returns:
-
fetchNextPage
- Returns:
-
rxFetchNextPage
- Returns:
-
wasApplied
public boolean wasApplied()- Returns:
-
all
The method should not be used concurrently with others likefetchNextPage()orone(). This may lead to unexpected result.- Returns:
- a future notified all the rows are fetched
-
rxAll
The method should not be used concurrently with others likefetchNextPage()orone(). This may lead to unexpected result.- Returns:
- a future notified all the rows are fetched
-
getColumnDefinitions
public com.datastax.oss.driver.api.core.cql.ColumnDefinitions getColumnDefinitions()- Returns:
-
getExecutionInfo
public com.datastax.oss.driver.api.core.cql.ExecutionInfo getExecutionInfo()- Returns:
-
currentPage
- Returns:
-
one
public com.datastax.oss.driver.api.core.cql.Row one()- Returns:
-
newInstance
-