Uses of Class
io.vertx.rxjava3.core.file.AsyncFileLock
Packages that use AsyncFileLock
-
Uses of AsyncFileLock in io.vertx.rxjava3.core.file
Fields in io.vertx.rxjava3.core.file with type parameters of type AsyncFileLockMethods in io.vertx.rxjava3.core.file that return AsyncFileLockModifier and TypeMethodDescriptionstatic AsyncFileLockAsyncFileLock.newInstance(AsyncFileLock arg) AsyncFile.tryLock()Try to acquire a non-shared lock on the entire file.AsyncFile.tryLock(long position, long size, boolean shared) Try to acquire a lock on a portion of this file.Methods in io.vertx.rxjava3.core.file that return types with arguments of type AsyncFileLockModifier and TypeMethodDescriptionio.reactivex.rxjava3.core.Single<AsyncFileLock>AsyncFile.lock()Acquire a non-shared lock on the entire file.io.reactivex.rxjava3.core.Single<AsyncFileLock>AsyncFile.lock(long position, long size, boolean shared) Acquire a lock on a portion of this file.io.reactivex.rxjava3.core.Single<AsyncFileLock>AsyncFile.rxLock()Acquire a non-shared lock on the entire file.io.reactivex.rxjava3.core.Single<AsyncFileLock>AsyncFile.rxLock(long position, long size, boolean shared) Acquire a lock on a portion of this file.