Interface HttpClient

All Superinterfaces:
RxDelegate
All Known Implementing Classes:
HttpClientAgent, HttpClientConnection

public interface HttpClient extends RxDelegate
The API to interacts with an HTTP server.

NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.

  • Method Details

    • getDelegate

      HttpClient getDelegate()
      Specified by:
      getDelegate in interface RxDelegate
    • request

      io.reactivex.rxjava3.core.Single<HttpClientRequest> request()
      Create an HTTP request to send to the server with the default host and port of the client.
      Returns:
      a future notified when the request is ready to be sent
    • rxRequest

      io.reactivex.rxjava3.core.Single<HttpClientRequest> rxRequest()
      Create an HTTP request to send to the server with the default host and port of the client.
      Returns:
      a future notified when the request is ready to be sent
    • request

      io.reactivex.rxjava3.core.Single<HttpClientRequest> request(RequestOptions options)
      Create an HTTP request to send to the server.
      Parameters:
      options - the request options
      Returns:
      a future notified when the request is ready to be sent
    • rxRequest

      io.reactivex.rxjava3.core.Single<HttpClientRequest> rxRequest(RequestOptions options)
      Create an HTTP request to send to the server.
      Parameters:
      options - the request options
      Returns:
      a future notified when the request is ready to be sent
    • request

      io.reactivex.rxjava3.core.Single<HttpClientRequest> request(HttpMethod method, int port, String host, String requestURI)
      Create an HTTP request to send to the server at the host and port.
      Parameters:
      method - the HTTP method
      port - the port
      host - the host
      requestURI - the relative URI
      Returns:
      a future notified when the request is ready to be sent
    • rxRequest

      io.reactivex.rxjava3.core.Single<HttpClientRequest> rxRequest(HttpMethod method, int port, String host, String requestURI)
      Create an HTTP request to send to the server at the host and port.
      Parameters:
      method - the HTTP method
      port - the port
      host - the host
      requestURI - the relative URI
      Returns:
      a future notified when the request is ready to be sent
    • request

      io.reactivex.rxjava3.core.Single<HttpClientRequest> request(HttpMethod method, String host, String requestURI)
      Create an HTTP request to send to the server at the host and default port.
      Parameters:
      method - the HTTP method
      host - the host
      requestURI - the relative URI
      Returns:
      a future notified when the request is ready to be sent
    • rxRequest

      io.reactivex.rxjava3.core.Single<HttpClientRequest> rxRequest(HttpMethod method, String host, String requestURI)
      Create an HTTP request to send to the server at the host and default port.
      Parameters:
      method - the HTTP method
      host - the host
      requestURI - the relative URI
      Returns:
      a future notified when the request is ready to be sent
    • request

      io.reactivex.rxjava3.core.Single<HttpClientRequest> request(HttpMethod method, String requestURI)
      Create an HTTP request to send to the server at the default host and port.
      Parameters:
      method - the HTTP method
      requestURI - the relative URI
      Returns:
      a future notified when the request is ready to be sent
    • rxRequest

      io.reactivex.rxjava3.core.Single<HttpClientRequest> rxRequest(HttpMethod method, String requestURI)
      Create an HTTP request to send to the server at the default host and port.
      Parameters:
      method - the HTTP method
      requestURI - the relative URI
      Returns:
      a future notified when the request is ready to be sent
    • shutdown

      io.reactivex.rxjava3.core.Completable shutdown()
      Shutdown with a 30 seconds timeout (shutdown(30, TimeUnit.SECONDS)).
      Returns:
      a future completed when shutdown has completed
    • rxShutdown

      io.reactivex.rxjava3.core.Completable rxShutdown()
      Shutdown with a 30 seconds timeout (shutdown(30, TimeUnit.SECONDS)).
      Returns:
      a future completed when shutdown has completed
    • close

      io.reactivex.rxjava3.core.Completable close()
      Close immediately (shutdown(0, TimeUnit.SECONDS).
      Returns:
      a future notified when the client is closed
    • rxClose

      io.reactivex.rxjava3.core.Completable rxClose()
      Close immediately (shutdown(0, TimeUnit.SECONDS).
      Returns:
      a future notified when the client is closed
    • shutdown

      io.reactivex.rxjava3.core.Completable shutdown(long timeout, TimeUnit unit)
      Calls shutdown().
      Parameters:
      timeout -
      unit -
      Returns:
    • rxShutdown

      io.reactivex.rxjava3.core.Completable rxShutdown(long timeout, TimeUnit unit)
      Calls shutdown().
      Parameters:
      timeout -
      unit -
      Returns:
    • newInstance

      static HttpClient newInstance(HttpClient arg)