Package io.vertx.rxjava3.core.http
Interface HttpResponseHead
- All Superinterfaces:
RxDelegate
- All Known Implementing Classes:
HttpClientResponse,HttpResponse
The state of the HTTP response head:
- Status code / Message
- Headers
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Method Summary
Modifier and TypeMethodDescriptioncookies()Return the first header value with the specified nameheaders()static HttpResponseHeadintversion()
-
Method Details
-
getDelegate
HttpResponseHead getDelegate()- Specified by:
getDelegatein interfaceRxDelegate
-
version
HttpVersion version()- Returns:
- the version of the response
-
statusCode
int statusCode()- Returns:
- the status code of the response
-
statusMessage
String statusMessage()- Returns:
- the status message of the response
-
headers
MultiMap headers()- Returns:
- the headers
-
getHeader
Return the first header value with the specified name- Parameters:
headerName- the header name- Returns:
- the header value
-
cookies
- Returns:
- the Set-Cookie headers (including trailers)
-
newInstance
-