Package io.vertx.rxjava3.core.http
Class HttpServerFileUpload
java.lang.Object
io.vertx.rxjava3.core.http.HttpServerFileUpload
- All Implemented Interfaces:
RxDelegate,ReadStream<Buffer>,StreamBase
Represents an file upload from an HTML FORM.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
ConstructorsConstructorDescriptionHttpServerFileUpload(HttpServerFileUpload delegate) HttpServerFileUpload(Object delegate) -
Method Summary
Modifier and TypeMethodDescriptionbooleanTry to cancel the file system streaming, the streamed file will be deleted.charset()endHandler(Handler<Void> endHandler) Set an end handler.booleanexceptionHandler(Handler<Throwable> handler) Set an exception handler on the read stream.fetch(long amount) Fetch the specifiedamountof elements.file()filename()Set a data handler.inthashCode()booleanname()static HttpServerFileUploadpause()Pause theReadStream, it sets the buffer infetchmode and clears the actual demand.pipe()Pause this stream and return a to transfer the elements of this stream to a destination .io.reactivex.rxjava3.core.CompletablepipeTo(WriteStream<Buffer> dst) Pipe thisReadStreamto theWriteStream.resume()Resume reading, and sets the buffer inflowingmode.io.reactivex.rxjava3.core.CompletablerxPipeTo(WriteStream<Buffer> dst) Pipe thisReadStreamto theWriteStream.io.reactivex.rxjava3.core.CompletablerxStreamToFileSystem(String filename) Stream the content of this upload to the given file on storage.longsize()The size of the upload may not be available until it is all read.io.reactivex.rxjava3.core.CompletablestreamToFileSystem(String filename) Stream the content of this upload to the given file on storage.io.reactivex.rxjava3.core.Flowable<Buffer>io.reactivex.rxjava3.core.Observable<Buffer>toString()
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
HttpServerFileUpload
-
HttpServerFileUpload
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceReadStream<Buffer>- Specified by:
getDelegatein interfaceRxDelegate- Specified by:
getDelegatein interfaceStreamBase
-
toObservable
- Specified by:
toObservablein interfaceReadStream<Buffer>
-
toFlowable
- Specified by:
toFlowablein interfaceReadStream<Buffer>
-
pipe
Pause this stream and return a to transfer the elements of this stream to a destination . The stream will be resumed when the pipe will be wired to aWriteStream.- Specified by:
pipein interfaceReadStream<Buffer>- Returns:
- a pipe
-
pipeTo
Pipe thisReadStreamto theWriteStream.Elements emitted by this stream will be written to the write stream until this stream ends or fails.
- Specified by:
pipeToin interfaceReadStream<Buffer>- Parameters:
dst- the destination write stream- Returns:
- a future notified when the write stream will be ended with the outcome
-
rxPipeTo
Pipe thisReadStreamto theWriteStream.Elements emitted by this stream will be written to the write stream until this stream ends or fails.
- Specified by:
rxPipeToin interfaceReadStream<Buffer>- Parameters:
dst- the destination write stream- Returns:
- a future notified when the write stream will be ended with the outcome
-
exceptionHandler
Description copied from interface:ReadStreamSet an exception handler on the read stream.- Specified by:
exceptionHandlerin interfaceReadStream<Buffer>- Specified by:
exceptionHandlerin interfaceStreamBase- Parameters:
handler- the exception handler- Returns:
- a reference to this, so the API can be used fluently
-
handler
Description copied from interface:ReadStreamSet a data handler. As data is read, the handler will be called with the data.- Specified by:
handlerin interfaceReadStream<Buffer>- Returns:
- a reference to this, so the API can be used fluently
-
endHandler
Description copied from interface:ReadStreamSet an end handler. Once the stream has ended, and there is no more data to be read, this handler will be called.- Specified by:
endHandlerin interfaceReadStream<Buffer>- Returns:
- a reference to this, so the API can be used fluently
-
pause
Description copied from interface:ReadStreamPause theReadStream, it sets the buffer infetchmode and clears the actual demand.While it's paused, no data will be sent to the data
handler.- Specified by:
pausein interfaceReadStream<Buffer>- Returns:
- a reference to this, so the API can be used fluently
-
resume
Description copied from interface:ReadStreamResume reading, and sets the buffer inflowingmode. If theReadStreamhas been paused, reading will recommence on it.- Specified by:
resumein interfaceReadStream<Buffer>- Returns:
- a reference to this, so the API can be used fluently
-
fetch
Description copied from interface:ReadStreamFetch the specifiedamountof elements. If theReadStreamhas been paused, reading will recommence with the specifiedamountof items, otherwise the specifiedamountwill be added to the current stream demand.- Specified by:
fetchin interfaceReadStream<Buffer>- Returns:
- a reference to this, so the API can be used fluently
-
streamToFileSystem
Stream the content of this upload to the given file on storage.If the stream has a failure or is cancelled the created file will be deleted.
- Parameters:
filename- the name of the file- Returns:
-
rxStreamToFileSystem
Stream the content of this upload to the given file on storage.If the stream has a failure or is cancelled the created file will be deleted.
- Parameters:
filename- the name of the file- Returns:
-
cancelStreamToFileSystem
public boolean cancelStreamToFileSystem()Try to cancel the file system streaming, the streamed file will be deleted.- Returns:
truewhen the stream is cancelled, otherwise it means that stream is finished
-
filename
- Returns:
- the filename which was used when upload the file.
-
name
- Returns:
- the name of the attribute
-
contentType
- Returns:
- the content type for the upload
-
contentTransferEncoding
- Returns:
- the contentTransferEncoding for the upload
-
charset
- Returns:
- the charset for the upload
-
size
public long size()The size of the upload may not be available until it is all read. CheckisSizeAvailable()to determine this- Returns:
- the size of the upload (in bytes)
-
isSizeAvailable
public boolean isSizeAvailable()- Returns:
trueif the size of the upload can be retrieved viasize().
-
file
- Returns:
- the async uploaded file when
streamToFileSystem(java.lang.String)has been used and the file is available
-
newInstance
-