Uses of Class
io.vertx.rxjava3.core.http.HttpClientConnection
Packages that use HttpClientConnection
-
Uses of HttpClientConnection in io.vertx.rxjava3.core.http
Fields in io.vertx.rxjava3.core.http with type parameters of type HttpClientConnectionModifier and TypeFieldDescriptionstatic final TypeArg<HttpClientConnection>HttpClientConnection.__TYPE_ARGMethods in io.vertx.rxjava3.core.http that return HttpClientConnectionModifier and TypeMethodDescriptionstatic HttpClientConnectionHttpClientConnection.newInstance(HttpClientConnection arg) Methods in io.vertx.rxjava3.core.http that return types with arguments of type HttpClientConnectionModifier and TypeMethodDescriptionio.reactivex.rxjava3.core.Single<HttpClientConnection>HttpClientAgent.connect(HttpConnectOptions options) Connect to a remote HTTP server with the specificoptions, the connection is un-pooled and the management of the connection is left to the user.io.reactivex.rxjava3.core.Single<HttpClientConnection>HttpClientAgent.rxConnect(HttpConnectOptions options) Connect to a remote HTTP server with the specificoptions, the connection is un-pooled and the management of the connection is left to the user.