Uses of Class
io.vertx.rxjava3.core.http.HttpClientRequest
-
Packages that use HttpClientRequest Package Description io.vertx.rxjava3.core.http io.vertx.rxjava3.httpproxy -
-
Uses of HttpClientRequest in io.vertx.rxjava3.core.http
Fields in io.vertx.rxjava3.core.http with type parameters of type HttpClientRequest Modifier and Type Field Description static TypeArg<HttpClientRequest>HttpClientRequest. __TYPE_ARGMethods in io.vertx.rxjava3.core.http that return HttpClientRequest Modifier and Type Method Description HttpClientRequestHttpClientRequest. authority(HostAndPort authority)Override the request authority, when using HTTP/1.x this overrides the requesthostheader, when using HTTP/2 this sets theauthoritypseudo header.HttpClientRequestHttpClientRequest. continueHandler(Handler<Void> handler)If you send an HTTP request with the headerExpectset to the value100-continueand the server responds with an interim HTTP response with a status code of100and a Continue handler has been set using this method, then thehandlerwill be called.HttpClientRequestHttpClientRequest. drainHandler(Handler<Void> handler)HttpClientRequestHttpClientRequest. earlyHintsHandler(Handler<MultiMap> handler)If the server responds with an interim HTTP response with a status code of103and a Early Hints handler has been set using this method, then thehandlerwill be called.HttpClientRequestHttpClientRequest. exceptionHandler(Handler<Throwable> handler)HttpClientRequestHttpClientRequest. idleTimeout(long timeout)Sets the amount of time after which, if the request does not return any data within the timeout period, the request/response is closed and the related futures are failed with aTimeoutException, e.g.static HttpClientRequestHttpClientRequest. newInstance(HttpClientRequest arg)HttpClientRequestHttpClientRequest. pushHandler(Handler<HttpClientRequest> handler)Set a push handler for this request.HttpClientRequestHttpClientRequest. putHeader(CharSequence name, CharSequence value)LikeputHeader(java.lang.String, java.lang.String)but using CharSequenceHttpClientRequestHttpClientRequest. putHeader(CharSequence name, Iterable<CharSequence> values)LikeputHeader(java.lang.String, java.lang.String)but using CharSequenceHttpClientRequestHttpClientRequest. putHeader(String name, Iterable<String> values)Put an HTTP header with multiple valuesHttpClientRequestHttpClientRequest. putHeader(String name, String value)Put an HTTP headerHttpClientRequestHttpClientRequest. redirectHandler(Function<HttpClientResponse,io.reactivex.rxjava3.core.Single<HttpClientRequest>> handler)HttpClientRequestHttpClientResponse. request()HttpClientRequestHttpClientRequest. setChunked(boolean chunked)If chunked is true then the request will be set into HTTP chunked modeHttpClientRequestHttpClientRequest. setFollowRedirects(boolean followRedirects)Set the request to follow HTTP redirects up toHttpClientOptions.HttpClientRequestHttpClientRequest. setHost(String host)Deprecated.HttpClientRequestHttpClientRequest. setMaxRedirects(int maxRedirects)Set the max number of HTTP redirects this request will follow.HttpClientRequestHttpClientRequest. setMethod(HttpMethod method)Set the HTTP method for this request.HttpClientRequestHttpClientRequest. setPort(int port)Deprecated.HttpClientRequestHttpClientRequest. setStreamPriority(StreamPriority streamPriority)Sets the priority of the associated stream.HttpClientRequestHttpClientRequest. setTimeout(long timeout)Deprecated.HttpClientRequestHttpClientRequest. setURI(String uri)Set the request uri.HttpClientRequestHttpClientRequest. setWriteQueueMaxSize(int maxSize)HttpClientRequestHttpClientRequest. traceOperation(String op)Set the trace operation of this request.HttpClientRequestHttpClientRequest. writeCustomFrame(int type, int flags, Buffer payload)Write an HTTP/2 frame to the request, allowing to extend the HTTP/2 protocol.HttpClientRequestHttpClientRequest. writeCustomFrame(HttpFrame frame)LikewriteCustomFrame(int, int, io.vertx.rxjava3.core.buffer.Buffer)but with anHttpFrame.Methods in io.vertx.rxjava3.core.http that return types with arguments of type HttpClientRequest Modifier and Type Method Description io.reactivex.rxjava3.core.Single<HttpClientRequest>HttpClient. request(HttpMethod method, int port, String host, String requestURI)Create an HTTP request to send to the server at thehostandport.io.reactivex.rxjava3.core.Single<HttpClientRequest>HttpClient. request(HttpMethod method, String requestURI)Create an HTTP request to send to the server at the default host and port.io.reactivex.rxjava3.core.Single<HttpClientRequest>HttpClient. request(HttpMethod method, String host, String requestURI)Create an HTTP request to send to the server at thehostand default port.io.reactivex.rxjava3.core.Single<HttpClientRequest>HttpClient. request(RequestOptions options)Create an HTTP request to send to the server.io.reactivex.rxjava3.core.Single<HttpClientRequest>HttpClient. rxRequest(HttpMethod method, int port, String host, String requestURI)Create an HTTP request to send to the server at thehostandport.io.reactivex.rxjava3.core.Single<HttpClientRequest>HttpClient. rxRequest(HttpMethod method, String requestURI)Create an HTTP request to send to the server at the default host and port.io.reactivex.rxjava3.core.Single<HttpClientRequest>HttpClient. rxRequest(HttpMethod method, String host, String requestURI)Create an HTTP request to send to the server at thehostand default port.io.reactivex.rxjava3.core.Single<HttpClientRequest>HttpClient. rxRequest(RequestOptions options)Create an HTTP request to send to the server.Method parameters in io.vertx.rxjava3.core.http with type arguments of type HttpClientRequest Modifier and Type Method Description HttpClientRequestHttpClientRequest. pushHandler(Handler<HttpClientRequest> handler)Set a push handler for this request.HttpClientRequestHttpClientRequest. redirectHandler(Function<HttpClientResponse,io.reactivex.rxjava3.core.Single<HttpClientRequest>> handler) -
Uses of HttpClientRequest in io.vertx.rxjava3.httpproxy
Methods in io.vertx.rxjava3.httpproxy that return types with arguments of type HttpClientRequest Modifier and Type Method Description io.reactivex.rxjava3.core.Single<HttpClientRequest>OriginRequestProvider. create(ProxyContext proxyContext)Create the to the origin server for a givenProxyContext.io.reactivex.rxjava3.core.Single<HttpClientRequest>OriginRequestProvider. rxCreate(ProxyContext proxyContext)Create the to the origin server for a givenProxyContext.Methods in io.vertx.rxjava3.httpproxy with parameters of type HttpClientRequest Modifier and Type Method Description io.reactivex.rxjava3.core.CompletableProxyRequest. proxy(HttpClientRequest request)Proxy this request to the origin server using the specifiedrequestand then send the proxy response.io.reactivex.rxjava3.core.CompletableProxyRequest. rxProxy(HttpClientRequest request)Proxy this request to the origin server using the specifiedrequestand then send the proxy response.io.reactivex.rxjava3.core.Single<ProxyResponse>ProxyRequest. rxSend(HttpClientRequest request)Send this request to the origin server using the specifiedrequest.io.reactivex.rxjava3.core.Single<ProxyResponse>ProxyRequest. send(HttpClientRequest request)Send this request to the origin server using the specifiedrequest.
-