Uses of Class
io.vertx.rxjava3.core.http.HttpClientResponse
Packages that use HttpClientResponse
-
Uses of HttpClientResponse in io.vertx.rxjava3.core.http
Fields in io.vertx.rxjava3.core.http with type parameters of type HttpClientResponseModifier and TypeFieldDescriptionstatic final TypeArg<HttpClientResponse>HttpClientResponse.__TYPE_ARGMethods in io.vertx.rxjava3.core.http that return HttpClientResponseModifier and TypeMethodDescriptionHttpClientResponse.bodyHandler(Handler<Buffer> bodyHandler) Convenience method for receiving the entire request body in one piece.HttpClientResponse.customFrameHandler(Handler<HttpFrame> handler) Set an custom frame handler.HttpClientResponse.endHandler(Handler<Void> endHandler) HttpClientResponse.exceptionHandler(Handler<Throwable> handler) HttpClientResponse.fetch(long amount) static HttpClientResponseHttpClientResponse.newInstance(HttpClientResponse arg) HttpClientResponse.pause()HttpClientResponse.resume()HttpClientResponse.streamPriorityHandler(Handler<StreamPriority> handler) Set an handler for stream priority changes.Methods in io.vertx.rxjava3.core.http that return types with arguments of type HttpClientResponseModifier and TypeMethodDescriptionio.reactivex.rxjava3.core.Single<HttpClientResponse>HttpClientRequest.connect()Create an HTTP tunnel to the server.io.reactivex.rxjava3.core.Single<HttpClientResponse>HttpClientRequest.response()io.reactivex.rxjava3.core.Single<HttpClientResponse>HttpClientRequest.rxConnect()Create an HTTP tunnel to the server.io.reactivex.rxjava3.core.Single<HttpClientResponse>HttpClientRequest.rxResponse()io.reactivex.rxjava3.core.Single<HttpClientResponse>HttpClientRequest.rxSend()Send the request with an empty body.io.reactivex.rxjava3.core.Single<HttpClientResponse>Send the request with a streambody.io.reactivex.rxjava3.core.Single<HttpClientResponse>Send the request with a bufferbody.io.reactivex.rxjava3.core.Single<HttpClientResponse>HttpClientRequest.rxSend(ClientForm form) LikeHttpClientRequest.send()but with aform.io.reactivex.rxjava3.core.Single<HttpClientResponse>Send the request with a stringbody.io.reactivex.rxjava3.core.Single<HttpClientResponse>HttpClientRequest.send()Send the request with an empty body.io.reactivex.rxjava3.core.Single<HttpClientResponse>Send the request with a streambody.io.reactivex.rxjava3.core.Single<HttpClientResponse>Send the request with a bufferbody.io.reactivex.rxjava3.core.Single<HttpClientResponse>HttpClientRequest.send(ClientForm form) LikeHttpClientRequest.send()but with aform.io.reactivex.rxjava3.core.Single<HttpClientResponse>Send the request with a stringbody.Method parameters in io.vertx.rxjava3.core.http with type arguments of type HttpClientResponseModifier and TypeMethodDescriptionHttpClientRequest.redirectHandler(Function<HttpClientResponse, io.reactivex.rxjava3.core.Single<HttpClientRequest>> handler) HttpClientBuilder.withRedirectHandler(Function<HttpClientResponse, io.reactivex.rxjava3.core.Single<RequestOptions>> handler) Set a redirect handler for the http client. -
Uses of HttpClientResponse in io.vertx.rxjava3.httpproxy
Methods in io.vertx.rxjava3.httpproxy that return HttpClientResponse