Uses of Class
io.vertx.rxjava3.core.http.HttpConnection
Packages that use HttpConnection
Package
Description
-
Uses of HttpConnection in io.vertx.rxjava3.core.http
Subclasses of HttpConnection in io.vertx.rxjava3.core.httpModifier and TypeClassDescriptionclassRepresents an HTTP client connection.Fields in io.vertx.rxjava3.core.http with type parameters of type HttpConnectionMethods in io.vertx.rxjava3.core.http that return HttpConnectionModifier and TypeMethodDescriptionHttpConnection.closeHandler(Handler<Void> handler) Set a close handler.HttpClientRequest.connection()HttpServerRequest.connection()HttpConnection.exceptionHandler(Handler<Throwable> handler) Set an handler called when a connection error happensHttpConnection.goAway(long errorCode) Deprecated.HttpConnection.goAway(long errorCode, int lastStreamId) Deprecated.Deprecated.HttpConnection.goAwayHandler(Handler<GoAway> handler) Set an handler called when a frame is received.static HttpConnectionHttpConnection.newInstance(HttpConnection arg) HttpConnection.pingHandler(Handler<Buffer> handler) Set an handler notified when a frame is received from the remote endpoint.HttpConnection.remoteSettingsHandler(Handler<HttpSettings> handler) Set an handler that is called when remote endpointHttpSettingsare updated.HttpConnection.setWindowSize(int windowSize) Update the current connection wide window size to a new size.HttpConnection.shutdownHandler(Handler<Void> handler) Set ahandlernotified when the HTTP connection is shutdown: the client or server will close the connection within a certain amount of time.Method parameters in io.vertx.rxjava3.core.http with type arguments of type HttpConnectionModifier and TypeMethodDescriptionHttpServer.connectionHandler(Handler<HttpConnection> handler) Set a connection handler for the server.HttpClientBuilder.withConnectHandler(Handler<HttpConnection> handler) Set a connection handler for the client.HttpServerBuilder.withConnectHandler(Handler<HttpConnection> handler) Set a connection handler for the server. -
Uses of HttpConnection in io.vertx.rxjava3.grpc.client
Methods in io.vertx.rxjava3.grpc.client that return HttpConnection -
Uses of HttpConnection in io.vertx.rxjava3.grpc.server
Methods in io.vertx.rxjava3.grpc.server that return HttpConnection