Uses of Class
io.vertx.rxjava3.core.http.HttpServer
Packages that use HttpServer
-
Uses of HttpServer in io.vertx.rxjava3.core.http
Fields in io.vertx.rxjava3.core.http with type parameters of type HttpServerMethods in io.vertx.rxjava3.core.http that return HttpServerModifier and TypeMethodDescriptionHttpServerBuilder.build()Build and return the server.HttpServer.connectionHandler(Handler<HttpConnection> handler) Set a connection handler for the server.HttpServer.exceptionHandler(Handler<Throwable> handler) Set an exception handler called for socket errors happening before the HTTP connection is established, e.g. during the TLS handshake.HttpServer.invalidRequestHandler(Handler<HttpServerRequest> handler) Set ahandlerfor handling invalid requests.static HttpServerHttpServer.newInstance(HttpServer arg) HttpServer.requestHandler(Handler<HttpServerRequest> handler) Set the request handler for the server torequestHandler.HttpServer.webSocketHandler(Handler<ServerWebSocket> handler) Set the WebSocket handler for the server towsHandler.HttpServer.webSocketHandshakeHandler(Handler<ServerWebSocketHandshake> handler) Set a handler for WebSocket handshake.Methods in io.vertx.rxjava3.core.http that return types with arguments of type HttpServerModifier and TypeMethodDescriptionio.reactivex.rxjava3.core.Single<HttpServer>HttpServer.listen()Tell the server to start listening.io.reactivex.rxjava3.core.Single<HttpServer>HttpServer.listen(int port) Likelisten()but the server will listen on host "0.0.0.0" and port specified here ignoring any value in theHttpServerOptionsthat was used when creating the server.io.reactivex.rxjava3.core.Single<HttpServer>Tell the server to start listening.io.reactivex.rxjava3.core.Single<HttpServer>HttpServer.listen(SocketAddress address) Tell the server to start listening on the given address supplying a handler that will be called when the server is actually listening (or has failed).io.reactivex.rxjava3.core.Single<HttpServer>HttpServer.rxListen()Tell the server to start listening.io.reactivex.rxjava3.core.Single<HttpServer>HttpServer.rxListen(int port) Likelisten()but the server will listen on host "0.0.0.0" and port specified here ignoring any value in theHttpServerOptionsthat was used when creating the server.io.reactivex.rxjava3.core.Single<HttpServer>Tell the server to start listening.io.reactivex.rxjava3.core.Single<HttpServer>HttpServer.rxListen(SocketAddress address) Tell the server to start listening on the given address supplying a handler that will be called when the server is actually listening (or has failed).