Uses of Class
io.vertx.rxjava3.core.http.HttpServerRequest
Packages that use HttpServerRequest
Package
Description
-
Uses of HttpServerRequest in io.vertx.rxjava3.core.http
Fields in io.vertx.rxjava3.core.http with type parameters of type HttpServerRequestModifier and TypeFieldDescriptionstatic final TypeArg<HttpServerRequest>HttpServerRequest.__TYPE_ARGMethods in io.vertx.rxjava3.core.http that return HttpServerRequestModifier and TypeMethodDescriptionHttpServerRequest.bodyHandler(Handler<Buffer> bodyHandler) Convenience method for receiving the entire request body in one piece.HttpServerRequest.customFrameHandler(Handler<HttpFrame> handler) Set a custom frame handler.HttpServerRequest.endHandler(Handler<Void> endHandler) HttpServerRequest.exceptionHandler(Handler<Throwable> handler) HttpServerRequest.fetch(long amount) static HttpServerRequestHttpServerRequest.newInstance(HttpServerRequest arg) HttpServerRequest.pause()HttpServerRequest.resume()Marks this request as being routed to the given route.HttpServerRequest.setExpectMultipart(boolean expect) Call this with true if you are expecting a multi-part body to be submitted in the request.HttpServerRequest.setParamsCharset(String charset) Override the charset to use for decoding the query parameter map, when none is set,UTF8is used.HttpServerRequest.streamPriorityHandler(Handler<StreamPriority> handler) Set an handler for stream priority changesHttpServerRequest.uploadHandler(Handler<HttpServerFileUpload> uploadHandler) Set an upload handler.Method parameters in io.vertx.rxjava3.core.http with type arguments of type HttpServerRequestModifier and TypeMethodDescriptionHttpServer.invalidRequestHandler(Handler<HttpServerRequest> handler) Set ahandlerfor handling invalid requests.HttpServer.requestHandler(Handler<HttpServerRequest> handler) Set the request handler for the server torequestHandler. -
Uses of HttpServerRequest in io.vertx.rxjava3.ext.web
Methods in io.vertx.rxjava3.ext.web that return HttpServerRequestMethods in io.vertx.rxjava3.ext.web with parameters of type HttpServerRequestModifier and TypeMethodDescriptionvoidRouter.handle(HttpServerRequest event) Something has happened, so handle it. -
Uses of HttpServerRequest in io.vertx.rxjava3.grpc.server
Methods in io.vertx.rxjava3.grpc.server with parameters of type HttpServerRequestModifier and TypeMethodDescriptionvoidGrpcServer.handle(HttpServerRequest event) Something has happened, so handle it. -
Uses of HttpServerRequest in io.vertx.rxjava3.httpproxy
Methods in io.vertx.rxjava3.httpproxy that return HttpServerRequestMethods in io.vertx.rxjava3.httpproxy with parameters of type HttpServerRequestModifier and TypeMethodDescriptionvoidHttpProxy.handle(HttpServerRequest request) Handle the outboundHttpServerRequest.static ProxyRequestProxyRequest.reverseProxy(HttpServerRequest proxiedRequest) Create a newProxyRequestinstance, the proxied request will be paused.static ProxyRequestProxyRequest.reverseProxy(HttpServerRequest proxiedRequest, ForwardedHeadersOptions forwardedHeadersOptions) LikeProxyRequest.reverseProxy(io.vertx.rxjava3.core.http.HttpServerRequest)but using specific For -
Uses of HttpServerRequest in io.vertx.rxjava3.micrometer
Methods in io.vertx.rxjava3.micrometer that return types with arguments of type HttpServerRequestModifier and TypeMethodDescriptionstatic Handler<HttpServerRequest>PrometheusRequestHandler.create()Creates a handler with a new PrometheusMeterRegistry and the default metrics endpoint ("/metrics").static Handler<HttpServerRequest>PrometheusRequestHandler.create(io.micrometer.prometheusmetrics.PrometheusMeterRegistry registry) Creates a handler with the specified PrometheusMeterRegistry and the default metrics endpoint ("/metrics").static Handler<HttpServerRequest>PrometheusRequestHandler.create(io.micrometer.prometheusmetrics.PrometheusMeterRegistry registry, String metricsEndpoint) Creates a handler with the specified PrometheusMeterRegistry and metrics endpoint. -
Uses of HttpServerRequest in io.vertx.rxjava3.openapi.validation
Methods in io.vertx.rxjava3.openapi.validation with parameters of type HttpServerRequestModifier and TypeMethodDescriptionstatic io.reactivex.rxjava3.core.Single<ValidatableRequest>ValidatableRequest.of(HttpServerRequest request, Operation operation) Creates a newValidatableRequestobject based on the passed and .static io.reactivex.rxjava3.core.Single<ValidatableRequest>ValidatableRequest.rxOf(HttpServerRequest request, Operation operation) Creates a newValidatableRequestobject based on the passed and .io.reactivex.rxjava3.core.Single<ValidatedRequest>RequestValidator.rxValidate(HttpServerRequest request) LikeRequestValidator.validate(io.vertx.rxjava3.core.http.HttpServerRequest), but the operationId andValidatableRequestare determined from the passed request.io.reactivex.rxjava3.core.Single<ValidatedRequest>RequestValidator.rxValidate(HttpServerRequest request, String operationId) LikeRequestValidator.validate(io.vertx.rxjava3.core.http.HttpServerRequest), butValidatableRequestare directly extracted from the passed request.io.reactivex.rxjava3.core.Single<ValidatedRequest>RequestValidator.validate(HttpServerRequest request) LikeRequestValidator.validate(io.vertx.rxjava3.core.http.HttpServerRequest), but the operationId andValidatableRequestare determined from the passed request.io.reactivex.rxjava3.core.Single<ValidatedRequest>RequestValidator.validate(HttpServerRequest request, String operationId) LikeRequestValidator.validate(io.vertx.rxjava3.core.http.HttpServerRequest), butValidatableRequestare directly extracted from the passed request.