Uses of Class
io.vertx.rxjava3.core.http.HttpServerResponse
Packages that use HttpServerResponse
Package
Description
-
Uses of HttpServerResponse in io.vertx.rxjava3.core.http
Fields in io.vertx.rxjava3.core.http with type parameters of type HttpServerResponseModifier and TypeFieldDescriptionstatic final TypeArg<HttpServerResponse>HttpServerResponse.__TYPE_ARGMethods in io.vertx.rxjava3.core.http that return HttpServerResponseModifier and TypeMethodDescriptionAdd a cookie.HttpServerResponse.bodyEndHandler(Handler<Void> handler) Provides a handler that will be called after the last part of the body is written to the wire.HttpServerResponse.closeHandler(Handler<Void> handler) Set a close handler for the response, this is called when the underlying connection is closed and the response was still using the connection.HttpServerResponse.drainHandler(Handler<Void> handler) HttpServerResponse.endHandler(Handler<Void> handler) Set an end handler for the response.HttpServerResponse.exceptionHandler(Handler<Throwable> handler) HttpServerResponse.headersEndHandler(Handler<Void> handler) Provide a handler that will be called just before the headers are written to the wire.static HttpServerResponseHttpServerResponse.newInstance(HttpServerResponse arg) HttpServerResponse.putHeader(CharSequence name, CharSequence value) LikeputHeader(java.lang.String, java.lang.String)but using CharSequenceHttpServerResponse.putHeader(CharSequence name, Iterable<CharSequence> values) LikeputHeader(java.lang.String, java.lang.String)but with CharSequence IterableLikeputHeader(java.lang.String, java.lang.String)but providing multiple values via a String IterablePut an HTTP headerHttpServerResponse.putTrailer(CharSequence name, CharSequence value) LikeputTrailer(java.lang.String, java.lang.String)but using CharSequenceHttpServerResponse.putTrailer(CharSequence name, Iterable<CharSequence> value) LikeputTrailer(java.lang.String, java.lang.String)but with CharSequence IterableHttpServerResponse.putTrailer(String name, Iterable<String> values) LikeputTrailer(java.lang.String, java.lang.String)but providing multiple values via a String IterableHttpServerResponse.putTrailer(String name, String value) Put an HTTP trailerHttpServerRequest.response()HttpServerResponse.setChunked(boolean chunked) Ifchunkedistrue, this response will use HTTP chunked encoding, and each call to write to the body will correspond to a new HTTP chunk sent on the wire.HttpServerResponse.setStatusCode(int statusCode) Set the status code.HttpServerResponse.setStatusMessage(String statusMessage) Set the status messageHttpServerResponse.setStreamPriority(StreamPriority streamPriority) Sets the priority of the associated streamHttpServerResponse.setWriteQueueMaxSize(int maxSize) Methods in io.vertx.rxjava3.core.http that return types with arguments of type HttpServerResponseModifier and TypeMethodDescriptionio.reactivex.rxjava3.core.Single<HttpServerResponse>HttpServerResponse.push(HttpMethod method, HostAndPort authority, String path) Likepush(io.vertx.core.http.HttpMethod, io.vertx.core.net.HostAndPort, java.lang.String)with no headers.io.reactivex.rxjava3.core.Single<HttpServerResponse>HttpServerResponse.push(HttpMethod method, HostAndPort authority, String path, MultiMap headers) Push a response to the client.io.reactivex.rxjava3.core.Single<HttpServerResponse>HttpServerResponse.push(HttpMethod method, String path) Likepush(io.vertx.core.http.HttpMethod, io.vertx.core.net.HostAndPort, java.lang.String)with the host copied from the current request.io.reactivex.rxjava3.core.Single<HttpServerResponse>HttpServerResponse.push(HttpMethod method, String path, MultiMap headers) Likepush(io.vertx.core.http.HttpMethod, io.vertx.core.net.HostAndPort, java.lang.String)with the host copied from the current request.io.reactivex.rxjava3.core.Single<HttpServerResponse>HttpServerResponse.rxPush(HttpMethod method, HostAndPort authority, String path) Likepush(io.vertx.core.http.HttpMethod, io.vertx.core.net.HostAndPort, java.lang.String)with no headers.io.reactivex.rxjava3.core.Single<HttpServerResponse>HttpServerResponse.rxPush(HttpMethod method, HostAndPort authority, String path, MultiMap headers) Push a response to the client.io.reactivex.rxjava3.core.Single<HttpServerResponse>HttpServerResponse.rxPush(HttpMethod method, String path) Likepush(io.vertx.core.http.HttpMethod, io.vertx.core.net.HostAndPort, java.lang.String)with the host copied from the current request.io.reactivex.rxjava3.core.Single<HttpServerResponse>HttpServerResponse.rxPush(HttpMethod method, String path, MultiMap headers) Likepush(io.vertx.core.http.HttpMethod, io.vertx.core.net.HostAndPort, java.lang.String)with the host copied from the current request. -
Uses of HttpServerResponse in io.vertx.rxjava3.ext.web
Methods in io.vertx.rxjava3.ext.web that return HttpServerResponse -
Uses of HttpServerResponse in io.vertx.rxjava3.openapi.validation
Methods in io.vertx.rxjava3.openapi.validation with parameters of type HttpServerResponseModifier and TypeMethodDescriptionio.reactivex.rxjava3.core.CompletableValidatedResponse.rxSend(HttpServerResponse serverResponse) Add all parameters from the validated response to the passed and send it.io.reactivex.rxjava3.core.CompletableValidatedResponse.send(HttpServerResponse serverResponse) Add all parameters from the validated response to the passed and send it.