Uses of Class
io.vertx.rxjava3.core.http.WebSocket
Packages that use WebSocket
-
Uses of WebSocket in io.vertx.rxjava3.core.http
Subclasses of WebSocket in io.vertx.rxjava3.core.httpModifier and TypeClassDescriptionclassRepresents a client-side WebSocket.classRepresents a server side WebSocket.Fields in io.vertx.rxjava3.core.http with type parameters of type WebSocketMethods in io.vertx.rxjava3.core.http that return WebSocketModifier and TypeMethodDescriptionWebSocket.binaryMessageHandler(Handler<Buffer> handler) WebSocket.closeHandler(Handler<Void> handler) WebSocket.drainHandler(Handler<Void> handler) WebSocket.endHandler(Handler<Void> endHandler) WebSocket.exceptionHandler(Handler<Throwable> handler) WebSocket.fetch(long amount) WebSocket.frameHandler(Handler<WebSocketFrame> handler) static WebSocketWebSocket.newInstance(WebSocket arg) WebSocket.pause()WebSocket.pongHandler(Handler<Buffer> handler) WebSocket.resume()WebSocket.setWriteQueueMaxSize(int maxSize) WebSocket.shutdownHandler(Handler<Void> handler) WebSocket.textMessageHandler(Handler<String> handler) Methods in io.vertx.rxjava3.core.http that return types with arguments of type WebSocketModifier and TypeMethodDescriptionio.reactivex.rxjava3.core.Single<WebSocket>Connect this WebSocket to the specified port, host and relative request URI.io.reactivex.rxjava3.core.Single<WebSocket>ClientWebSocket.connect(WebSocketConnectOptions options) Connect this WebSocket with the specified options.io.reactivex.rxjava3.core.Single<WebSocket>Connect this WebSocket at the relative request URI using the default host and port.io.reactivex.rxjava3.core.Single<WebSocket>Connect this WebSocket to the host and relative request URI and default port.io.reactivex.rxjava3.core.Single<WebSocket>Connect a WebSocket to the specified port, host and relative request URI.io.reactivex.rxjava3.core.Single<WebSocket>WebSocketClient.connect(WebSocketConnectOptions options) Connect a WebSocket with the specified options.io.reactivex.rxjava3.core.Single<WebSocket>Connect a WebSocket to the default client port, default client host and specified, relative request URI.io.reactivex.rxjava3.core.Single<WebSocket>Connect a WebSocket to the default client port and specified host and relative request URI.io.reactivex.rxjava3.core.Single<WebSocket>Connect this WebSocket to the specified port, host and relative request URI.io.reactivex.rxjava3.core.Single<WebSocket>ClientWebSocket.rxConnect(WebSocketConnectOptions options) Connect this WebSocket with the specified options.io.reactivex.rxjava3.core.Single<WebSocket>Connect this WebSocket at the relative request URI using the default host and port.io.reactivex.rxjava3.core.Single<WebSocket>Connect this WebSocket to the host and relative request URI and default port.io.reactivex.rxjava3.core.Single<WebSocket>Connect a WebSocket to the specified port, host and relative request URI.io.reactivex.rxjava3.core.Single<WebSocket>WebSocketClient.rxConnect(WebSocketConnectOptions options) Connect a WebSocket with the specified options.io.reactivex.rxjava3.core.Single<WebSocket>Connect a WebSocket to the default client port, default client host and specified, relative request URI.io.reactivex.rxjava3.core.Single<WebSocket>Connect a WebSocket to the default client port and specified host and relative request URI.