Uses of Class
io.vertx.rxjava3.core.net.NetServer
Packages that use NetServer
-
Uses of NetServer in io.vertx.rxjava3.core.net
Fields in io.vertx.rxjava3.core.net with type parameters of type NetServerMethods in io.vertx.rxjava3.core.net that return NetServerModifier and TypeMethodDescriptionNetServer.connectHandler(Handler<NetSocket> handler) Supply a connect handler for this server.static NetServerNetServer.newInstance(NetServer arg) Methods in io.vertx.rxjava3.core.net that return types with arguments of type NetServerModifier and TypeMethodDescriptionio.reactivex.rxjava3.core.Single<NetServer>NetServer.listen()Start listening on the port and host as configured in theNetServerOptionsused when creating the server.io.reactivex.rxjava3.core.Single<NetServer>NetServer.listen(int port) Start listening on the specified port and host "0.0.0.0", ignoring port and host configured in theNetServerOptionsused when creating the server.io.reactivex.rxjava3.core.Single<NetServer>Start listening on the specified port and host, ignoring port and host configured in theNetServerOptionsused when creating the server.io.reactivex.rxjava3.core.Single<NetServer>NetServer.listen(SocketAddress localAddress) Start listening on the specified local address, ignoring port and host configured in theNetServerOptionsused when creating the server.io.reactivex.rxjava3.core.Single<NetServer>NetServer.rxListen()Start listening on the port and host as configured in theNetServerOptionsused when creating the server.io.reactivex.rxjava3.core.Single<NetServer>NetServer.rxListen(int port) Start listening on the specified port and host "0.0.0.0", ignoring port and host configured in theNetServerOptionsused when creating the server.io.reactivex.rxjava3.core.Single<NetServer>Start listening on the specified port and host, ignoring port and host configured in theNetServerOptionsused when creating the server.io.reactivex.rxjava3.core.Single<NetServer>NetServer.rxListen(SocketAddress localAddress) Start listening on the specified local address, ignoring port and host configured in theNetServerOptionsused when creating the server. -
Uses of NetServer in io.vertx.rxjava3.ext.stomp
Methods in io.vertx.rxjava3.ext.stomp with parameters of type NetServerModifier and TypeMethodDescriptionstatic StompServerCreates aStompServerbased on the default Stomp Server implementation.static StompServerStompServer.create(io.vertx.rxjava3.core.Vertx vertx, NetServer net, StompServerOptions options) Creates aStompServerbased on the default Stomp Server implementation.