Uses of Class
io.vertx.rxjava3.core.net.QuicServer
Packages that use QuicServer
-
Uses of QuicServer in io.vertx.rxjava3.core.net
Fields in io.vertx.rxjava3.core.net with type parameters of type QuicServerMethods in io.vertx.rxjava3.core.net that return QuicServerModifier and TypeMethodDescriptionQuicServer.connectHandler(Handler<QuicConnection> handler) Set the handler processingQuicConnection, the handler must be set before the server is bound.QuicServer.exceptionHandler(Handler<Throwable> handler) Set an exception handler called for socket errors happening before the QUIC connection is established, e.g. during the TLS handshake.static QuicServerQuicServer.newInstance(QuicServer arg) QuicServer.streamHandler(Handler<QuicStream> handler) Set a handler processing incoming Quic streams, this is a short-cut ofserver.connectHandler(connection -> connection.streamHandler(stream)).