Class ServerEndpoint
java.lang.Object
io.vertx.rxjava3.core.net.endpoint.ServerEndpoint
- All Implemented Interfaces:
RxDelegate
A physical server of an endpoint.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionaddress()booleaninthashCode()key()static ServerEndpointInitiate a request/response interaction with the endpoint represented by this node, the returned interaction gathers statistics.toString()
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
ServerEndpoint
-
ServerEndpoint
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
key
- Returns:
- the node key for hashing strategies
-
address
- Returns:
- the server socket address
-
protocolId
- Returns:
- the server protocol id, optional it can be null
-
newInteraction
Initiate a request/response interaction with the endpoint represented by this node, the returned interaction gathers statistics.- Returns:
- the request
-
newInstance
-