Class ServerInteraction
java.lang.Object
io.vertx.rxjava3.core.net.endpoint.ServerInteraction
- All Implemented Interfaces:
RxDelegate
Request interaction with an endpoint, mostly callbacks to gather statistics.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
ConstructorsConstructorDescriptionServerInteraction(ServerInteraction delegate) ServerInteraction(Object delegate) -
Method Summary
Modifier and TypeMethodDescriptionbooleaninthashCode()static ServerInteractionvoidreportFailure(Throwable failure) Report a failure.voidThe request has begun.voidThe request has ended.voidThe response has begun.voidThe request has ended.toString()
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
ServerInteraction
-
ServerInteraction
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
reportFailure
Report a failure.- Parameters:
failure- the failure to report
-
reportRequestBegin
public void reportRequestBegin()The request has begun. -
reportRequestEnd
public void reportRequestEnd()The request has ended. -
reportResponseBegin
public void reportResponseBegin()The response has begun. -
reportResponseEnd
public void reportResponseEnd()The request has ended. -
newInstance
-