Package io.vertx.rxjava3.core.net


package io.vertx.rxjava3.core.net
  • Class
    Description
    A TCP client.
    Represents a TCP server
    Represents a socket-like interface to a TCP connection on either the client or the server side.
    A Quic client.
    A Quic connection between a client and a server, providing support for handling or creating Quic streams
    Represents a Quic endpoints, whose primary function is to bind a UDP socket on a given or random port.
    A Quic server.
    A Quic stream.
    Represents a channel interface modelling a duplex flow controlled byte oriented stream.