Uses of Class
io.vertx.rxjava3.core.shareddata.AsyncMap
Packages that use AsyncMap
-
Uses of AsyncMap in io.vertx.rxjava3.core.shareddata
Fields in io.vertx.rxjava3.core.shareddata with type parameters of type AsyncMapMethods in io.vertx.rxjava3.core.shareddata that return AsyncMapModifier and TypeMethodDescriptionstatic <K,V> AsyncMap<K, V> AsyncMap.newInstance(AsyncMap arg) static <K,V> AsyncMap<K, V> AsyncMap.newInstance(AsyncMap arg, TypeArg<K> __typeArg_K, TypeArg<V> __typeArg_V) Methods in io.vertx.rxjava3.core.shareddata that return types with arguments of type AsyncMapModifier and TypeMethodDescription<K,V> io.reactivex.rxjava3.core.Single<AsyncMap<K, V>> SharedData.getAsyncMap(String name) Get theAsyncMapwith the specified name.<K,V> io.reactivex.rxjava3.core.Single<AsyncMap<K, V>> SharedData.getClusterWideMap(String name) Get the cluster wide map with the specified name.<K,V> io.reactivex.rxjava3.core.Single<AsyncMap<K, V>> SharedData.getLocalAsyncMap(String name) Get theAsyncMapwith the specified name.<K,V> io.reactivex.rxjava3.core.Single<AsyncMap<K, V>> SharedData.rxGetAsyncMap(String name) Get theAsyncMapwith the specified name.<K,V> io.reactivex.rxjava3.core.Single<AsyncMap<K, V>> SharedData.rxGetClusterWideMap(String name) Get the cluster wide map with the specified name.<K,V> io.reactivex.rxjava3.core.Single<AsyncMap<K, V>> SharedData.rxGetLocalAsyncMap(String name) Get theAsyncMapwith the specified name.