Package io.vertx.rxjava3.db2client
Class DB2Connection
java.lang.Object
io.vertx.rxjava3.sqlclient.SqlClient
io.vertx.rxjava3.sqlclient.SqlConnection
io.vertx.rxjava3.db2client.DB2Connection
- All Implemented Interfaces:
RxDelegate
A connection to DB2 server.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic DB2Connectioncast(SqlConnection sqlConnection) Cast a toDB2Connection.closeHandler(Handler<Void> handler) Set an handler called when the connection is closed.static io.reactivex.rxjava3.core.Single<DB2Connection>connect(io.vertx.rxjava3.core.Vertx vertx, DB2ConnectOptions connectOptions) Create a connection to DB2 server with the givenconnectOptions.static io.reactivex.rxjava3.core.Single<DB2Connection>Likeconnect(io.vertx.rxjava3.core.Vertx, io.vertx.db2client.DB2ConnectOptions)with options build fromconnectionUri.io.reactivex.rxjava3.core.Completabledebug()Send a DEBUG command to dump debug information to the server's stdout.booleanexceptionHandler(Handler<Throwable> handler) Set an handler called with connection errors.inthashCode()static DB2ConnectionnewInstance(DB2Connection arg) io.reactivex.rxjava3.core.Completableping()Send a PING command to check if the server is alive.static io.reactivex.rxjava3.core.Single<DB2Connection>rxConnect(io.vertx.rxjava3.core.Vertx vertx, DB2ConnectOptions connectOptions) Create a connection to DB2 server with the givenconnectOptions.static io.reactivex.rxjava3.core.Single<DB2Connection>Likeconnect(io.vertx.rxjava3.core.Vertx, io.vertx.db2client.DB2ConnectOptions)with options build fromconnectionUri.io.reactivex.rxjava3.core.CompletablerxDebug()Send a DEBUG command to dump debug information to the server's stdout.io.reactivex.rxjava3.core.CompletablerxPing()Send a PING command to check if the server is alive.toString()Methods inherited from class io.vertx.rxjava3.sqlclient.SqlConnection
begin, databaseMetadata, isSSL, newInstance, prepare, prepare, rxBegin, rxPrepare, rxPrepare, transactionMethods inherited from class io.vertx.rxjava3.sqlclient.SqlClient
close, newInstance, preparedQuery, preparedQuery, query, rxClose
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
DB2Connection
-
DB2Connection
-
-
Method Details
-
toString
- Overrides:
toStringin classSqlConnection
-
equals
- Overrides:
equalsin classSqlConnection
-
hashCode
public int hashCode()- Overrides:
hashCodein classSqlConnection
-
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate- Overrides:
getDelegatein classSqlConnection
-
connect
public static io.reactivex.rxjava3.core.Single<DB2Connection> connect(io.vertx.rxjava3.core.Vertx vertx, DB2ConnectOptions connectOptions) Create a connection to DB2 server with the givenconnectOptions.- Parameters:
vertx- the vertx instanceconnectOptions- the options for the connection- Returns:
- a future notified with the connection or the failure
-
rxConnect
public static io.reactivex.rxjava3.core.Single<DB2Connection> rxConnect(io.vertx.rxjava3.core.Vertx vertx, DB2ConnectOptions connectOptions) Create a connection to DB2 server with the givenconnectOptions.- Parameters:
vertx- the vertx instanceconnectOptions- the options for the connection- Returns:
- a future notified with the connection or the failure
-
connect
public static io.reactivex.rxjava3.core.Single<DB2Connection> connect(io.vertx.rxjava3.core.Vertx vertx, String connectionUri) Likeconnect(io.vertx.rxjava3.core.Vertx, io.vertx.db2client.DB2ConnectOptions)with options build fromconnectionUri.- Parameters:
vertx-connectionUri-- Returns:
-
rxConnect
public static io.reactivex.rxjava3.core.Single<DB2Connection> rxConnect(io.vertx.rxjava3.core.Vertx vertx, String connectionUri) Likeconnect(io.vertx.rxjava3.core.Vertx, io.vertx.db2client.DB2ConnectOptions)with options build fromconnectionUri.- Parameters:
vertx-connectionUri-- Returns:
-
exceptionHandler
Description copied from class:SqlConnectionSet an handler called with connection errors.- Overrides:
exceptionHandlerin classSqlConnection- Parameters:
handler- the handler- Returns:
- a reference to this, so the API can be used fluently
-
closeHandler
Description copied from class:SqlConnectionSet an handler called when the connection is closed.- Overrides:
closeHandlerin classSqlConnection- Parameters:
handler- the handler- Returns:
- a reference to this, so the API can be used fluently
-
ping
public io.reactivex.rxjava3.core.Completable ping()Send a PING command to check if the server is alive.- Returns:
- a future notified with the server response
-
rxPing
public io.reactivex.rxjava3.core.Completable rxPing()Send a PING command to check if the server is alive.- Returns:
- a future notified with the server response
-
debug
public io.reactivex.rxjava3.core.Completable debug()Send a DEBUG command to dump debug information to the server's stdout.- Returns:
- a future notified with the execution result
-
rxDebug
public io.reactivex.rxjava3.core.Completable rxDebug()Send a DEBUG command to dump debug information to the server's stdout.- Returns:
- a future notified with the execution result
-
cast
Cast a toDB2Connection. This is mostly useful for Vert.x generated APIs like RxJava/Mutiny.- Parameters:
sqlConnection- the connection to cast- Returns:
- a
instance
-
newInstance
-