Class ChainAuth

All Implemented Interfaces:
RxDelegate

public class ChainAuth extends AuthenticationProvider implements RxDelegate
Chain several authentication providers as if they were one. This is useful for cases where one want to authenticate across several providers, for example, database and fallback to passwd file.

NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.