Class AuthenticationProvider
java.lang.Object
io.vertx.rxjava3.ext.auth.authentication.AuthenticationProvider
- All Implemented Interfaces:
RxDelegate
- Direct Known Subclasses:
ChainAuth,HotpAuth,HtdigestAuth,HtpasswdAuth,JWTAuth,LdapAuthentication,OAuth2Auth,PropertyFileAuthentication,SqlAuthentication,TotpAuth,WebAuthn4J
User-facing interface for authenticating users.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
ConstructorsConstructorDescriptionAuthenticationProvider(AuthenticationProvider delegate) AuthenticationProvider(Object delegate) -
Method Summary
Modifier and TypeMethodDescriptionio.reactivex.rxjava3.core.Single<User>authenticate(Credentials credentials) Authenticate a user.booleaninthashCode()static AuthenticationProviderio.reactivex.rxjava3.core.Single<User>rxAuthenticate(Credentials credentials) Authenticate a user.toString()
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
AuthenticationProvider
-
AuthenticationProvider
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
authenticate
Authenticate a user.The first argument is a Credentials object containing information for authenticating the user. What this actually contains depends on the specific implementation.
- Parameters:
credentials- The credentials- Returns:
- The result future
-
rxAuthenticate
Authenticate a user.The first argument is a Credentials object containing information for authenticating the user. What this actually contains depends on the specific implementation.
- Parameters:
credentials- The credentials- Returns:
- The result future
-
newInstance
-