Class AuthorizationContext

java.lang.Object
io.vertx.rxjava3.ext.auth.authorization.AuthorizationContext
All Implemented Interfaces:
RxDelegate

public class AuthorizationContext extends Object implements RxDelegate
The AuthorizationContext contains properties that can be used to match authorizations.

NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.