Class RoleBasedAuthorization

java.lang.Object
io.vertx.rxjava3.ext.auth.authorization.RoleBasedAuthorization
All Implemented Interfaces:
RxDelegate, Authorization

public class RoleBasedAuthorization extends Object implements RxDelegate, Authorization
Represents a role. Note that this role can optionally be assigned to a specific resource

NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.