Class HashingAlgorithm
java.lang.Object
io.vertx.rxjava3.ext.auth.hashing.HashingAlgorithm
- All Implemented Interfaces:
RxDelegate
Hashing Algorithm. A common interface to interact with any system provided algorithms.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
ConstructorsConstructorDescriptionHashingAlgorithm(HashingAlgorithm delegate) HashingAlgorithm(Object delegate) -
Method Summary
Modifier and TypeMethodDescriptionbooleaninthashCode()id()return the symbolic name for the algorithmbooleanShould the encoded string use the default separator to split fields.static HashingAlgorithmparams()return the list of param names required for this algorithm.toString()
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
HashingAlgorithm
-
HashingAlgorithm
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
id
return the symbolic name for the algorithm- Returns:
- short id e.g.: sha512.
-
params
return the list of param names required for this algorithm.- Returns:
- set of param names.
-
needsSeparator
public boolean needsSeparator()Should the encoded string use the default separator to split fields.- Returns:
- true by default.
-
newInstance
-