Class HashingStrategy
java.lang.Object
io.vertx.rxjava3.ext.auth.hashing.HashingStrategy
- All Implemented Interfaces:
RxDelegate
Hashing Strategy manager.
This class will load system provided hashing strategies and algorithms.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleanGet an algorithm interface by its IdHashes a password.inthashCode()static HashingStrategyload()Factory method to load the algorithms from the systemstatic HashingStrategyput(String id, HashingAlgorithm algorithm) Put or replace an algorithm into the list of system loaded algorithms.toString()booleanTime constant password check.
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
HashingStrategy
-
HashingStrategy
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
load
Factory method to load the algorithms from the system- Returns:
- a Hashing Strategy capable of hashing using the available algorithms
-
hash
Hashes a password.- Parameters:
id- the algorithm idparams- the algorithm specific parameterssalt- the given saltpassword- the given password- Returns:
- the hashed string
-
verify
Time constant password check. Regardless of the check, this algorithm executes the same number of checks regardless of the correctly number of characters- Parameters:
hash- the hash to verifypassword- the password to test against- Returns:
- boolean
-
get
Get an algorithm interface by its Id- Parameters:
id- the algorithm id- Returns:
- the algorithm
-
put
Put or replace an algorithm into the list of system loaded algorithms.- Parameters:
id- the algorithm idalgorithm- the implementation- Returns:
- self
-
newInstance
-