Class SqlUserUtil
java.lang.Object
io.vertx.rxjava3.ext.auth.sqlclient.SqlUserUtil
- All Implemented Interfaces:
RxDelegate
Utility to create users/roles/permissions. This is a helper class and not intended to be a full user
management utility. While the standard authentication and authorization interfaces will require usually
read only access to the database, in order to use this API a full read/write access must be granted.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic SqlUserUtilCreate an instance of the user helper.static SqlUserUtilcreate(SqlClient client, String insertUserSQL, String insertUserRoleSQL, String insertRolePermissionSQL) Create an instance of the user helper with custom queries.io.reactivex.rxjava3.core.CompletablecreateHashedUser(String username, String hash) Insert a user into a database.io.reactivex.rxjava3.core.CompletablecreateRolePermission(String role, String permission) Insert a role permission into a database.io.reactivex.rxjava3.core.CompletablecreateUser(String username, String password) Insert a user into a database.io.reactivex.rxjava3.core.CompletablecreateUserRole(String username, String role) Insert a user role into a database.booleaninthashCode()static SqlUserUtilnewInstance(SqlUserUtil arg) io.reactivex.rxjava3.core.CompletablerxCreateHashedUser(String username, String hash) Insert a user into a database.io.reactivex.rxjava3.core.CompletablerxCreateRolePermission(String role, String permission) Insert a role permission into a database.io.reactivex.rxjava3.core.CompletablerxCreateUser(String username, String password) Insert a user into a database.io.reactivex.rxjava3.core.CompletablerxCreateUserRole(String username, String role) Insert a user role into a database.toString()
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
SqlUserUtil
-
SqlUserUtil
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
create
Create an instance of the user helper.- Parameters:
client- the client with write rights to the database.- Returns:
- the instance
-
create
public static SqlUserUtil create(SqlClient client, String insertUserSQL, String insertUserRoleSQL, String insertRolePermissionSQL) Create an instance of the user helper with custom queries.- Parameters:
client- the client with write rights to the database.insertUserSQL-insertUserRoleSQL-insertRolePermissionSQL-- Returns:
- the instance
-
createUser
Insert a user into a database.- Parameters:
username- the username to be setpassword- the passsword in clear text, will be adapted following the definitions of the defined strategy- Returns:
- a future notified with the result of the operation
-
rxCreateUser
Insert a user into a database.- Parameters:
username- the username to be setpassword- the passsword in clear text, will be adapted following the definitions of the defined strategy- Returns:
- a future notified with the result of the operation
-
createHashedUser
Insert a user into a database.- Parameters:
username- the username to be sethash- the password hash, as result of- Returns:
- a future notified with the result of the operation
-
rxCreateHashedUser
Insert a user into a database.- Parameters:
username- the username to be sethash- the password hash, as result of- Returns:
- a future notified with the result of the operation
-
createUserRole
Insert a user role into a database.- Parameters:
username- the username to be setrole- a to be set- Returns:
- a future notified with the result of the operation
-
rxCreateUserRole
Insert a user role into a database.- Parameters:
username- the username to be setrole- a to be set- Returns:
- a future notified with the result of the operation
-
createRolePermission
Insert a role permission into a database.- Parameters:
role- a to be setpermission- the permission to be set- Returns:
- a future notified with the result of the operation
-
rxCreateRolePermission
Insert a role permission into a database.- Parameters:
role- a to be setpermission- the permission to be set- Returns:
- a future notified with the result of the operation
-
newInstance
-