Package io.vertx.rxjava3.ext.dropwizard
Class MetricsService
java.lang.Object
io.vertx.rxjava3.ext.dropwizard.MetricsService
- All Implemented Interfaces:
RxDelegate
The metrics service mainly allows to return a snapshot of measured objects.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic MetricsServicecreate(io.vertx.rxjava3.core.Vertx vertx) Creates a metric service for a givenVertxinstance.booleangetBaseName(Measured measured) getMetricsSnapshot(Measured measured) Will return the metrics that correspond with themeasuredobject, null if no metrics is available.getMetricsSnapshot(String baseName) Will return the metrics that begins with thebaseName, null if no metrics is available.inthashCode()static MetricsServicetoString()
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
MetricsService
-
MetricsService
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
create
Creates a metric service for a givenVertxinstance.- Parameters:
vertx- the vertx instance- Returns:
- the metrics service
-
getBaseName
- Parameters:
measured- the measure object- Returns:
- the base name of the measured object
-
metricsNames
- Returns:
- the known metrics names by this service
-
getMetricsSnapshot
Will return the metrics that correspond with themeasuredobject, null if no metrics is available. Note: in the case of scaled servers, the JsonObject returns an aggregation of the metrics as the dropwizard backend reports to a single server.- Parameters:
measured-- Returns:
- the map of metrics where the key is the name of the metric (excluding the base name unless for the Vert.x object) and the value is the json data representing that metric
-
getMetricsSnapshot
Will return the metrics that begins with thebaseName, null if no metrics is available. Note: in the case of scaled servers, the JsonObject returns an aggregation of the metrics as the dropwizard backend reports to a single server.- Parameters:
baseName-- Returns:
- the map of metrics where the key is the name of the metric and the value is the json data representing that metric
-
newInstance
-