Class Frames

java.lang.Object
io.vertx.rxjava3.ext.stomp.Frames
All Implemented Interfaces:
RxDelegate

public class Frames extends Object implements RxDelegate
Utility methods to build common Frames. It defines a non-STOMP frame (PING) that is used for heartbeats. When such frame is written on the wire it is just the 0 byte.

This class is thread-safe.

NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.