Class ServerFrame

java.lang.Object
io.vertx.rxjava3.ext.stomp.ServerFrame
All Implemented Interfaces:
RxDelegate

public class ServerFrame extends Object implements RxDelegate
Structure passed to server handler when receiving a frame. It provides a reference on the received Frame but also on the StompServerConnection.

NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.