Uses of Class
io.vertx.rxjava3.ext.stomp.StompClientConnection
Packages that use StompClientConnection
-
Uses of StompClientConnection in io.vertx.rxjava3.ext.stomp
Fields in io.vertx.rxjava3.ext.stomp with type parameters of type StompClientConnectionModifier and TypeFieldDescriptionstatic final TypeArg<StompClientConnection>StompClientConnection.__TYPE_ARGMethods in io.vertx.rxjava3.ext.stomp that return StompClientConnectionModifier and TypeMethodDescriptionStompClientConnection.closeHandler(Handler<StompClientConnection> handler) Sets a handler notified when the STOMP connection is closed.StompClientConnection.connectionDroppedHandler(Handler<StompClientConnection> handler) Sets a handler notified when the server does not respond to apingrequest in time.StompClientConnection.errorHandler(Handler<Frame> handler) Sets a handler notified when anERRORframe is received by the client.StompClientConnection.exceptionHandler(Handler<Throwable> exceptionHandler) Configures the exception handler notified upon TCP-level errors.static StompClientConnectionStompClientConnection.newInstance(StompClientConnection arg) StompClientConnection.pingHandler(Handler<StompClientConnection> handler) Sets a handler that let customize the behavior when a ping needs to be sent to the server.StompClientConnection.receivedFrameHandler(Handler<Frame> handler) Configures a received handler that get notified when a STOMP frame is received by the client.StompClientConnection.writingFrameHandler(Handler<Frame> handler) Configures a handler notified when a frame is going to be written on the wire.Methods in io.vertx.rxjava3.ext.stomp that return types with arguments of type StompClientConnectionModifier and TypeMethodDescriptionio.reactivex.rxjava3.core.Single<StompClientConnection>StompClient.connect()Connects to the server using the host and port configured in the client's options.io.reactivex.rxjava3.core.Single<StompClientConnection>Connects to the server.io.reactivex.rxjava3.core.Single<StompClientConnection>StompClient.rxConnect()Connects to the server using the host and port configured in the client's options.io.reactivex.rxjava3.core.Single<StompClientConnection>Connects to the server.Method parameters in io.vertx.rxjava3.ext.stomp with type arguments of type StompClientConnectionModifier and TypeMethodDescriptionStompClientConnection.closeHandler(Handler<StompClientConnection> handler) Sets a handler notified when the STOMP connection is closed.StompClientConnection.connectionDroppedHandler(Handler<StompClientConnection> handler) Sets a handler notified when the server does not respond to apingrequest in time.StompClientConnection.pingHandler(Handler<StompClientConnection> handler) Sets a handler that let customize the behavior when a ping needs to be sent to the server.