Uses of Class
io.vertx.rxjava3.ext.stomp.StompServer
Packages that use StompServer
-
Uses of StompServer in io.vertx.rxjava3.ext.stomp
Fields in io.vertx.rxjava3.ext.stomp with type parameters of type StompServerMethods in io.vertx.rxjava3.ext.stomp that return StompServerModifier and TypeMethodDescriptionstatic StompServerStompServer.create(io.vertx.rxjava3.core.Vertx vertx) Creates aStompServerbased on the default Stomp Server implementation, and use the default options.static StompServerStompServer.create(io.vertx.rxjava3.core.Vertx vertx, StompServerOptions options) Creates aStompServerbased on the default Stomp Server implementation.static StompServerCreates aStompServerbased on the default Stomp Server implementation.static StompServerStompServer.create(io.vertx.rxjava3.core.Vertx vertx, NetServer net, StompServerOptions options) Creates aStompServerbased on the default Stomp Server implementation.StompServer.handler(StompServerHandler handler) Configures theStompServerHandler.static StompServerStompServer.newInstance(StompServer arg) StompServerConnection.server()StompServer.writingFrameHandler(Handler<ServerFrame> handler) Configures the handler that is invoked every time a frame is going to be written to the "wire".Methods in io.vertx.rxjava3.ext.stomp that return types with arguments of type StompServerModifier and TypeMethodDescriptionio.reactivex.rxjava3.core.Single<StompServer>StompServer.listen()Connects the STOMP server default port (61613) and network interface (0.0.0.0).io.reactivex.rxjava3.core.Single<StompServer>StompServer.listen(int port) Connects the STOMP server to the given port.io.reactivex.rxjava3.core.Single<StompServer>Connects the STOMP server to the given port / interface.io.reactivex.rxjava3.core.Single<StompServer>StompServer.rxListen()Connects the STOMP server default port (61613) and network interface (0.0.0.0).io.reactivex.rxjava3.core.Single<StompServer>StompServer.rxListen(int port) Connects the STOMP server to the given port.io.reactivex.rxjava3.core.Single<StompServer>Connects the STOMP server to the given port / interface.