Package io.vertx.rxjava3.ext.unit
Class Completion<T>
java.lang.Object
io.vertx.rxjava3.ext.unit.Completion<T>
- All Implemented Interfaces:
RxDelegate
- Direct Known Subclasses:
Async,TestCompletion
A completion object that emits completion notifications either succeeded or failed.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
ConstructorsConstructorDescriptionCompletion(Completion delegate) Completion(Object delegate, TypeArg<T> typeArg_0) -
Method Summary
Modifier and TypeMethodDescriptionvoidawait()Cause the current thread to wait until this completion completes.voidawait(long timeoutMillis) Cause the current thread to wait until this completion completes with a configurable timeout.voidCause the current thread to wait until this completion completes and succeeds.voidawaitSuccess(long timeoutMillis) Cause the current thread to wait until this completion completes and succeeds with a configurable timeout.booleanvoidhandler(Handler<AsyncResult<T>> completionHandler) Completion handler to receive a completion signal when this completions completes.inthashCode()booleanbooleanisFailed()booleanstatic <T> Completion<T>newInstance(Completion arg) static <T> Completion<T>newInstance(Completion arg, TypeArg<T> __typeArg_T) voidCompletes the future upon completion, otherwise fails it.toString()
-
Field Details
-
__TYPE_ARG
-
__typeArg_0
-
-
Constructor Details
-
Completion
-
Completion
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
resolve
Completes the future upon completion, otherwise fails it.- Parameters:
future- the future to resolve
-
isCompleted
public boolean isCompleted()- Returns:
- true if this completion is completed
-
isSucceeded
public boolean isSucceeded()- Returns:
- true if this completion is completed and succeeded
-
isFailed
public boolean isFailed()- Returns:
- true if the this completion is completed and failed
-
await
public void await()Cause the current thread to wait until this completion completes. If the current thread is interrupted, an exception will be thrown. -
await
public void await(long timeoutMillis) Cause the current thread to wait until this completion completes with a configurable timeout. If completion times out or the current thread is interrupted, an exception will be thrown.- Parameters:
timeoutMillis- the timeout in milliseconds
-
awaitSuccess
public void awaitSuccess()Cause the current thread to wait until this completion completes and succeeds. If the current thread is interrupted or the suite fails, an exception will be thrown. -
awaitSuccess
public void awaitSuccess(long timeoutMillis) Cause the current thread to wait until this completion completes and succeeds with a configurable timeout. If completion times out or the current thread is interrupted or the suite fails, an exception will be thrown.- Parameters:
timeoutMillis- the timeout in milliseconds
-
handler
Completion handler to receive a completion signal when this completions completes.- Parameters:
completionHandler- the completion handler
-
newInstance
-
newInstance
-