Package io.vertx.rxjava3.ext.unit
Class TestCase
java.lang.Object
io.vertx.rxjava3.ext.unit.TestCase
- All Implemented Interfaces:
RxDelegate
A test case object can be used to create a single test.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic TestCasecreate(String name, Handler<TestContext> testCase) Create a test case.booleaninthashCode()static TestCasenewInstance(TestCase arg) toString()
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
TestCase
-
TestCase
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
create
Create a test case.- Parameters:
name- the test case nametestCase- the test case- Returns:
- the created test case
-
newInstance
-