Uses of Class
io.vertx.rxjava3.ext.unit.Completion
Packages that use Completion
-
Uses of Completion in io.vertx.rxjava3.ext.unit
Subclasses of Completion in io.vertx.rxjava3.ext.unitModifier and TypeClassDescriptionclassAn asynchronous exit point for a test.classThis object provides callback-ability for the end of a test suite, the completion succeeds when all tests pass otherwise it fails.Fields in io.vertx.rxjava3.ext.unit with type parameters of type CompletionMethods in io.vertx.rxjava3.ext.unit that return CompletionModifier and TypeMethodDescriptionstatic <T> Completion<T>Completion.newInstance(Completion arg) static <T> Completion<T>Completion.newInstance(Completion arg, TypeArg<T> __typeArg_T)