Package io.vertx.rxjava3.ext.unit.report
Class TestCaseReport
java.lang.Object
io.vertx.rxjava3.ext.unit.report.TestCaseReport
- All Implemented Interfaces:
RxDelegate
Report the execution of a test case.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionendHandler(Handler<TestResult> handler) Set a callback for completion, the specifiedhandleris invoked when the test exec has completed.booleaninthashCode()name()static TestCaseReporttoString()
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
TestCaseReport
-
TestCaseReport
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
name
- Returns:
- the test case name
-
endHandler
Set a callback for completion, the specifiedhandleris invoked when the test exec has completed.- Parameters:
handler- the completion handler- Returns:
- a reference to this, so the API can be used fluently
-
newInstance
-