Package io.vertx.rxjava3.ext.web
Class FileUpload
java.lang.Object
io.vertx.rxjava3.ext.web.FileUpload
- All Implemented Interfaces:
RxDelegate
Represents a file-upload from an HTTP multipart form submission.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleancancel()Try to cancel the file upload.charSet()io.reactivex.rxjava3.core.Completabledelete()Delete the uploaded file on the disk.booleanfileName()inthashCode()name()static FileUploadnewInstance(FileUpload arg) io.reactivex.rxjava3.core.CompletablerxDelete()Delete the uploaded file on the disk.longsize()toString()
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
FileUpload
-
FileUpload
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
name
- Returns:
- the name of the upload as provided in the form submission
-
uploadedFileName
- Returns:
- the actual temporary file name on the server where the file was uploaded to.
-
fileName
- Returns:
- the file name of the upload as provided in the form submission
-
size
public long size()- Returns:
- the size of the upload, in bytes
-
contentType
- Returns:
- the content type (MIME type) of the upload
-
contentTransferEncoding
- Returns:
- the content transfer encoding of the upload - this describes how the upload was encoded in the form submission.
-
charSet
- Returns:
- the charset of the upload
-
cancel
public boolean cancel()Try to cancel the file upload.- Returns:
truewhen the upload was cancelled,falsewhen the upload is finished and the file is available
-
delete
public io.reactivex.rxjava3.core.Completable delete()Delete the uploaded file on the disk.- Returns:
- a future signaling when the file has been deleted
-
rxDelete
public io.reactivex.rxjava3.core.Completable rxDelete()Delete the uploaded file on the disk.- Returns:
- a future signaling when the file has been deleted
-
newInstance
-