Class ParsedHeaderValues

java.lang.Object
io.vertx.rxjava3.ext.web.ParsedHeaderValues
All Implemented Interfaces:
RxDelegate

public class ParsedHeaderValues extends Object implements RxDelegate
A container with the request's headers that are meaningful enough to be parsed Contains:
  • Accept -> MIME header, parameters and sortable
  • Accept-Charset -> Parameters and sortable
  • Accept-Encoding -> Parameters and sortable
  • Accept-Language -> Parameters and sortable
  • Content-Type -> MIME header and parameters

NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.