Uses of Class
io.vertx.rxjava3.ext.web.RoutingContext
Packages that use RoutingContext
Package
Description
-
Uses of RoutingContext in io.vertx.rxjava3.ext.web
Fields in io.vertx.rxjava3.ext.web with type parameters of type RoutingContextMethods in io.vertx.rxjava3.ext.web that return RoutingContextModifier and TypeMethodDescriptionRoutingContext.attachment(String filename) Set Content-Disposition get to "attachment" with optionalfilenamemime type.Set the ETag of a response.RoutingContext.lastModified(String instant) Set the Last-Modified date using a String.RoutingContext.lastModified(Instant instant) Set the Last-Modified date using a Instant.static RoutingContextRoutingContext.newInstance(RoutingContext arg) Put some arbitrary data in the context.Methods in io.vertx.rxjava3.ext.web with parameters of type RoutingContextModifier and TypeMethodDescriptionvoidRouter.handleContext(RoutingContext context) Used to route a context to the router.voidRouter.handleFailure(RoutingContext context) Used to route a failure to the router.Method parameters in io.vertx.rxjava3.ext.web with type arguments of type RoutingContextModifier and TypeMethodDescriptionRoute.blockingHandler(Handler<RoutingContext> requestHandler) LikeRoute.blockingHandler(io.vertx.core.Handler<io.vertx.rxjava3.ext.web.RoutingContext>)called with ordered = trueRoute.blockingHandler(Handler<RoutingContext> requestHandler, boolean ordered) Specify a blocking request handler for the route.Router.errorHandler(int statusCode, Handler<RoutingContext> errorHandler) Specify an handler to handle an error for a particular status code.Route.failureHandler(Handler<RoutingContext> failureHandler) Append a failure handler to the route failure handlers list.Route.handler(Handler<RoutingContext> requestHandler) Append a request handler to the route handlers list.<T> RouteRoute.respond(Function<RoutingContext, io.reactivex.rxjava3.core.Maybe<T>> function) Append a function request handler to the route handlers list.Router.uncaughtErrorHandler(Handler<RoutingContext> errorHandler) Specify an handler to handle an error for any status code that doesn't have a specific handler assigned. -
Uses of RoutingContext in io.vertx.rxjava3.ext.web.handler
Methods in io.vertx.rxjava3.ext.web.handler with parameters of type RoutingContextModifier and TypeMethodDescriptionio.reactivex.rxjava3.core.CompletableSessionHandler.flush(RoutingContext ctx) Flush a context session earlier to the store, this will allow the end user to have full control on the event of a failure at the store level.io.reactivex.rxjava3.core.CompletableSessionHandler.flush(RoutingContext ctx, boolean ignoreStatus) Flush a context session earlier to the store, this will allow the end user to have full control on the event of a failure at the store level.LoggerFormatter.format(RoutingContext routingContext, long ms) Formats and returns the log statementvoidAPIKeyHandler.handle(RoutingContext event) Something has happened, so handle it.voidAuthenticationHandler.handle(RoutingContext event) Something has happened, so handle it.voidAuthorizationHandler.handle(RoutingContext event) Something has happened, so handle it.voidBasicAuthHandler.handle(RoutingContext event) Something has happened, so handle it.voidBodyHandler.handle(RoutingContext event) Something has happened, so handle it.voidChainAuthHandler.handle(RoutingContext event) Something has happened, so handle it.voidCorsHandler.handle(RoutingContext event) Something has happened, so handle it.voidCSPHandler.handle(RoutingContext event) Something has happened, so handle it.voidCSRFHandler.handle(RoutingContext event) Something has happened, so handle it.voidDigestAuthHandler.handle(RoutingContext event) Something has happened, so handle it.voidErrorHandler.handle(RoutingContext event) Something has happened, so handle it.voidFaviconHandler.handle(RoutingContext event) Something has happened, so handle it.voidFormLoginHandler.handle(RoutingContext event) Something has happened, so handle it.voidHSTSHandler.handle(RoutingContext event) Something has happened, so handle it.voidInputTrustHandler.handle(RoutingContext event) Something has happened, so handle it.voidJWTAuthHandler.handle(RoutingContext event) Something has happened, so handle it.voidLoggerHandler.handle(RoutingContext event) Something has happened, so handle it.voidMethodOverrideHandler.handle(RoutingContext event) Something has happened, so handle it.voidMultiTenantHandler.handle(RoutingContext event) Something has happened, so handle it.voidOAuth2AuthHandler.handle(RoutingContext event) Something has happened, so handle it.voidOtpAuthHandler.handle(RoutingContext event) Something has happened, so handle it.voidPlatformHandler.handle(RoutingContext event) Something has happened, so handle it.voidProtocolUpgradeHandler.handle(RoutingContext event) Something has happened, so handle it.voidRedirectAuthHandler.handle(RoutingContext event) Something has happened, so handle it.voidResponseContentTypeHandler.handle(RoutingContext event) Something has happened, so handle it.voidResponseTimeHandler.handle(RoutingContext event) Something has happened, so handle it.voidSecurityAuditLoggerHandler.handle(RoutingContext event) Something has happened, so handle it.voidSecurityPolicyHandler.handle(RoutingContext event) Something has happened, so handle it.voidSessionHandler.handle(RoutingContext event) Something has happened, so handle it.voidSimpleAuthenticationHandler.handle(RoutingContext event) Something has happened, so handle it.voidStaticHandler.handle(RoutingContext event) Something has happened, so handle it.voidTemplateHandler.handle(RoutingContext event) Something has happened, so handle it.voidTimeoutHandler.handle(RoutingContext event) Something has happened, so handle it.voidWebAuthn4JHandler.handle(RoutingContext event) Something has happened, so handle it.voidXFrameHandler.handle(RoutingContext event) Something has happened, so handle it.SessionHandler.newSession(RoutingContext context) Create a new sessionio.reactivex.rxjava3.core.CompletableSessionHandler.rxFlush(RoutingContext ctx) Flush a context session earlier to the store, this will allow the end user to have full control on the event of a failure at the store level.io.reactivex.rxjava3.core.CompletableSessionHandler.rxFlush(RoutingContext ctx, boolean ignoreStatus) Flush a context session earlier to the store, this will allow the end user to have full control on the event of a failure at the store level.io.reactivex.rxjava3.core.CompletableSessionHandler.rxSetUser(RoutingContext context, User user) Set the user for the sessionio.reactivex.rxjava3.core.CompletableSessionHandler.setUser(RoutingContext context, User user) Set the user for the sessionMethod parameters in io.vertx.rxjava3.ext.web.handler with type arguments of type RoutingContextModifier and TypeMethodDescriptionMultiTenantHandler.addDefaultHandler(Handler<RoutingContext> handler) Add a default handler for the case when no tenant was matched.MultiTenantHandler.addTenantHandler(String tenant, Handler<RoutingContext> handler) Add a handler for a given tenant to this handler.SimpleAuthenticationHandler.authenticate(Function<RoutingContext, io.reactivex.rxjava3.core.Single<User>> authenticationFunction) This function will allow you to perform authentication the way you intended to.static MultiTenantHandlerMultiTenantHandler.create(Function<RoutingContext, String> tenantExtractor) Create a MultiTenant handler using a custom tenant extraction function.static MultiTenantHandlerMultiTenantHandler.create(Function<RoutingContext, String> tenantExtractor, String contextKey) Create a MultiTenant handler using a custom tenant extraction function. -
Uses of RoutingContext in io.vertx.rxjava3.ext.web.handler.graphql
Methods in io.vertx.rxjava3.ext.web.handler.graphql with parameters of type RoutingContextModifier and TypeMethodDescriptionvoidGraphQLHandler.handle(RoutingContext event) Something has happened, so handle it.Method parameters in io.vertx.rxjava3.ext.web.handler.graphql with type arguments of type RoutingContextModifier and TypeMethodDescriptionGraphiQLHandlerBuilder.addingHeaders(Function<RoutingContext, MultiMap> factory) Customize the HTTP headers to add to GraphQL requests sent by the GraphiQL user interface.GraphQLHandlerBuilder.beforeExecute(Handler<ExecutionInputBuilderWithContext<RoutingContext>> beforeExecuteHandler) Set a callback to invoke before executing a GraphQL query. -
Uses of RoutingContext in io.vertx.rxjava3.ext.web.handler.graphql.ws
Methods in io.vertx.rxjava3.ext.web.handler.graphql.ws with parameters of type RoutingContextModifier and TypeMethodDescriptionvoidGraphQLWSHandler.handle(RoutingContext event) Something has happened, so handle it. -
Uses of RoutingContext in io.vertx.rxjava3.ext.web.handler.sockjs
Methods in io.vertx.rxjava3.ext.web.handler.sockjs that return RoutingContext -
Uses of RoutingContext in io.vertx.rxjava3.ext.web.healthchecks
Methods in io.vertx.rxjava3.ext.web.healthchecks with parameters of type RoutingContextModifier and TypeMethodDescriptionvoidHealthCheckHandler.handle(RoutingContext event) Something has happened, so handle it. -
Uses of RoutingContext in io.vertx.rxjava3.ext.web.openapi.router
Methods in io.vertx.rxjava3.ext.web.openapi.router with parameters of type RoutingContextModifier and TypeMethodDescriptionio.reactivex.rxjava3.core.Single<ValidatableRequest>RequestExtractor.extractValidatableRequest(RoutingContext routingContext, Operation operation) Extracts and transforms the parameters and the body of an incoming request into a that can be validated by theRequestValidator.io.reactivex.rxjava3.core.Single<ValidatableRequest>RequestExtractor.rxExtractValidatableRequest(RoutingContext routingContext, Operation operation) Extracts and transforms the parameters and the body of an incoming request into a that can be validated by theRequestValidator.Method parameters in io.vertx.rxjava3.ext.web.openapi.router with type arguments of type RoutingContextModifier and TypeMethodDescriptionOpenAPIRoute.addFailureHandler(Handler<RoutingContext> handler) Adds a failure handler for this routeOpenAPIRoute.addHandler(Handler<RoutingContext> handler) Adds a handler for this route which is executed after the security and validation handlers defined in the contractRouterBuilder.rootHandler(Handler<RoutingContext> rootHandler) Add global handler to be applied prior to being generated. -
Uses of RoutingContext in io.vertx.rxjava3.ext.web.proxy.handler
Methods in io.vertx.rxjava3.ext.web.proxy.handler with parameters of type RoutingContextModifier and TypeMethodDescriptionvoidProxyHandler.handle(RoutingContext event) Something has happened, so handle it. -
Uses of RoutingContext in io.vertx.rxjava3.ext.web.validation
Methods in io.vertx.rxjava3.ext.web.validation with parameters of type RoutingContextModifier and TypeMethodDescriptionRequestPredicate.apply(RoutingContext in) voidValidationHandler.handle(RoutingContext event) Something has happened, so handle it. -
Uses of RoutingContext in io.vertx.rxjava3.micrometer
Methods in io.vertx.rxjava3.micrometer that return types with arguments of type RoutingContextModifier and TypeMethodDescriptionstatic Handler<RoutingContext>PrometheusScrapingHandler.create()Creates a Vert.x WebRoutehandler for Prometheus metrics scraping.static Handler<RoutingContext>PrometheusScrapingHandler.create(io.micrometer.prometheusmetrics.PrometheusMeterRegistry registry) Creates a Vert.x WebRoutehandler for Prometheus metrics scraping.static Handler<RoutingContext>Creates a Vert.x WebRoutehandler for Prometheus metrics scraping.