Uses of Class
io.vertx.rxjava3.ext.web.Session
Packages that use Session
Package
Description
-
Uses of Session in io.vertx.rxjava3.ext.web
Fields in io.vertx.rxjava3.ext.web with type parameters of type SessionMethods in io.vertx.rxjava3.ext.web that return SessionModifier and TypeMethodDescriptionSession.computeIfAbsent(String key, Function<String, Object> mappingFunction) Put some data in a session if absent.static SessionSession.newInstance(Session arg) Put some data in a sessionSession.putIfAbsent(String key, Object obj) Put some data in a session if absentSession.regenerateId()RoutingContext.session()Get the session. -
Uses of Session in io.vertx.rxjava3.ext.web.handler
Methods in io.vertx.rxjava3.ext.web.handler that return SessionModifier and TypeMethodDescriptionSessionHandler.newSession(RoutingContext context) Create a new session -
Uses of Session in io.vertx.rxjava3.ext.web.handler.sockjs
Methods in io.vertx.rxjava3.ext.web.handler.sockjs that return Session -
Uses of Session in io.vertx.rxjava3.ext.web.sstore
Methods in io.vertx.rxjava3.ext.web.sstore that return SessionModifier and TypeMethodDescriptionSessionStore.createSession(long timeout) Create a new session using the default min length.SessionStore.createSession(long timeout, int length) Create a new session.Methods in io.vertx.rxjava3.ext.web.sstore that return types with arguments of type SessionModifier and TypeMethodDescriptionio.reactivex.rxjava3.core.Maybe<Session>Get the session with the specified ID.io.reactivex.rxjava3.core.Maybe<Session>Get the session with the specified ID.Methods in io.vertx.rxjava3.ext.web.sstore with parameters of type Session