Uses of Class
io.vertx.rxjava3.ext.web.client.HttpResponse
Packages that use HttpResponse
-
Uses of HttpResponse in io.vertx.rxjava3.ext.web.client
Fields in io.vertx.rxjava3.ext.web.client with type parameters of type HttpResponseMethods in io.vertx.rxjava3.ext.web.client that return HttpResponseModifier and TypeMethodDescriptionstatic <T> HttpResponse<T>HttpResponse.newInstance(HttpResponse arg) static <T> HttpResponse<T>HttpResponse.newInstance(HttpResponse arg, TypeArg<T> __typeArg_T) Methods in io.vertx.rxjava3.ext.web.client that return types with arguments of type HttpResponseModifier and TypeMethodDescriptionio.reactivex.rxjava3.core.Single<HttpResponse<T>>HttpRequest.rxSend()Send a request, thehandlerwill receive the response as anHttpResponse.io.reactivex.rxjava3.core.Single<HttpResponse<T>>HttpRequest.rxSendBuffer(Buffer body) LikeHttpRequest.send()but with an HTTP requestbodybuffer.io.reactivex.rxjava3.core.Single<HttpResponse<T>>HttpRequest.rxSendForm(MultiMap body) LikeHttpRequest.send()but with an HTTP requestbodymultimap encoded as form and the content type set toapplication/x-www-form-urlencoded.io.reactivex.rxjava3.core.Single<HttpResponse<T>>HttpRequest.rxSendForm(MultiMap body, String charset) LikeHttpRequest.send()but with an HTTP requestbodymultimap encoded as form and the content type set toapplication/x-www-form-urlencoded.io.reactivex.rxjava3.core.Single<HttpResponse<T>>HttpRequest.rxSendJson(Object body) LikeHttpRequest.send()but with an HTTP requestbodyobject encoded as json and the content type set toapplication/json.io.reactivex.rxjava3.core.Single<HttpResponse<T>>HttpRequest.rxSendJsonObject(JsonObject body) LikeHttpRequest.send()but with an HTTP requestbodyobject encoded as json and the content type set toapplication/json.io.reactivex.rxjava3.core.Single<HttpResponse<T>>HttpRequest.rxSendMultipartForm(MultipartForm body) LikeHttpRequest.send()but with an HTTP requestbodymultimap encoded as form and the content type set tomultipart/form-data.io.reactivex.rxjava3.core.Single<HttpResponse<T>>HttpRequest.rxSendStream(io.reactivex.rxjava3.core.Flowable<Buffer> body) LikeHttpRequest.send()but with an HTTP requestbodystream.io.reactivex.rxjava3.core.Single<HttpResponse<T>>HttpRequest.send()Send a request, thehandlerwill receive the response as anHttpResponse.io.reactivex.rxjava3.core.Single<HttpResponse<T>>HttpRequest.sendBuffer(Buffer body) LikeHttpRequest.send()but with an HTTP requestbodybuffer.io.reactivex.rxjava3.core.Single<HttpResponse<T>>LikeHttpRequest.send()but with an HTTP requestbodymultimap encoded as form and the content type set toapplication/x-www-form-urlencoded.io.reactivex.rxjava3.core.Single<HttpResponse<T>>LikeHttpRequest.send()but with an HTTP requestbodymultimap encoded as form and the content type set toapplication/x-www-form-urlencoded.io.reactivex.rxjava3.core.Single<HttpResponse<T>>LikeHttpRequest.send()but with an HTTP requestbodyobject encoded as json and the content type set toapplication/json.io.reactivex.rxjava3.core.Single<HttpResponse<T>>HttpRequest.sendJsonObject(JsonObject body) LikeHttpRequest.send()but with an HTTP requestbodyobject encoded as json and the content type set toapplication/json.io.reactivex.rxjava3.core.Single<HttpResponse<T>>HttpRequest.sendMultipartForm(MultipartForm body) LikeHttpRequest.send()but with an HTTP requestbodymultimap encoded as form and the content type set tomultipart/form-data.io.reactivex.rxjava3.core.Single<HttpResponse<T>>HttpRequest.sendStream(io.reactivex.rxjava3.core.Flowable<Buffer> body) LikeHttpRequest.send()but with an HTTP requestbodystream.