Package io.vertx.rxjava3.ext.web.codec
Class BodyCodec<T>
java.lang.Object
io.vertx.rxjava3.ext.web.codec.BodyCodec<T>
- All Implemented Interfaces:
RxDelegate
A codec for encoding and decoding HTTP bodies.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
FieldsModifier and TypeFieldDescription -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbuffer()booleaninthashCode()static <U> BodyCodec<U>Create and return a codec for Java objects encoded using Jackson mapper.static BodyCodec<JsonObject>jsonStream(JsonParser parser) A body codec that parse the response as a JSON stream.static <T> BodyCodec<T>newInstance(BodyCodec arg) static <T> BodyCodec<T>newInstance(BodyCodec arg, TypeArg<T> __typeArg_T) none()pipe(WriteStream<Buffer> stream) A body codec that pipes the body to a write stream.pipe(WriteStream<Buffer> stream, boolean close) A body codec that pipes the body to a write stream.sseStream(Handler<ReadStream<SseEvent>> handler) A body codec that parse the response as a Server-SentEvent stream.static <T> BodyCodec<T>Create a codec that buffers the entire body and then apply thedecodefunction and returns the result.string()A codec for strings using a specificencoding.toString()
-
Field Details
-
__TYPE_ARG
-
__typeArg_0
-
-
Constructor Details
-
BodyCodec
-
BodyCodec
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
string
- Returns:
- the UTF-8 string codec
-
string
A codec for strings using a specificencoding.- Parameters:
encoding- the encoding- Returns:
- the codec
-
buffer
- Returns:
- the codec
-
jsonObject
- Returns:
- the codec
-
jsonArray
- Returns:
- the codec
-
json
Create and return a codec for Java objects encoded using Jackson mapper.- Parameters:
type-- Returns:
- a codec for mapping POJO to Json
-
none
- Returns:
- a codec that simply discards the response
-
stream
Create a codec that buffers the entire body and then apply thedecodefunction and returns the result.- Parameters:
decode- the decode function- Returns:
- the created codec
-
pipe
A body codec that pipes the body to a write stream. Same as pipe(stream, true).- Parameters:
stream- the destination stream- Returns:
- the body codec for a write stream
-
pipe
A body codec that pipes the body to a write stream.- Parameters:
stream- the destination streamclose- whether the destination stream should be closed- Returns:
- the body codec for a write stream
-
jsonStream
A body codec that parse the response as a JSON stream.- Parameters:
parser- the non-null JSON parser to emits the JSON object. The parser must be configured for the stream. Not e that you need to keep a reference on the parser to retrieved the JSON events.- Returns:
- the body codec for a write stream
-
sseStream
A body codec that parse the response as a Server-SentEvent stream.- Parameters:
handler- the non-nullhandlerfor the stream of Server-Sent Events.- Returns:
- the body codec for a write stream
-
newInstance
-
newInstance
-