Package io.vertx.rxjava3.ext.web.handler
Interface AuthenticationHandler
- All Superinterfaces:
Handler<RoutingContext>,RxDelegate
- All Known Implementing Classes:
APIKeyHandler,BasicAuthHandler,ChainAuthHandler,DigestAuthHandler,FormLoginHandler,JWTAuthHandler,OAuth2AuthHandler,OtpAuthHandler,RedirectAuthHandler,SimpleAuthenticationHandler,WebAuthn4JHandler
Base interface for auth handlers.
An auth handler allows your application to provide authentication support.
An Auth handler may require a SessionHandler to be on the routing chain before it.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Method Summary
Modifier and TypeMethodDescriptionvoidhandle(RoutingContext event) Something has happened, so handle it.static AuthenticationHandler
-
Method Details
-
getDelegate
AuthenticationHandler getDelegate()- Specified by:
getDelegatein interfaceRxDelegate
-
handle
Something has happened, so handle it.- Specified by:
handlein interfaceHandler<RoutingContext>- Parameters:
event- the event to handle
-
newInstance
-