Class ChainAuthHandler

java.lang.Object
io.vertx.rxjava3.ext.web.handler.ChainAuthHandler
All Implemented Interfaces:
Handler<RoutingContext>, RxDelegate, AuthenticationHandler

public class ChainAuthHandler extends Object implements RxDelegate, AuthenticationHandler, Handler<RoutingContext>
An auth handler that chains to a sequence of handlers.

NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.