Package io.vertx.rxjava3.ext.web.handler
Class DigestAuthHandler
java.lang.Object
io.vertx.rxjava3.ext.web.handler.DigestAuthHandler
- All Implemented Interfaces:
Handler<RoutingContext>,RxDelegate,AuthenticationHandler
public class DigestAuthHandler
extends Object
implements RxDelegate, AuthenticationHandler, Handler<RoutingContext>
An auth handler that provides HTTP Basic Authentication support.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final TypeArg<DigestAuthHandler>static final longThe default nonce expire timeout to use in milliseconds. -
Constructor Summary
ConstructorsConstructorDescriptionDigestAuthHandler(DigestAuthHandler delegate) DigestAuthHandler(Object delegate) -
Method Summary
Modifier and TypeMethodDescriptionstatic DigestAuthHandlercreate(io.vertx.rxjava3.core.Vertx vertx, HtdigestAuth authProvider) Create a digest auth handlerstatic DigestAuthHandlercreate(io.vertx.rxjava3.core.Vertx vertx, HtdigestAuth authProvider, long nonceExpireTimeout) Create a digest auth handler, specifying the expire timeout for nonces.booleanvoidhandle(RoutingContext event) Something has happened, so handle it.inthashCode()static DigestAuthHandlertoString()
-
Field Details
-
__TYPE_ARG
-
DEFAULT_NONCE_EXPIRE_TIMEOUT
public static final long DEFAULT_NONCE_EXPIRE_TIMEOUTThe default nonce expire timeout to use in milliseconds.- See Also:
-
-
Constructor Details
-
DigestAuthHandler
-
DigestAuthHandler
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceAuthenticationHandler- Specified by:
getDelegatein interfaceRxDelegate
-
handle
Something has happened, so handle it.- Specified by:
handlein interfaceAuthenticationHandler- Specified by:
handlein interfaceHandler<RoutingContext>- Parameters:
event- the event to handle
-
create
public static DigestAuthHandler create(io.vertx.rxjava3.core.Vertx vertx, HtdigestAuth authProvider) Create a digest auth handler- Parameters:
vertx- the vertx instanceauthProvider- the auth provider to use- Returns:
- the auth handler
-
create
public static DigestAuthHandler create(io.vertx.rxjava3.core.Vertx vertx, HtdigestAuth authProvider, long nonceExpireTimeout) Create a digest auth handler, specifying the expire timeout for nonces.- Parameters:
vertx- the vertx instanceauthProvider- the auth service to usenonceExpireTimeout- the nonce expire timeout in milliseconds.- Returns:
- the auth handler
-
newInstance
-