Package io.vertx.rxjava3.ext.web.handler
Interface InputTrustHandler
- All Superinterfaces:
Handler<RoutingContext>,RxDelegate
- All Known Implementing Classes:
CSRFHandler
Base input trust interface for handlers that verify the trust of the request. Do not confuse trust and authorization.
Trusted input by means of
Cross-Site Request Forgery as an example, gives the application guarantees about
the integrity of the data. It does not replace proper AuthorizationHandler checks.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Method Summary
Modifier and TypeMethodDescriptionvoidhandle(RoutingContext event) Something has happened, so handle it.static InputTrustHandler
-
Method Details
-
getDelegate
InputTrustHandler getDelegate()- Specified by:
getDelegatein interfaceRxDelegate
-
handle
Something has happened, so handle it.- Specified by:
handlein interfaceHandler<RoutingContext>- Parameters:
event- the event to handle
-
newInstance
-