Package io.vertx.rxjava3.ext.web.handler
Class LoggerFormatter
java.lang.Object
io.vertx.rxjava3.ext.web.handler.LoggerFormatter
- All Implemented Interfaces:
RxDelegate
Implement to format the output of the
LoggerHandler
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleanformat(RoutingContext routingContext, long ms) Formats and returns the log statementinthashCode()static LoggerFormattertoString()
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
LoggerFormatter
-
LoggerFormatter
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
format
Formats and returns the log statement- Parameters:
routingContext- The routing contextms- The number of milliseconds since first receiving the request- Returns:
- The formatted string to log
-
newInstance
-