Class LoggerHandler

java.lang.Object
io.vertx.rxjava3.ext.web.handler.LoggerHandler
All Implemented Interfaces:
Handler<RoutingContext>, RxDelegate, PlatformHandler

public class LoggerHandler extends Object implements RxDelegate, PlatformHandler, Handler<RoutingContext>
A handler which logs request information to the Vert.x logger. You should mount this handler before any handler that could fail the routing context. Logs will be produced with the appropriate severity level depending on the status code of the response. To capture the logs configure the logger in your logging configuration with the name: io.vertx.ext.web.handler.LoggerHandler.

NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.

  • Field Details

  • Constructor Details

    • LoggerHandler

      public LoggerHandler(LoggerHandler delegate)
    • LoggerHandler

      public LoggerHandler(Object delegate)
  • Method Details