Package io.vertx.rxjava3.ext.web.handler
Interface PlatformHandler
- All Superinterfaces:
Handler<RoutingContext>,RxDelegate
- All Known Implementing Classes:
FaviconHandler,LoggerHandler,MethodOverrideHandler,ResponseContentTypeHandler,ResponseTimeHandler,SecurityAuditLoggerHandler,SessionHandler,TimeoutHandler
Base platform interface for handlers that provide functionality to the application platform.
Two examples are:
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Method Summary
Modifier and TypeMethodDescriptionvoidhandle(RoutingContext event) Something has happened, so handle it.static PlatformHandler
-
Method Details
-
getDelegate
PlatformHandler getDelegate()- Specified by:
getDelegatein interfaceRxDelegate
-
handle
Something has happened, so handle it.- Specified by:
handlein interfaceHandler<RoutingContext>- Parameters:
event- the event to handle
-
newInstance
-