Package io.vertx.rxjava3.ext.web.handler
Interface ProtocolUpgradeHandler
- All Superinterfaces:
Handler<RoutingContext>,RxDelegate
- All Known Implementing Classes:
GraphQLWSHandler
Base interface for handlers that perform protocol upgrades.
Sub-interfaces hint vert.x core that we should hold the request. This allows later parsing. It can be available
during the upgrade, even if there are asynchronous calls in between.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Method Summary
Modifier and TypeMethodDescriptionvoidhandle(RoutingContext event) Something has happened, so handle it.static ProtocolUpgradeHandler
-
Method Details
-
getDelegate
ProtocolUpgradeHandler getDelegate()- Specified by:
getDelegatein interfaceRxDelegate
-
handle
Something has happened, so handle it.- Specified by:
handlein interfaceHandler<RoutingContext>- Parameters:
event- the event to handle
-
newInstance
-