Class TimeoutHandler

java.lang.Object
io.vertx.rxjava3.ext.web.handler.TimeoutHandler
All Implemented Interfaces:
Handler<RoutingContext>, RxDelegate, PlatformHandler

public class TimeoutHandler extends Object implements RxDelegate, PlatformHandler, Handler<RoutingContext>
Handler that will timeout requests if the response has not been written after a certain time. Timeout requests will be ended with an HTTP status code `503`.

NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.