Uses of Class
io.vertx.rxjava3.ext.web.handler.FaviconHandler
Packages that use FaviconHandler
-
Uses of FaviconHandler in io.vertx.rxjava3.ext.web.handler
Fields in io.vertx.rxjava3.ext.web.handler with type parameters of type FaviconHandlerMethods in io.vertx.rxjava3.ext.web.handler that return FaviconHandlerModifier and TypeMethodDescriptionstatic FaviconHandlerFaviconHandler.create(io.vertx.rxjava3.core.Vertx vertx) Create a handler with defaultsstatic FaviconHandlerFaviconHandler.create(io.vertx.rxjava3.core.Vertx vertx, long maxAgeSeconds) Create a handler with the specified max cache timestatic FaviconHandlerCreate a handler attempting to load favicon file from the specified pathstatic FaviconHandlerCreate a handler attempting to load favicon file from the specified path, and with the specified max cache timestatic FaviconHandlerFaviconHandler.newInstance(FaviconHandler arg)