Class ConnectionInitEvent

java.lang.Object
io.vertx.rxjava3.core.Promise<Object>
io.vertx.rxjava3.ext.web.handler.graphql.ws.ConnectionInitEvent
All Implemented Interfaces:
RxDelegate

public class ConnectionInitEvent extends io.vertx.rxjava3.core.Promise<Object> implements RxDelegate
  • Field Details

  • Constructor Details

    • ConnectionInitEvent

      public ConnectionInitEvent(ConnectionInitEvent delegate)
    • ConnectionInitEvent

      public ConnectionInitEvent(Object delegate)
  • Method Details

    • toString

      public String toString()
      Overrides:
      toString in class io.vertx.rxjava3.core.Promise<Object>
    • equals

      public boolean equals(Object o)
      Overrides:
      equals in class io.vertx.rxjava3.core.Promise<Object>
    • hashCode

      public int hashCode()
      Overrides:
      hashCode in class io.vertx.rxjava3.core.Promise<Object>
    • getDelegate

      public ConnectionInitEvent getDelegate()
      Specified by:
      getDelegate in interface RxDelegate
      Overrides:
      getDelegate in class io.vertx.rxjava3.core.Promise<Object>
    • complete

      public void complete(Object result, Throwable failure)
      Overrides:
      complete in class io.vertx.rxjava3.core.Promise<Object>
    • complete

      public void complete(Object result)
      Set the result. Any handler will be called, if there is one, and the promise will be marked as completed.

      Any handler set on the associated promise will be called.

      Overrides:
      complete in class io.vertx.rxjava3.core.Promise<Object>
      Parameters:
      result - the result
    • succeed

      public void succeed(Object result)
      Overrides:
      succeed in class io.vertx.rxjava3.core.Promise<Object>
    • tryComplete

      public boolean tryComplete(Object result)
      Like Promise.complete(T, java.lang.Throwable) but returns false when the promise is already completed instead of throwing an IllegalStateException, it returns true otherwise.
      Overrides:
      tryComplete in class io.vertx.rxjava3.core.Promise<Object>
      Parameters:
      result - the result
      Returns:
      false when the future is already completed
    • future

      public io.reactivex.rxjava3.core.Single<Object> future()
      Overrides:
      future in class io.vertx.rxjava3.core.Promise<Object>
      Returns:
      the associated with this promise, it can be used to be aware of the promise completion
    • rxFuture

      public io.reactivex.rxjava3.core.Single<Object> rxFuture()
      Overrides:
      rxFuture in class io.vertx.rxjava3.core.Promise<Object>
      Returns:
      the associated with this promise, it can be used to be aware of the promise completion
    • message

      public Message message()
      Provides message content.
      Returns:
      message
    • handle

      public void handle(AsyncResult<Object> asyncResult)
      Succeed or fail this promise with the event.
      Overrides:
      handle in class io.vertx.rxjava3.core.Promise<Object>
      Parameters:
      asyncResult - the async result to handle
    • newInstance

      public static ConnectionInitEvent newInstance(ConnectionInitEvent arg)