Class BridgeEvent

java.lang.Object
io.vertx.rxjava3.core.Promise<Boolean>
io.vertx.rxjava3.ext.bridge.BaseBridgeEvent
io.vertx.rxjava3.ext.web.handler.sockjs.BridgeEvent
All Implemented Interfaces:
RxDelegate

public class BridgeEvent extends BaseBridgeEvent implements RxDelegate
Represents an event that occurs on the event bus bridge.

Please consult the documentation for a full explanation.

NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.

  • Field Details

  • Constructor Details

    • BridgeEvent

      public BridgeEvent(BridgeEvent delegate)
    • BridgeEvent

      public BridgeEvent(Object delegate)
  • Method Details

    • toString

      public String toString()
      Overrides:
      toString in class BaseBridgeEvent
    • equals

      public boolean equals(Object o)
      Overrides:
      equals in class BaseBridgeEvent
    • hashCode

      public int hashCode()
      Overrides:
      hashCode in class BaseBridgeEvent
    • getDelegate

      public BridgeEvent getDelegate()
      Specified by:
      getDelegate in interface RxDelegate
      Overrides:
      getDelegate in class BaseBridgeEvent
    • complete

      public void complete(Boolean result, Throwable failure)
      Overrides:
      complete in class BaseBridgeEvent
    • complete

      public void complete(Boolean result)
      Set the result. Any handler will be called, if there is one, and the promise will be marked as completed.

      Any handler set on the associated promise will be called.

      Overrides:
      complete in class BaseBridgeEvent
      Parameters:
      result - the result
    • succeed

      public void succeed(Boolean result)
      Overrides:
      succeed in class BaseBridgeEvent
    • tryComplete

      public boolean tryComplete(Boolean result)
      Like Promise.complete(T, java.lang.Throwable) but returns false when the promise is already completed instead of throwing an IllegalStateException, it returns true otherwise.
      Overrides:
      tryComplete in class BaseBridgeEvent
      Parameters:
      result - the result
      Returns:
      false when the future is already completed
    • future

      public io.reactivex.rxjava3.core.Single<Boolean> future()
      Overrides:
      future in class BaseBridgeEvent
      Returns:
      the associated with this promise, it can be used to be aware of the promise completion
    • rxFuture

      public io.reactivex.rxjava3.core.Single<Boolean> rxFuture()
      Overrides:
      rxFuture in class BaseBridgeEvent
      Returns:
      the associated with this promise, it can be used to be aware of the promise completion
    • setRawMessage

      public BridgeEvent setRawMessage(JsonObject message)
      Set the raw JSON message for the event.
      Overrides:
      setRawMessage in class BaseBridgeEvent
      Parameters:
      message - the raw message
      Returns:
      this reference, so it can be used fluently
    • socket

      public SockJSSocket socket()
      Get the SockJSSocket instance corresponding to the event
      Returns:
      the SockJSSocket instance
    • handle

      public void handle(AsyncResult<Boolean> asyncResult)
      Succeed or fail this promise with the event.
      Overrides:
      handle in class BaseBridgeEvent
      Parameters:
      asyncResult - the async result to handle
    • newInstance

      public static BridgeEvent newInstance(BridgeEvent arg)