Class RequestExtractor
java.lang.Object
io.vertx.rxjava3.ext.web.openapi.router.RequestExtractor
- All Implemented Interfaces:
RxDelegate
-
Field Summary
Fields -
Constructor Summary
ConstructorsConstructorDescriptionRequestExtractor(RequestExtractor delegate) RequestExtractor(Object delegate) -
Method Summary
Modifier and TypeMethodDescriptionbooleanio.reactivex.rxjava3.core.Single<ValidatableRequest>extractValidatableRequest(RoutingContext routingContext, Operation operation) Extracts and transforms the parameters and the body of an incoming request into a that can be validated by theRequestValidator.inthashCode()static RequestExtractorio.reactivex.rxjava3.core.Single<ValidatableRequest>rxExtractValidatableRequest(RoutingContext routingContext, Operation operation) Extracts and transforms the parameters and the body of an incoming request into a that can be validated by theRequestValidator.toString()static RequestExtractor
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
RequestExtractor
-
RequestExtractor
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
extractValidatableRequest
public io.reactivex.rxjava3.core.Single<ValidatableRequest> extractValidatableRequest(RoutingContext routingContext, Operation operation) Extracts and transforms the parameters and the body of an incoming request into a that can be validated by theRequestValidator.- Parameters:
routingContext- The routing context of the incoming request.operation- The operation of the related request.- Returns:
- A holding the .
-
rxExtractValidatableRequest
public io.reactivex.rxjava3.core.Single<ValidatableRequest> rxExtractValidatableRequest(RoutingContext routingContext, Operation operation) Extracts and transforms the parameters and the body of an incoming request into a that can be validated by theRequestValidator.- Parameters:
routingContext- The routing context of the incoming request.operation- The operation of the related request.- Returns:
- A holding the .
-
withBodyHandler
- Returns:
- a RequestExtractor that works in case that a BodyHandler was applied to the related route.
-
newInstance
-