Class RequestParameter
java.lang.Object
io.vertx.rxjava3.ext.web.validation.RequestParameter
- All Implemented Interfaces:
RxDelegate
Request parameter holder
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
ConstructorsConstructorDescriptionRequestParameter(RequestParameter delegate) RequestParameter(Object delegate) -
Method Summary
Modifier and TypeMethodDescriptionstatic RequestParameterbooleanget()getFloat()Returns null if value is not a , otherwise it returns valuegetLong()inthashCode()booleanbooleanisBuffer()booleanisEmpty()booleanbooleanbooleanisNull()booleanisNumber()booleanisString()static RequestParametertoString()
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
RequestParameter
-
RequestParameter
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
getString
- Returns:
- null if value is not a
String, otherwise it returns value
-
isString
public boolean isString()- Returns:
- true if value of this instance is a
Stringinstance
-
getInteger
-
getLong
-
getFloat
-
getDouble
-
isNumber
public boolean isNumber()- Returns:
- true if value of this instance is a
Numberinstance
-
getBoolean
- Returns:
- null if value is not a
Boolean, otherwise it returns value
-
isBoolean
public boolean isBoolean()- Returns:
- true if value of this instance is a
Booleaninstance
-
getJsonObject
Returns null if value is not a , otherwise it returns value- Returns:
-
isJsonObject
public boolean isJsonObject()- Returns:
- true if value of this instance is a instance
-
getJsonArray
- Returns:
- null if value is not a , otherwise it returns value
-
isJsonArray
public boolean isJsonArray()- Returns:
- true if value of this instance is a instance
-
getBuffer
- Returns:
- null if value is not a , otherwise it returns value
-
isBuffer
public boolean isBuffer()- Returns:
- true if value of this instance is a instance
-
isNull
public boolean isNull()- Returns:
- true if value is null
-
isEmpty
public boolean isEmpty()- Returns:
- True if it's an empty string, an empty json object/array, an empty buffer or it's null
-
get
- Returns:
- the internal value. The internal value is always a valid Vert.x JSON type
-
create
-
newInstance
-