Class RequestPredicate
java.lang.Object
io.vertx.rxjava3.ext.web.validation.RequestPredicate
- All Implemented Interfaces:
RxDelegate,Function<RoutingContext,RequestPredicateResult>
public class RequestPredicate
extends Object
implements RxDelegate, Function<RoutingContext,RequestPredicateResult>
Request predicate
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final TypeArg<RequestPredicate>static final RequestPredicateRequest predicate that checks if body exists or not -
Constructor Summary
ConstructorsConstructorDescriptionRequestPredicate(RequestPredicate delegate) RequestPredicate(Object delegate) -
Method Summary
Modifier and TypeMethodDescriptionapply(RoutingContext in) booleaninthashCode()static RequestPredicatemultipartFileUploadExists(String propertyName, String contentTypePattern) Generate request predicate that checks if a particular multipart file upload withpropertyNameand matchingcontentTypePatternexistsstatic RequestPredicatetoString()
-
Field Details
-
__TYPE_ARG
-
BODY_REQUIRED
Request predicate that checks if body exists or not
-
-
Constructor Details
-
RequestPredicate
-
RequestPredicate
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
apply
- Specified by:
applyin interfaceFunction<RoutingContext,RequestPredicateResult>
-
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
multipartFileUploadExists
public static RequestPredicate multipartFileUploadExists(String propertyName, String contentTypePattern) Generate request predicate that checks if a particular multipart file upload withpropertyNameand matchingcontentTypePatternexists- Parameters:
propertyName-contentTypePattern-- Returns:
-
newInstance
-