Class ParameterProcessorFactory

java.lang.Object
io.vertx.rxjava3.ext.web.validation.builder.ParameterProcessorFactory
All Implemented Interfaces:
RxDelegate

public class ParameterProcessorFactory extends Object implements RxDelegate
This interface is used to build parameter processors supported on every . You can use in query and cookie more complex parameters with StyledParameterProcessorFactory.

Look at Parameters for all available factories

NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.