Class StyledParameterProcessorFactory
java.lang.Object
io.vertx.rxjava3.ext.web.validation.builder.StyledParameterProcessorFactory
- All Implemented Interfaces:
RxDelegate
This interface is used to build complex parameter processors supported only in cookie & query.
Look at Parameters for all available factories
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionio.vertx.ext.web.validation.impl.parameter.ParameterProcessorcreate(io.vertx.ext.web.validation.impl.ParameterLocation location, SchemaRepository repository) booleaninthashCode()toString()
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
StyledParameterProcessorFactory
-
StyledParameterProcessorFactory
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
create
public io.vertx.ext.web.validation.impl.parameter.ParameterProcessor create(io.vertx.ext.web.validation.impl.ParameterLocation location, SchemaRepository repository) -
newInstance
-