Class TupleParserFactory

java.lang.Object
io.vertx.rxjava3.ext.web.validation.builder.TupleParserFactory
All Implemented Interfaces:
RxDelegate

public class TupleParserFactory extends Object implements RxDelegate
This interface is used to create able to parse serialized object structures.
Look at Parsers for all available factories

NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.