Uses of Class
io.vertx.rxjava3.grpc.client.GrpcClientBuilder
Packages that use GrpcClientBuilder
-
Uses of GrpcClientBuilder in io.vertx.rxjava3.grpc.client
Fields in io.vertx.rxjava3.grpc.client with type parameters of type GrpcClientBuilderModifier and TypeFieldDescriptionstatic final TypeArg<GrpcClientBuilder>GrpcClientBuilder.__TYPE_ARGMethods in io.vertx.rxjava3.grpc.client that return GrpcClientBuilderModifier and TypeMethodDescriptionstatic GrpcClientBuilder<GrpcClient>GrpcClient.builder(io.vertx.rxjava3.core.Vertx vertx) Provide a builder forGrpcClient, it can be used to configure advanced client settings like a load balancer or an address resolver.static <C> GrpcClientBuilder<C>GrpcClientBuilder.newInstance(GrpcClientBuilder arg) static <C> GrpcClientBuilder<C>GrpcClientBuilder.newInstance(GrpcClientBuilder arg, TypeArg<C> __typeArg_C) GrpcClientBuilder.with(HttpClientConfig transportConfig) Configure the client HTTP transport options.GrpcClientBuilder.with(HttpClientOptions transportOptions) Configure the client HTTP transport options.GrpcClientBuilder.with(ClientSSLOptions sslOptions) Configure the client HTTP transport options.GrpcClientBuilder.with(GrpcClientOptions options) Configure the client options.GrpcClientBuilder.withAddressResolver(AddressResolver resolver) Configure the client to use a specific address resolver.GrpcClientBuilder.withLoadBalancer(LoadBalancer loadBalancer) Configure the client to use a load balancer.