Class ServiceContainer

java.lang.Object
io.vertx.rxjava3.grpc.server.ServiceContainer
All Implemented Interfaces:
RxDelegate
Direct Known Subclasses:
GrpcServer

public class ServiceContainer extends Object implements RxDelegate
A contract for registering gRPC service method handlers, without requiring a specific transport.

Generated gRPC service stubs use this interface as their binding abstraction, allowing them to work with any implementation - HTTP/2 via GrpcServer, event bus, etc.

NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.

  • Field Details

  • Constructor Details

    • ServiceContainer

      public ServiceContainer(ServiceContainer delegate)
    • ServiceContainer

      public ServiceContainer(Object delegate)
  • Method Details