Package io.vertx.rxjava3.httpproxy
Class BodyTransformer
java.lang.Object
io.vertx.rxjava3.httpproxy.BodyTransformer
- All Implemented Interfaces:
RxDelegate
A synchronous function that transforms an HTTP body entity.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleanbooleaninthashCode()static BodyTransformertoString()
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
BodyTransformer
-
BodyTransformer
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
consumes
- Parameters:
mediaType-- Returns:
- whether this transformer consumes the
mediaType,mediaTypecan benullwhen the HTTP head does not present a body, the default implementation returnstrue
-
produces
- Parameters:
mediaType-- Returns:
- the media type produced by this transformer, the default implementation returns the same media type
-
newInstance
-