Package io.vertx.rxjava3.httpproxy
Class ProxyContext
java.lang.Object
io.vertx.rxjava3.httpproxy.ProxyContext
- All Implemented Interfaces:
RxDelegate
A controller for proxy interception.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionclient()boolean<T> TGet a payload attached to this context.inthashCode()booleanstatic ProxyContextnewInstance(ProxyContext arg) request()response()io.reactivex.rxjava3.core.Single<ProxyResponse>io.reactivex.rxjava3.core.Completableio.reactivex.rxjava3.core.Single<ProxyResponse>io.reactivex.rxjava3.core.CompletablevoidAttach a payload to the context.toString()
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
ProxyContext
-
ProxyContext
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
request
- Returns:
- the proxy request
-
response
- Returns:
- the proxy response, it might be
nullif the response has not been sent
-
sendRequest
- Returns:
-
rxSendRequest
- Returns:
-
sendResponse
public io.reactivex.rxjava3.core.Completable sendResponse()- Returns:
-
rxSendResponse
public io.reactivex.rxjava3.core.Completable rxSendResponse()- Returns:
-
isWebSocket
public boolean isWebSocket()- Returns:
- if this request or response is the handshake of WebSocket
-
set
Attach a payload to the context.- Parameters:
name- the payload namevalue- any payload value
-
get
Get a payload attached to this context.- Parameters:
name- the payload nametype- the expected payload type- Returns:
- the attached payload
-
client
- Returns:
- the use to interact with the origin server
-
newInstance
-