Class ProxyInterceptor

java.lang.Object
io.vertx.rxjava3.httpproxy.ProxyInterceptor
All Implemented Interfaces:
RxDelegate

public class ProxyInterceptor extends Object implements RxDelegate
A HttpProxy interceptor.

NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.

  • Field Details

  • Constructor Details

    • ProxyInterceptor

      public ProxyInterceptor(ProxyInterceptor delegate)
    • ProxyInterceptor

      public ProxyInterceptor(Object delegate)
  • Method Details

    • toString

      public String toString()
      Overrides:
      toString in class Object
    • equals

      public boolean equals(Object o)
      Overrides:
      equals in class Object
    • hashCode

      public int hashCode()
      Overrides:
      hashCode in class Object
    • getDelegate

      public ProxyInterceptor getDelegate()
      Specified by:
      getDelegate in interface RxDelegate
    • builder

      public static ProxyInterceptorBuilder builder()
      Create a builder for implementing common HTTP interception hooks such as modifying headers or transforming the HTTP entity stream.
      Returns:
      a builder for common interception
    • handleProxyRequest

      public io.reactivex.rxjava3.core.Single<ProxyResponse> handleProxyRequest(ProxyContext context)
      Handle the proxy request at the stage of this interceptor.
      Parameters:
      context - the proxy context
      Returns:
      when the request has actually been sent to the origin
    • rxHandleProxyRequest

      public io.reactivex.rxjava3.core.Single<ProxyResponse> rxHandleProxyRequest(ProxyContext context)
      Handle the proxy request at the stage of this interceptor.
      Parameters:
      context - the proxy context
      Returns:
      when the request has actually been sent to the origin
    • handleProxyResponse

      public io.reactivex.rxjava3.core.Completable handleProxyResponse(ProxyContext context)
      Handle the proxy response at the stage of this interceptor.
      Parameters:
      context - the proxy context
      Returns:
      when the response has actually been sent to the user-agent
    • rxHandleProxyResponse

      public io.reactivex.rxjava3.core.Completable rxHandleProxyResponse(ProxyContext context)
      Handle the proxy response at the stage of this interceptor.
      Parameters:
      context - the proxy context
      Returns:
      when the response has actually been sent to the user-agent
    • newInstance

      public static ProxyInterceptor newInstance(ProxyInterceptor arg)