Package io.vertx.rxjava3.httpproxy
Class ProxyResponse
java.lang.Object
io.vertx.rxjava3.httpproxy.ProxyResponse
- All Implemented Interfaces:
RxDelegate
Handles the interoperability of the response between the origin and the user agent.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleanetag()getBody()Get the body of the response.intGet the status code.Get the status message.inthashCode()headers()longmaxAge()static ProxyResponsenewInstance(ProxyResponse arg) booleanrelease()Release the proxy response.request()Return the correspondingProxyRequest.io.reactivex.rxjava3.core.CompletablerxSend()Send the proxies response to the user agent.io.reactivex.rxjava3.core.Completablesend()Send the proxies response to the user agent.Set the request body to be sent to the user agent.setStatusCode(int sc) Set the status code to be sent to the user agent.setStatusMessage(String statusMessage) Set the status message to be sent to the user agent.toString()
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
ProxyResponse
-
ProxyResponse
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
request
Return the correspondingProxyRequest.- Returns:
- the proxy request
-
getStatusCode
public int getStatusCode()Get the status code.- Returns:
- the status code to be sent to the user agent
-
setStatusCode
Set the status code to be sent to the user agent.The initial value is the proxied response status code.
- Parameters:
sc- the status code- Returns:
- a reference to this, so the API can be used fluently
-
getStatusMessage
Get the status message.- Returns:
- the status message to be sent to the user agent
-
setStatusMessage
Set the status message to be sent to the user agent.The initial value is the proxied response status message.
- Parameters:
statusMessage- the status message- Returns:
- a reference to this, so the API can be used fluently
-
headers
- Returns:
- the headers that will be sent to the user agent, the returned headers can be modified. The headers map is populated with the proxied response headers
-
getBody
Get the body of the response.- Returns:
- the response body to be sent to the user agent
-
setBody
Set the request body to be sent to the user agent.The initial request body value is the proxied response body.
- Parameters:
body- the new body- Returns:
- a reference to this, so the API can be used fluently
-
proxiedResponse
- Returns:
- the proxied HTTP server response
-
publicCacheControl
public boolean publicCacheControl() -
maxAge
public long maxAge() -
etag
- Returns:
- the
etagsent by the origin response
-
send
public io.reactivex.rxjava3.core.Completable send()Send the proxies response to the user agent.- Returns:
-
rxSend
public io.reactivex.rxjava3.core.Completable rxSend()Send the proxies response to the user agent.- Returns:
-
release
Release the proxy response.The proxied response is resumed, no HTTP response is sent to the user-agent
- Returns:
-
newInstance
-