Uses of Class
io.vertx.rxjava3.httpproxy.BodyTransformer
Packages that use BodyTransformer
-
Uses of BodyTransformer in io.vertx.rxjava3.httpproxy
Fields in io.vertx.rxjava3.httpproxy with type parameters of type BodyTransformerModifier and TypeFieldDescriptionstatic final TypeArg<BodyTransformer>BodyTransformer.__TYPE_ARGMethods in io.vertx.rxjava3.httpproxy that return BodyTransformerModifier and TypeMethodDescriptionstatic BodyTransformerBodyTransformers.discard()Create a transformer that discards the body, the transformer consumes any media type.static BodyTransformerCreate a body transformer that transforms JSON array to JSON array, the transformer consumes and producesapplication/json.static BodyTransformerLikeBodyTransformers.jsonArray(long, java.util.function.Function<io.vertx.core.json.JsonArray, io.vertx.core.json.JsonArray>)withBodyTransformersmaximum buffered bytes.static BodyTransformerBodyTransformers.jsonObject(long maxBufferedBytes, Function<JsonObject, JsonObject> transformer) Create a body transformer that transforms JSON object to JSON object, the transformer consumes and producesapplication/json.static BodyTransformerBodyTransformers.jsonObject(Function<JsonObject, JsonObject> transformer) LikeBodyTransformers.jsonObject(long, java.util.function.Function<io.vertx.core.json.JsonObject, io.vertx.core.json.JsonObject>)withBodyTransformersmaximum buffered bytes.static BodyTransformerCreate a body transformer that transforms JSON value to JSON value, the transformer consumes and producesapplication/json.static BodyTransformerLikeBodyTransformers.jsonValue(long, java.util.function.Function<java.lang.Object, java.lang.Object>)withBodyTransformersmaximum buffered bytes.static BodyTransformerBodyTransformer.newInstance(BodyTransformer arg) static BodyTransformerCreate a transformer that transforms text to text, the transformer consumes and producestext/plain.static BodyTransformerLikeBodyTransformers.text(long, java.util.function.Function<java.lang.String, java.lang.String>, java.lang.String)withBodyTransformersmaximum buffered bytes.static BodyTransformerBodyTransformers.transform(MediaType consumes, MediaType produces, long maxBufferedBytes, Function<Buffer, Buffer> transformer) Create a body transformer that transformsconsumesmedia type to theproducesmedia type, by applying thetransformerfunction.static BodyTransformerMethods in io.vertx.rxjava3.httpproxy with parameters of type BodyTransformerModifier and TypeMethodDescriptionProxyInterceptorBuilder.transformingRequestBody(BodyTransformer requestTransformer) Apply a transformation to change the request body when the proxy receives it.ProxyInterceptorBuilder.transformingResponseBody(BodyTransformer responseTransformer) Apply a transformation to change the response body when the proxy receives it.