Uses of Class
io.vertx.rxjava3.httpproxy.ProxyContext
Packages that use ProxyContext
-
Uses of ProxyContext in io.vertx.rxjava3.httpproxy
Fields in io.vertx.rxjava3.httpproxy with type parameters of type ProxyContextMethods in io.vertx.rxjava3.httpproxy that return ProxyContextMethods in io.vertx.rxjava3.httpproxy with parameters of type ProxyContextModifier and TypeMethodDescriptionio.reactivex.rxjava3.core.Single<HttpClientRequest>OriginRequestProvider.create(ProxyContext proxyContext) Create the to the origin server for a givenProxyContext.io.reactivex.rxjava3.core.Single<ProxyResponse>ProxyInterceptor.handleProxyRequest(ProxyContext context) Handle the proxy request at the stage of this interceptor.io.reactivex.rxjava3.core.CompletableProxyInterceptor.handleProxyResponse(ProxyContext context) Handle the proxy response at the stage of this interceptor.io.reactivex.rxjava3.core.Single<HttpClientRequest>OriginRequestProvider.rxCreate(ProxyContext proxyContext) Create the to the origin server for a givenProxyContext.io.reactivex.rxjava3.core.Single<ProxyResponse>ProxyInterceptor.rxHandleProxyRequest(ProxyContext context) Handle the proxy request at the stage of this interceptor.io.reactivex.rxjava3.core.CompletableProxyInterceptor.rxHandleProxyResponse(ProxyContext context) Handle the proxy response at the stage of this interceptor.Method parameters in io.vertx.rxjava3.httpproxy with type arguments of type ProxyContextModifier and TypeMethodDescriptionstatic OriginRequestProviderOriginRequestProvider.selector(Function<ProxyContext, io.reactivex.rxjava3.core.Single<SocketAddress>> selector) Creates a provider that selects the origin server based onProxyContext.