Package io.vertx.rxjava3.micrometer
Class PrometheusRequestHandler
java.lang.Object
io.vertx.rxjava3.micrometer.PrometheusRequestHandler
- All Implemented Interfaces:
RxDelegate
An interface for creating handlers to expose Prometheus metrics via an HTTP endpoint.
This interface provides factory methods to create handlers that can scrape metrics from a PrometheusMeterRegistry and serve them over HTTP. It allows for various configurations of the metrics endpoint and the Prometheus registry.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic Handler<HttpServerRequest>create()Creates a handler with a new PrometheusMeterRegistry and the default metrics endpoint ("/metrics").static Handler<HttpServerRequest>create(io.micrometer.prometheusmetrics.PrometheusMeterRegistry registry) Creates a handler with the specified PrometheusMeterRegistry and the default metrics endpoint ("/metrics").static Handler<HttpServerRequest>Creates a handler with the specified PrometheusMeterRegistry and metrics endpoint.booleaninthashCode()static PrometheusRequestHandlertoString()
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
PrometheusRequestHandler
-
PrometheusRequestHandler
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
create
Creates a handler with a new PrometheusMeterRegistry and the default metrics endpoint ("/metrics").This handler scrapes metrics from a newly created PrometheusMeterRegistry and serves them at the default endpoint "/metrics".
- Returns:
- a handler for scraping Prometheus metrics
-
create
public static Handler<HttpServerRequest> create(io.micrometer.prometheusmetrics.PrometheusMeterRegistry registry, String metricsEndpoint) Creates a handler with the specified PrometheusMeterRegistry and metrics endpoint.This handler scrapes metrics from the given PrometheusMeterRegistry and serves them at the specified endpoint.
- Parameters:
registry- the PrometheusMeterRegistry to use for scraping metricsmetricsEndpoint- the endpoint to expose metrics- Returns:
- a handler for scraping Prometheus metrics
-
create
public static Handler<HttpServerRequest> create(io.micrometer.prometheusmetrics.PrometheusMeterRegistry registry) Creates a handler with the specified PrometheusMeterRegistry and the default metrics endpoint ("/metrics").This handler scrapes metrics from the given PrometheusMeterRegistry and serves them at the default endpoint "/metrics".
- Parameters:
registry- the PrometheusMeterRegistry to use for scraping metrics- Returns:
- a handler for scraping Prometheus metrics
-
newInstance
-