Package io.vertx.rxjava3.mssqlclient
Class MSSQLConnection
java.lang.Object
io.vertx.rxjava3.sqlclient.SqlClient
io.vertx.rxjava3.sqlclient.SqlConnection
io.vertx.rxjava3.mssqlclient.MSSQLConnection
- All Implemented Interfaces:
RxDelegate
A connection to Microsoft SQL Server.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic MSSQLConnectioncast(SqlConnection sqlConnection) Cast a toMSSQLConnection.closeHandler(Handler<Void> handler) Set an handler called when the connection is closed.static io.reactivex.rxjava3.core.Single<MSSQLConnection>connect(io.vertx.rxjava3.core.Vertx vertx, MSSQLConnectOptions connectOptions) Create a connection to SQL Server with the givenconnectOptions.static io.reactivex.rxjava3.core.Single<MSSQLConnection>Likeconnect(io.vertx.rxjava3.core.Vertx, io.vertx.mssqlclient.MSSQLConnectOptions)with options built fromconnectionUri.booleanexceptionHandler(Handler<Throwable> handler) Set an handler called with connection errors.inthashCode()infoHandler(Handler<MSSQLInfo> handler) Set a handler called when the connection receives an informational message from the server.static MSSQLConnectionstatic io.reactivex.rxjava3.core.Single<MSSQLConnection>rxConnect(io.vertx.rxjava3.core.Vertx vertx, MSSQLConnectOptions connectOptions) Create a connection to SQL Server with the givenconnectOptions.static io.reactivex.rxjava3.core.Single<MSSQLConnection>Likeconnect(io.vertx.rxjava3.core.Vertx, io.vertx.mssqlclient.MSSQLConnectOptions)with options built fromconnectionUri.toString()Methods inherited from class io.vertx.rxjava3.sqlclient.SqlConnection
begin, databaseMetadata, isSSL, newInstance, prepare, prepare, rxBegin, rxPrepare, rxPrepare, transactionMethods inherited from class io.vertx.rxjava3.sqlclient.SqlClient
close, newInstance, preparedQuery, preparedQuery, query, rxClose
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
MSSQLConnection
-
MSSQLConnection
-
-
Method Details
-
toString
- Overrides:
toStringin classSqlConnection
-
equals
- Overrides:
equalsin classSqlConnection
-
hashCode
public int hashCode()- Overrides:
hashCodein classSqlConnection
-
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate- Overrides:
getDelegatein classSqlConnection
-
connect
public static io.reactivex.rxjava3.core.Single<MSSQLConnection> connect(io.vertx.rxjava3.core.Vertx vertx, MSSQLConnectOptions connectOptions) Create a connection to SQL Server with the givenconnectOptions.- Parameters:
vertx- the vertx instanceconnectOptions- the options for the connection- Returns:
- a future notified with the connection or the failure
-
rxConnect
public static io.reactivex.rxjava3.core.Single<MSSQLConnection> rxConnect(io.vertx.rxjava3.core.Vertx vertx, MSSQLConnectOptions connectOptions) Create a connection to SQL Server with the givenconnectOptions.- Parameters:
vertx- the vertx instanceconnectOptions- the options for the connection- Returns:
- a future notified with the connection or the failure
-
connect
public static io.reactivex.rxjava3.core.Single<MSSQLConnection> connect(io.vertx.rxjava3.core.Vertx vertx, String connectionUri) Likeconnect(io.vertx.rxjava3.core.Vertx, io.vertx.mssqlclient.MSSQLConnectOptions)with options built fromconnectionUri.- Parameters:
vertx-connectionUri-- Returns:
-
rxConnect
public static io.reactivex.rxjava3.core.Single<MSSQLConnection> rxConnect(io.vertx.rxjava3.core.Vertx vertx, String connectionUri) Likeconnect(io.vertx.rxjava3.core.Vertx, io.vertx.mssqlclient.MSSQLConnectOptions)with options built fromconnectionUri.- Parameters:
vertx-connectionUri-- Returns:
-
exceptionHandler
Description copied from class:SqlConnectionSet an handler called with connection errors.- Overrides:
exceptionHandlerin classSqlConnection- Parameters:
handler-- Returns:
-
closeHandler
Description copied from class:SqlConnectionSet an handler called when the connection is closed.- Overrides:
closeHandlerin classSqlConnection- Parameters:
handler-- Returns:
-
infoHandler
Set a handler called when the connection receives an informational message from the server.- Parameters:
handler- the handler- Returns:
- a reference to this, so the API can be used fluently
-
cast
Cast a toMSSQLConnection. This is mostly useful for Vert.x generated APIs like RxJava/Mutiny.- Parameters:
sqlConnection- the connection to cast- Returns:
- a
instance
-
newInstance
-