Uses of Class
io.vertx.rxjava3.mssqlclient.MSSQLConnection
Packages that use MSSQLConnection
-
Uses of MSSQLConnection in io.vertx.rxjava3.mssqlclient
Fields in io.vertx.rxjava3.mssqlclient with type parameters of type MSSQLConnectionModifier and TypeFieldDescriptionstatic final TypeArg<MSSQLConnection>MSSQLConnection.__TYPE_ARGMethods in io.vertx.rxjava3.mssqlclient that return MSSQLConnectionModifier and TypeMethodDescriptionstatic MSSQLConnectionMSSQLConnection.cast(SqlConnection sqlConnection) Cast a toMSSQLConnection.MSSQLConnection.closeHandler(Handler<Void> handler) MSSQLConnection.exceptionHandler(Handler<Throwable> handler) MSSQLConnection.infoHandler(Handler<MSSQLInfo> handler) Set a handler called when the connection receives an informational message from the server.static MSSQLConnectionMSSQLConnection.newInstance(MSSQLConnection arg) Methods in io.vertx.rxjava3.mssqlclient that return types with arguments of type MSSQLConnectionModifier and TypeMethodDescriptionstatic io.reactivex.rxjava3.core.Single<MSSQLConnection>MSSQLConnection.connect(io.vertx.rxjava3.core.Vertx vertx, MSSQLConnectOptions connectOptions) Create a connection to SQL Server with the givenconnectOptions.static io.reactivex.rxjava3.core.Single<MSSQLConnection>Likeconnect(io.vertx.rxjava3.core.Vertx, io.vertx.mssqlclient.MSSQLConnectOptions)with options built fromconnectionUri.static io.reactivex.rxjava3.core.Single<MSSQLConnection>MSSQLConnection.rxConnect(io.vertx.rxjava3.core.Vertx vertx, MSSQLConnectOptions connectOptions) Create a connection to SQL Server with the givenconnectOptions.static io.reactivex.rxjava3.core.Single<MSSQLConnection>Likeconnect(io.vertx.rxjava3.core.Vertx, io.vertx.mssqlclient.MSSQLConnectOptions)with options built fromconnectionUri.