Package io.vertx.rxjava3.mysqlclient
Class MySQLBuilder
java.lang.Object
io.vertx.rxjava3.mysqlclient.MySQLBuilder
- All Implemented Interfaces:
RxDelegate
Entry point for building MySQL clients.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic ClientBuilder<SqlClient>client()Provide a builder for MySQL client backed by a connection pool.static SqlClientclient(Handler<ClientBuilder<SqlClient>> handler) Build a client backed by a connection pool with the specifiedblockargument.booleaninthashCode()static MySQLBuildernewInstance(MySQLBuilder arg) static ClientBuilder<Pool>pool()Provide a builder for MySQL pool of connectionsstatic Poolpool(Handler<ClientBuilder<Pool>> block) Build a pool with the specifiedblockargument.toString()
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
MySQLBuilder
-
MySQLBuilder
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
pool
Build a pool with the specifiedblockargument. Theblockargument is usually a lambda that configures the provided builderExample usage:
Pool pool = PgBuilder.pool(builder -> builder.connectingTo(connectOptions));- Parameters:
block-- Returns:
- the pool as configured by the code
block
-
pool
Provide a builder for MySQL pool of connectionsExample usage:
Pool pool = PgBuilder.pool().connectingTo(connectOptions).build()- Returns:
-
client
Build a client backed by a connection pool with the specifiedblockargument. Theblockargument is usually a lambda that configures the provided builderExample usage:
SqlClient client = PgBuilder.client(builder -> builder.connectingTo(connectOptions));- Parameters:
handler-- Returns:
- the client as configured by the code
block
-
client
Provide a builder for MySQL client backed by a connection pool.Example usage:
SqlClient client = PgBuilder.client().connectingTo(connectOptions).build()- Returns:
-
newInstance
-