Package io.vertx.rxjava3.mysqlclient
Class MySQLConnection
java.lang.Object
io.vertx.rxjava3.sqlclient.SqlClient
io.vertx.rxjava3.sqlclient.SqlConnection
io.vertx.rxjava3.mysqlclient.MySQLConnection
- All Implemented Interfaces:
RxDelegate
An interface which represents a connection to MySQL server.
The connection object supports all the operations defined in the interface, in addition it provides MySQL utility command support:
- COM_PING
- COM_CHANGE_USER
- COM_RESET_CONNECTION
- COM_DEBUG
- COM_INIT_DB
- COM_STATISTICS
- COM_SET_OPTION
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic MySQLConnectioncast(SqlConnection sqlConnection) Cast a toMySQLConnection.io.reactivex.rxjava3.core.CompletablechangeUser(MySQLAuthOptions options) Send a CHANGE_USER command to change the user of the current connection, this operation will also reset connection state.closeHandler(Handler<Void> handler) Set an handler called when the connection is closed.static io.reactivex.rxjava3.core.Single<MySQLConnection>connect(io.vertx.rxjava3.core.Vertx vertx, MySQLConnectOptions connectOptions) Create a connection to MySQL server with the givenconnectOptions.static io.reactivex.rxjava3.core.Single<MySQLConnection>Likeconnect(io.vertx.rxjava3.core.Vertx, io.vertx.mysqlclient.MySQLConnectOptions)with options built fromconnectionUri.io.reactivex.rxjava3.core.Completabledebug()Send a DEBUG command to dump debug information to the server's stdout.booleanexceptionHandler(Handler<Throwable> handler) Set an handler called with connection errors.io.reactivex.rxjava3.core.Single<String>Send a STATISTICS command to get a human readable string of the server internal status.inthashCode()static MySQLConnectionio.reactivex.rxjava3.core.Completableping()Send a PING command to check if the server is alive.io.reactivex.rxjava3.core.CompletableSend a RESET_CONNECTION command to reset the session state.io.reactivex.rxjava3.core.CompletablerxChangeUser(MySQLAuthOptions options) Send a CHANGE_USER command to change the user of the current connection, this operation will also reset connection state.static io.reactivex.rxjava3.core.Single<MySQLConnection>rxConnect(io.vertx.rxjava3.core.Vertx vertx, MySQLConnectOptions connectOptions) Create a connection to MySQL server with the givenconnectOptions.static io.reactivex.rxjava3.core.Single<MySQLConnection>Likeconnect(io.vertx.rxjava3.core.Vertx, io.vertx.mysqlclient.MySQLConnectOptions)with options built fromconnectionUri.io.reactivex.rxjava3.core.CompletablerxDebug()Send a DEBUG command to dump debug information to the server's stdout.io.reactivex.rxjava3.core.Single<String>Send a STATISTICS command to get a human readable string of the server internal status.io.reactivex.rxjava3.core.CompletablerxPing()Send a PING command to check if the server is alive.io.reactivex.rxjava3.core.CompletableSend a RESET_CONNECTION command to reset the session state.io.reactivex.rxjava3.core.CompletablerxSetOption(MySQLSetOption option) Send a SET_OPTION command to set options for the current connection.io.reactivex.rxjava3.core.CompletablerxSpecifySchema(String schemaName) Send a INIT_DB command to change the default schema of the connection.io.reactivex.rxjava3.core.CompletablesetOption(MySQLSetOption option) Send a SET_OPTION command to set options for the current connection.io.reactivex.rxjava3.core.CompletablespecifySchema(String schemaName) Send a INIT_DB command to change the default schema of the connection.toString()Methods inherited from class io.vertx.rxjava3.sqlclient.SqlConnection
begin, databaseMetadata, isSSL, newInstance, prepare, prepare, rxBegin, rxPrepare, rxPrepare, transactionMethods inherited from class io.vertx.rxjava3.sqlclient.SqlClient
close, newInstance, preparedQuery, preparedQuery, query, rxClose
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
MySQLConnection
-
MySQLConnection
-
-
Method Details
-
toString
- Overrides:
toStringin classSqlConnection
-
equals
- Overrides:
equalsin classSqlConnection
-
hashCode
public int hashCode()- Overrides:
hashCodein classSqlConnection
-
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate- Overrides:
getDelegatein classSqlConnection
-
connect
public static io.reactivex.rxjava3.core.Single<MySQLConnection> connect(io.vertx.rxjava3.core.Vertx vertx, MySQLConnectOptions connectOptions) Create a connection to MySQL server with the givenconnectOptions.- Parameters:
vertx- the vertx instanceconnectOptions- the options for the connection- Returns:
- a future notified with the connection or the failure
-
rxConnect
public static io.reactivex.rxjava3.core.Single<MySQLConnection> rxConnect(io.vertx.rxjava3.core.Vertx vertx, MySQLConnectOptions connectOptions) Create a connection to MySQL server with the givenconnectOptions.- Parameters:
vertx- the vertx instanceconnectOptions- the options for the connection- Returns:
- a future notified with the connection or the failure
-
connect
public static io.reactivex.rxjava3.core.Single<MySQLConnection> connect(io.vertx.rxjava3.core.Vertx vertx, String connectionUri) Likeconnect(io.vertx.rxjava3.core.Vertx, io.vertx.mysqlclient.MySQLConnectOptions)with options built fromconnectionUri.- Parameters:
vertx-connectionUri-- Returns:
-
rxConnect
public static io.reactivex.rxjava3.core.Single<MySQLConnection> rxConnect(io.vertx.rxjava3.core.Vertx vertx, String connectionUri) Likeconnect(io.vertx.rxjava3.core.Vertx, io.vertx.mysqlclient.MySQLConnectOptions)with options built fromconnectionUri.- Parameters:
vertx-connectionUri-- Returns:
-
exceptionHandler
Description copied from class:SqlConnectionSet an handler called with connection errors.- Overrides:
exceptionHandlerin classSqlConnection- Parameters:
handler-- Returns:
-
closeHandler
Description copied from class:SqlConnectionSet an handler called when the connection is closed.- Overrides:
closeHandlerin classSqlConnection- Parameters:
handler-- Returns:
-
ping
public io.reactivex.rxjava3.core.Completable ping()Send a PING command to check if the server is alive.- Returns:
- a future notified with the server response
-
rxPing
public io.reactivex.rxjava3.core.Completable rxPing()Send a PING command to check if the server is alive.- Returns:
- a future notified with the server response
-
specifySchema
Send a INIT_DB command to change the default schema of the connection.- Parameters:
schemaName- name of the schema to change to- Returns:
- a future notified with the execution result
-
rxSpecifySchema
Send a INIT_DB command to change the default schema of the connection.- Parameters:
schemaName- name of the schema to change to- Returns:
- a future notified with the execution result
-
getInternalStatistics
Send a STATISTICS command to get a human readable string of the server internal status.- Returns:
- a future notified with the execution result
-
rxGetInternalStatistics
Send a STATISTICS command to get a human readable string of the server internal status.- Returns:
- a future notified with the execution result
-
setOption
Send a SET_OPTION command to set options for the current connection.- Parameters:
option- the options to set- Returns:
- a future notified with the execution result
-
rxSetOption
Send a SET_OPTION command to set options for the current connection.- Parameters:
option- the options to set- Returns:
- a future notified with the execution result
-
resetConnection
public io.reactivex.rxjava3.core.Completable resetConnection()Send a RESET_CONNECTION command to reset the session state.- Returns:
- a future notified with the execution result
-
rxResetConnection
public io.reactivex.rxjava3.core.Completable rxResetConnection()Send a RESET_CONNECTION command to reset the session state.- Returns:
- a future notified with the execution result
-
debug
public io.reactivex.rxjava3.core.Completable debug()Send a DEBUG command to dump debug information to the server's stdout.- Returns:
- a future notified with the execution result
-
rxDebug
public io.reactivex.rxjava3.core.Completable rxDebug()Send a DEBUG command to dump debug information to the server's stdout.- Returns:
- a future notified with the execution result
-
changeUser
Send a CHANGE_USER command to change the user of the current connection, this operation will also reset connection state.- Parameters:
options-- Returns:
- a future notified with the execution result
-
rxChangeUser
Send a CHANGE_USER command to change the user of the current connection, this operation will also reset connection state.- Parameters:
options-- Returns:
- a future notified with the execution result
-
cast
Cast a toMySQLConnection. This is mostly useful for Vert.x generated APIs like RxJava/Mutiny.- Parameters:
sqlConnection- the connection to cast- Returns:
- a
instance
-
newInstance
-