Class SecurityRequirement

java.lang.Object
io.vertx.rxjava3.openapi.contract.SecurityRequirement
All Implemented Interfaces:
RxDelegate

public class SecurityRequirement extends Object implements RxDelegate
A Security requirement is an object that contains the names of the security schemes that apply to the operation. Each name has a list of scopes that apply to the operation.

NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.