Uses of Class
io.vertx.rxjava3.openapi.contract.Operation
Packages that use Operation
Package
Description
-
Uses of Operation in io.vertx.rxjava3.ext.web.openapi.router
Methods in io.vertx.rxjava3.ext.web.openapi.router that return OperationMethods in io.vertx.rxjava3.ext.web.openapi.router with parameters of type OperationModifier and TypeMethodDescriptionio.reactivex.rxjava3.core.Single<ValidatableRequest>RequestExtractor.extractValidatableRequest(RoutingContext routingContext, Operation operation) Extracts and transforms the parameters and the body of an incoming request into a that can be validated by theRequestValidator.io.reactivex.rxjava3.core.Single<ValidatableRequest>RequestExtractor.rxExtractValidatableRequest(RoutingContext routingContext, Operation operation) Extracts and transforms the parameters and the body of an incoming request into a that can be validated by theRequestValidator. -
Uses of Operation in io.vertx.rxjava3.openapi.contract
Fields in io.vertx.rxjava3.openapi.contract with type parameters of type OperationMethods in io.vertx.rxjava3.openapi.contract that return OperationModifier and TypeMethodDescriptionOpenAPIContract.findOperation(String urlPath, HttpMethod method) Finds the relatedOperationobject based on the passed url path and method.static OperationOperation.newInstance(Operation arg) Access to an operation defined in the contract withoperationId.Methods in io.vertx.rxjava3.openapi.contract that return types with arguments of type Operation -
Uses of Operation in io.vertx.rxjava3.openapi.validation
Methods in io.vertx.rxjava3.openapi.validation with parameters of type OperationModifier and TypeMethodDescriptionstatic io.reactivex.rxjava3.core.Single<ValidatableRequest>ValidatableRequest.of(HttpServerRequest request, Operation operation) Creates a newValidatableRequestobject based on the passed and .static io.reactivex.rxjava3.core.Single<ValidatableRequest>ValidatableRequest.rxOf(HttpServerRequest request, Operation operation) Creates a newValidatableRequestobject based on the passed and .