Class ValidatedResponse
java.lang.Object
io.vertx.rxjava3.openapi.validation.ValidatedResponse
- All Implemented Interfaces:
RxDelegate
-
Field Summary
Fields -
Constructor Summary
ConstructorsConstructorDescriptionValidatedResponse(ValidatedResponse delegate) ValidatedResponse(Object delegate) -
Method Summary
Modifier and TypeMethodDescriptionbooleangetBody()inthashCode()static ValidatedResponseio.reactivex.rxjava3.core.CompletablerxSend(HttpServerResponse serverResponse) Add all parameters from the validated response to the passed and send it.io.reactivex.rxjava3.core.Completablesend(HttpServerResponse serverResponse) Add all parameters from the validated response to the passed and send it.toString()
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
ValidatedResponse
-
ValidatedResponse
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
getHeaders
- Returns:
- the header parameters.
-
getBody
- Returns:
- the body.
-
send
Add all parameters from the validated response to the passed and send it.- Parameters:
serverResponse- The related response- Returns:
- A succeeded Future when the response was sent successfully, otherwise a failed one.
-
rxSend
Add all parameters from the validated response to the passed and send it.- Parameters:
serverResponse- The related response- Returns:
- A succeeded Future when the response was sent successfully, otherwise a failed one.
-
newInstance
-