Uses of Class
io.vertx.rxjava3.openapi.validation.ValidatableRequest
Packages that use ValidatableRequest
-
Uses of ValidatableRequest in io.vertx.rxjava3.ext.web.openapi.router
Methods in io.vertx.rxjava3.ext.web.openapi.router that return types with arguments of type ValidatableRequestModifier and TypeMethodDescriptionio.reactivex.rxjava3.core.Single<ValidatableRequest>RequestExtractor.extractValidatableRequest(RoutingContext routingContext, Operation operation) Extracts and transforms the parameters and the body of an incoming request into a that can be validated by theRequestValidator.io.reactivex.rxjava3.core.Single<ValidatableRequest>RequestExtractor.rxExtractValidatableRequest(RoutingContext routingContext, Operation operation) Extracts and transforms the parameters and the body of an incoming request into a that can be validated by theRequestValidator. -
Uses of ValidatableRequest in io.vertx.rxjava3.openapi.validation
Fields in io.vertx.rxjava3.openapi.validation with type parameters of type ValidatableRequestModifier and TypeFieldDescriptionstatic final TypeArg<ValidatableRequest>ValidatableRequest.__TYPE_ARGMethods in io.vertx.rxjava3.openapi.validation that return ValidatableRequestModifier and TypeMethodDescriptionstatic ValidatableRequestValidatableRequest.newInstance(ValidatableRequest arg) Methods in io.vertx.rxjava3.openapi.validation that return types with arguments of type ValidatableRequestModifier and TypeMethodDescriptionstatic io.reactivex.rxjava3.core.Single<ValidatableRequest>ValidatableRequest.of(HttpServerRequest request, Operation operation) Creates a newValidatableRequestobject based on the passed and .static io.reactivex.rxjava3.core.Single<ValidatableRequest>ValidatableRequest.rxOf(HttpServerRequest request, Operation operation) Creates a newValidatableRequestobject based on the passed and .Methods in io.vertx.rxjava3.openapi.validation with parameters of type ValidatableRequestModifier and TypeMethodDescriptionio.reactivex.rxjava3.core.Single<ValidatedRequest>RequestValidator.rxValidate(ValidatableRequest params, String operationId) Validates the passed request parameters against the operation defined in the related OpenAPI contract.io.reactivex.rxjava3.core.Single<ValidatedRequest>RequestValidator.validate(ValidatableRequest params, String operationId) Validates the passed request parameters against the operation defined in the related OpenAPI contract.