Package io.vertx.rxjava3.oracleclient
Class OracleBuilder
java.lang.Object
io.vertx.rxjava3.oracleclient.OracleBuilder
- All Implemented Interfaces:
RxDelegate
Entry point for building Oracle clients.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleaninthashCode()static OracleBuildernewInstance(OracleBuilder arg) static ClientBuilder<Pool>pool()Provide a builder for Oracle pool of connectionsstatic Poolpool(Handler<ClientBuilder<Pool>> block) Build a pool with the specifiedblockargument.toString()
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
OracleBuilder
-
OracleBuilder
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
pool
Build a pool with the specifiedblockargument. Theblockargument is usually a lambda that configures the provided builderExample usage:
Pool pool = PgBuilder.pool(builder -> builder.connectingTo(connectOptions));- Parameters:
block-- Returns:
- the pool as configured by the code
block
-
pool
Provide a builder for Oracle pool of connectionsExample usage:
Pool pool = PgBuilder.pool().connectingTo(connectOptions).build()- Returns:
-
newInstance
-