Package io.vertx.rxjava3.oracleclient
Class OracleClient
java.lang.Object
io.vertx.rxjava3.oracleclient.OracleClient
- All Implemented Interfaces:
RxDelegate
An interface to define Oracle specific constants or behaviors.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final TypeArg<OracleClient>static final PropertyKind<Row>The property to be used to retrieve the generated keysstatic final PropertyKind<Boolean>The property to be used to retrieve the output of the callable statement -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleaninthashCode()static OracleClientnewInstance(OracleClient arg) toString()
-
Field Details
-
__TYPE_ARG
-
GENERATED_KEYS
The property to be used to retrieve the generated keys -
OUTPUT
The property to be used to retrieve the output of the callable statement
-
-
Constructor Details
-
OracleClient
-
OracleClient
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
newInstance
-