Uses of Class
io.vertx.rxjava3.pgclient.PgConnection
Packages that use PgConnection
-
Uses of PgConnection in io.vertx.rxjava3.pgclient
Fields in io.vertx.rxjava3.pgclient with type parameters of type PgConnectionMethods in io.vertx.rxjava3.pgclient that return PgConnectionModifier and TypeMethodDescriptionstatic PgConnectionPgConnection.cast(SqlConnection sqlConnection) Cast a toPgConnection.PgConnection.closeHandler(Handler<Void> handler) PgConnection.exceptionHandler(Handler<Throwable> handler) static PgConnectionPgConnection.newInstance(PgConnection arg) PgConnection.noticeHandler(Handler<PgNotice> handler) Set a handler called when the connection receives a notice from the server.PgConnection.notificationHandler(Handler<PgNotification> handler) Set a handler called when the connection receives notification on a channel.Methods in io.vertx.rxjava3.pgclient that return types with arguments of type PgConnectionModifier and TypeMethodDescriptionstatic io.reactivex.rxjava3.core.Single<PgConnection>PgConnection.connect(io.vertx.rxjava3.core.Vertx vertx) Likeconnect(io.vertx.rxjava3.core.Vertx, io.vertx.pgclient.PgConnectOptions)with options build from the environment variables.static io.reactivex.rxjava3.core.Single<PgConnection>PgConnection.connect(io.vertx.rxjava3.core.Vertx vertx, PgConnectOptions options) Connects to the database and returns the connection if that succeeds.static io.reactivex.rxjava3.core.Single<PgConnection>Likeconnect(io.vertx.rxjava3.core.Vertx, io.vertx.pgclient.PgConnectOptions)with options build fromconnectionUri.static io.reactivex.rxjava3.core.Single<PgConnection>PgConnection.rxConnect(io.vertx.rxjava3.core.Vertx vertx) Likeconnect(io.vertx.rxjava3.core.Vertx, io.vertx.pgclient.PgConnectOptions)with options build from the environment variables.static io.reactivex.rxjava3.core.Single<PgConnection>PgConnection.rxConnect(io.vertx.rxjava3.core.Vertx vertx, PgConnectOptions options) Connects to the database and returns the connection if that succeeds.static io.reactivex.rxjava3.core.Single<PgConnection>Likeconnect(io.vertx.rxjava3.core.Vertx, io.vertx.pgclient.PgConnectOptions)with options build fromconnectionUri. -
Uses of PgConnection in io.vertx.rxjava3.pgclient.pubsub
Methods in io.vertx.rxjava3.pgclient.pubsub that return PgConnection