Package io.vertx.rxjava3.rabbitmq
Class RabbitMQMessage
java.lang.Object
io.vertx.rxjava3.rabbitmq.RabbitMQMessage
- All Implemented Interfaces:
RxDelegate
Represent a message received message received in a rabbitmq-queue.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbody()com.rabbitmq.client.Envelopeenvelope()booleaninthashCode()static RabbitMQMessagecom.rabbitmq.client.BasicPropertiestoString()
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
RabbitMQMessage
-
RabbitMQMessage
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
body
- Returns:
- the message body
-
consumerTag
- Returns:
- the consumer tag associated with the consumer
-
messageCount
- Returns:
- the message count for messages obtained with
RabbitMQClient.basicGet(java.lang.String, boolean)
-
envelope
public com.rabbitmq.client.Envelope envelope()- Returns:
- packaging data for the message
-
properties
public com.rabbitmq.client.BasicProperties properties()- Returns:
- content header data for the message
-
newInstance
-