Package io.vertx.rxjava3.redis.client
Class RedisConnection
java.lang.Object
io.vertx.rxjava3.redis.client.RedisConnection
- All Implemented Interfaces:
RxDelegate,ReadStream<Response>,StreamBase
A simple Redis client.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionSends a list of commands in a single IO operation, this prevents any inter twinning to happen from other client users.io.reactivex.rxjava3.core.Completableclose()Closes the connection or returns to the pool.endHandler(Handler<Void> endHandler) Set an end handler.booleanexceptionHandler(Handler<Throwable> handler) Set an exception handler on the read stream.fetch(long amount) Fetch the specifiedamountof elements.Set a data handler.inthashCode()static RedisConnectionpause()Pause theReadStream, it sets the buffer infetchmode and clears the actual demand.booleanFlag to notify if the pending message queue (commands in transit) is full.pipe()Pause this stream and return a to transfer the elements of this stream to a destination .io.reactivex.rxjava3.core.CompletablepipeTo(WriteStream<Response> dst) Pipe thisReadStreamto theWriteStream.resume()Resume reading, and sets the buffer inflowingmode.Sends a list of commands in a single IO operation, this prevents any inter twinning to happen from other client users.io.reactivex.rxjava3.core.CompletablerxClose()Closes the connection or returns to the pool.io.reactivex.rxjava3.core.CompletablerxPipeTo(WriteStream<Response> dst) Pipe thisReadStreamto theWriteStream.io.reactivex.rxjava3.core.Maybe<Response>Send the given command to the redis server or cluster.io.reactivex.rxjava3.core.Maybe<Response>Send the given command to the redis server or cluster.io.reactivex.rxjava3.core.Flowable<Response>io.reactivex.rxjava3.core.Observable<Response>toString()
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
RedisConnection
-
RedisConnection
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceReadStream<Response>- Specified by:
getDelegatein interfaceRxDelegate- Specified by:
getDelegatein interfaceStreamBase
-
toObservable
- Specified by:
toObservablein interfaceReadStream<Response>
-
toFlowable
- Specified by:
toFlowablein interfaceReadStream<Response>
-
pipe
Pause this stream and return a to transfer the elements of this stream to a destination . The stream will be resumed when the pipe will be wired to aWriteStream.- Specified by:
pipein interfaceReadStream<Response>- Returns:
- a pipe
-
pipeTo
Pipe thisReadStreamto theWriteStream.Elements emitted by this stream will be written to the write stream until this stream ends or fails.
- Specified by:
pipeToin interfaceReadStream<Response>- Parameters:
dst- the destination write stream- Returns:
- a future notified when the write stream will be ended with the outcome
-
rxPipeTo
Pipe thisReadStreamto theWriteStream.Elements emitted by this stream will be written to the write stream until this stream ends or fails.
- Specified by:
rxPipeToin interfaceReadStream<Response>- Parameters:
dst- the destination write stream- Returns:
- a future notified when the write stream will be ended with the outcome
-
exceptionHandler
Description copied from interface:ReadStreamSet an exception handler on the read stream.- Specified by:
exceptionHandlerin interfaceReadStream<Response>- Specified by:
exceptionHandlerin interfaceStreamBase- Parameters:
handler-- Returns:
-
handler
Description copied from interface:ReadStreamSet a data handler. As data is read, the handler will be called with the data.- Specified by:
handlerin interfaceReadStream<Response>- Parameters:
handler-- Returns:
-
pause
Description copied from interface:ReadStreamPause theReadStream, it sets the buffer infetchmode and clears the actual demand.While it's paused, no data will be sent to the data
handler.- Specified by:
pausein interfaceReadStream<Response>- Returns:
-
resume
Description copied from interface:ReadStreamResume reading, and sets the buffer inflowingmode. If theReadStreamhas been paused, reading will recommence on it.- Specified by:
resumein interfaceReadStream<Response>- Returns:
-
fetch
Description copied from interface:ReadStreamFetch the specifiedamountof elements. If theReadStreamhas been paused, reading will recommence with the specifiedamountof items, otherwise the specifiedamountwill be added to the current stream demand.- Specified by:
fetchin interfaceReadStream<Response>- Parameters:
amount-- Returns:
-
endHandler
Description copied from interface:ReadStreamSet an end handler. Once the stream has ended, and there is no more data to be read, this handler will be called.- Specified by:
endHandlerin interfaceReadStream<Response>- Parameters:
endHandler-- Returns:
-
send
Send the given command to the redis server or cluster.- Parameters:
command- the command to send- Returns:
- a future with the result of the operation
-
rxSend
Send the given command to the redis server or cluster.- Parameters:
command- the command to send- Returns:
- a future with the result of the operation
-
batch
Sends a list of commands in a single IO operation, this prevents any inter twinning to happen from other client users.- Parameters:
commands- list of command to send- Returns:
- a future with the result of the operation
-
rxBatch
Sends a list of commands in a single IO operation, this prevents any inter twinning to happen from other client users.- Parameters:
commands- list of command to send- Returns:
- a future with the result of the operation
-
close
public io.reactivex.rxjava3.core.Completable close()Closes the connection or returns to the pool.- Returns:
-
rxClose
public io.reactivex.rxjava3.core.Completable rxClose()Closes the connection or returns to the pool.- Returns:
-
pendingQueueFull
public boolean pendingQueueFull()Flag to notify if the pending message queue (commands in transit) is full.When the pending message queue is full and a new send command is issued it will result in a exception to be thrown. Checking this flag before sending can allow the application to wait before sending the next message.
- Returns:
- true is queue is full.
-
newInstance
-