Package io.vertx.rxjava3.sqlclient
Class Cursor
java.lang.Object
io.vertx.rxjava3.sqlclient.Cursor
- All Implemented Interfaces:
RxDelegate
A cursor that reads progressively rows from the database, it is useful for reading very large result sets.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionio.reactivex.rxjava3.core.Completableclose()Release the cursor.booleaninthashCode()booleanhasMore()Returnstruewhen the cursor has results in progress and theread(int)should be called to retrieve them.booleanisClosed()static CursornewInstance(Cursor arg) read(int count) Read rows from the cursor, the result is provided asynchronously to thehandler.Describes rows loaded withread(int).io.reactivex.rxjava3.core.CompletablerxClose()Release the cursor.rxRead(int count) Read rows from the cursor, the result is provided asynchronously to thehandler.toString()
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
Cursor
-
Cursor
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
rowDescriptor
Describes rows loaded withread(int).This returns
nulluntil the first set of rows is fetched from the database.- Returns:
-
read
Read rows from the cursor, the result is provided asynchronously to thehandler.- Parameters:
count- the amount of rows to read- Returns:
- a future notified with the result
-
rxRead
Read rows from the cursor, the result is provided asynchronously to thehandler.- Parameters:
count- the amount of rows to read- Returns:
- a future notified with the result
-
hasMore
public boolean hasMore()Returnstruewhen the cursor has results in progress and theread(int)should be called to retrieve them.- Returns:
- whether the cursor has more results,
-
close
public io.reactivex.rxjava3.core.Completable close()Release the cursor. It should be called for prepared queries executed with a fetch size.- Returns:
-
rxClose
public io.reactivex.rxjava3.core.Completable rxClose()Release the cursor. It should be called for prepared queries executed with a fetch size.- Returns:
-
isClosed
public boolean isClosed()- Returns:
- whether the cursor is closed
-
newInstance
-