Class PropertyKind<T>

java.lang.Object
io.vertx.rxjava3.sqlclient.PropertyKind<T>
All Implemented Interfaces:
RxDelegate

public class PropertyKind<T> extends Object implements RxDelegate
The kind of the property, this can be used to fetch some specific property of the execution result.

NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.