Package io.vertx.rxjava3.sqlclient
Class SqlResult<T>
java.lang.Object
io.vertx.rxjava3.sqlclient.SqlResult<T>
- All Implemented Interfaces:
RxDelegate
- Direct Known Subclasses:
RowSet
An interface that represents the execution result of an operation on the database server.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
FieldsModifier and TypeFieldDescription -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionGet the column descriptors in the SqlResult.Get the names of columns in the SqlResult.booleaninthashCode()static <T> SqlResult<T>newInstance(SqlResult arg) static <T> SqlResult<T>newInstance(SqlResult arg, TypeArg<T> __typeArg_T) next()Return the next available result ornull, e.g for a simple query that executed multiple queries or for a batch result.<V> Vproperty(PropertyKind<V> propertyKind) Get the specific property with the specifiedPropertyKind.introwCount()Get the number of the affected rows in the operation to this SqlResult.intsize()Get the number of rows retrieved in the SqlResult.toString()value()
-
Field Details
-
__TYPE_ARG
-
__typeArg_0
-
-
Constructor Details
-
SqlResult
-
SqlResult
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
rowCount
public int rowCount()Get the number of the affected rows in the operation to this SqlResult.- Returns:
- the count of affected rows.
-
rowDescriptor
-
columnsNames
Get the names of columns in the SqlResult.- Returns:
- the list of names of columns.
-
columnDescriptors
Get the column descriptors in the SqlResult.- Returns:
- the list of column descriptors
-
size
public int size()Get the number of rows retrieved in the SqlResult.- Returns:
- the count of rows.
-
property
Get the specific property with the specifiedPropertyKind.- Parameters:
propertyKind- the unique object which is used to indicate which property of the execution result to fetch- Returns:
- the value of the property
-
value
Get the execution result value, the execution result type may vary such as arowSetor even aString.- Returns:
- the result value
-
next
Return the next available result ornull, e.g for a simple query that executed multiple queries or for a batch result.- Returns:
- the next available result or
nullif none is available
-
newInstance
-
newInstance
-