Package io.vertx.rxjava3.sqlclient
Class Transaction
java.lang.Object
io.vertx.rxjava3.sqlclient.Transaction
- All Implemented Interfaces:
RxDelegate
A transaction.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionio.reactivex.rxjava3.core.Completablecommit()Commit the current transaction.io.reactivex.rxjava3.core.CompletableReturn the transaction completionFuturethat succeeds when the transaction commits and fails withTransactionRollbackExceptionwhen the transaction rolls back.booleaninthashCode()static TransactionnewInstance(Transaction arg) io.reactivex.rxjava3.core.Completablerollback()Rollback the transaction and release the associated resources.io.reactivex.rxjava3.core.CompletablerxCommit()Commit the current transaction.io.reactivex.rxjava3.core.CompletableReturn the transaction completionFuturethat succeeds when the transaction commits and fails withTransactionRollbackExceptionwhen the transaction rolls back.io.reactivex.rxjava3.core.CompletableRollback the transaction and release the associated resources.toString()
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
Transaction
-
Transaction
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
commit
public io.reactivex.rxjava3.core.Completable commit()Commit the current transaction.- Returns:
-
rxCommit
public io.reactivex.rxjava3.core.Completable rxCommit()Commit the current transaction.- Returns:
-
rollback
public io.reactivex.rxjava3.core.Completable rollback()Rollback the transaction and release the associated resources.- Returns:
-
rxRollback
public io.reactivex.rxjava3.core.Completable rxRollback()Rollback the transaction and release the associated resources.- Returns:
-
completion
public io.reactivex.rxjava3.core.Completable completion()Return the transaction completionFuturethat succeeds when the transaction commits and fails withTransactionRollbackExceptionwhen the transaction rolls back.- Returns:
- the transaction result
-
rxCompletion
public io.reactivex.rxjava3.core.Completable rxCompletion()Return the transaction completionFuturethat succeeds when the transaction commits and fails withTransactionRollbackExceptionwhen the transaction rolls back.- Returns:
- the transaction result
-
newInstance
-