Package io.vertx.rxjava3.sqlclient.desc
Class RowDescriptor
java.lang.Object
io.vertx.rxjava3.sqlclient.desc.RowDescriptor
- All Implemented Interfaces:
RxDelegate
Describe a database row.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionintcolumnIndex(String columnName) Get the index of the named column or when not foundbooleaninthashCode()static RowDescriptornewInstance(RowDescriptor arg) toString()
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
RowDescriptor
-
RowDescriptor
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
columnIndex
Get the index of the named column or when not found- Parameters:
columnName- the column to lookup- Returns:
- the index of the column
-
columnNames
- Returns:
- the list of the column names
-
columnDescriptors
- Returns:
- the list of column descriptors
-
newInstance
-