Class TupleMapper<T>
java.lang.Object
io.vertx.rxjava3.sqlclient.templates.TupleMapper<T>
- All Implemented Interfaces:
RxDelegate
Map an arbitrary
T object to a .
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
ConstructorsConstructorDescriptionTupleMapper(TupleMapper delegate) TupleMapper(Object delegate, TypeArg<T> typeArg_0) -
Method Summary
Modifier and TypeMethodDescriptionbooleaninthashCode()static TupleMapper<JsonObject>Map a to a .The internal mapper contract that builds a tuple.static <T> TupleMapper<T>Create a mapper that associates a parameters object to a map of named parameters to their respective value.static <T> TupleMapper<T>newInstance(TupleMapper arg) static <T> TupleMapper<T>newInstance(TupleMapper arg, TypeArg<T> __typeArg_T) toString()
-
Field Details
-
__TYPE_ARG
-
__typeArg_0
-
-
Constructor Details
-
TupleMapper
-
TupleMapper
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
mapper
Create a mapper that associates a parameters object to a map of named parameters to their respective value.- Parameters:
fn- the function turning a parameters object into a map- Returns:
- the mapper
-
jsonObject
Map a to a .- Returns:
-
map
The internal mapper contract that builds a tuple.- Parameters:
mapping- associates an index to template parameter namesize- the tuple sizeparams- the parameters object- Returns:
- the tuple
-
newInstance
-
newInstance
-