Uses of Class
io.vertx.rxjava3.sqlclient.templates.TupleMapper
Packages that use TupleMapper
-
Uses of TupleMapper in io.vertx.rxjava3.sqlclient.templates
Fields in io.vertx.rxjava3.sqlclient.templates with type parameters of type TupleMapperMethods in io.vertx.rxjava3.sqlclient.templates that return TupleMapperModifier and TypeMethodDescriptionstatic TupleMapper<JsonObject>TupleMapper.jsonObject()Map a to a .static <T> TupleMapper<T>Create a mapper that associates a parameters object to a map of named parameters to their respective value.static <T> TupleMapper<T>TupleMapper.newInstance(TupleMapper arg) static <T> TupleMapper<T>TupleMapper.newInstance(TupleMapper arg, TypeArg<T> __typeArg_T) Methods in io.vertx.rxjava3.sqlclient.templates with parameters of type TupleMapperModifier and TypeMethodDescription<T> SqlTemplate<T,R> SqlTemplate.mapFrom(TupleMapper<T> mapper) Set a parameters user defined mapping function.