Package io.vertx.rxjava3.uritemplate
Class Variables
java.lang.Object
io.vertx.rxjava3.uritemplate.Variables
- All Implemented Interfaces:
RxDelegate
Holds a set of name/value pairs where each value can be a
String or a List or a Map<String, String>.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionaddAll(JsonObject json) Populates with a JSON object:nullare conservedJsonArrayis converted toListJsonObjectis converted toMap<String, String>any other value is converted to a string Note that nested JSON elements are converted to a string, so { "user": { "first_name": "John", "last_name": "Doe", "address" : { "city": "Paris", etc... } } } flattens the JSON "address" to the string "{\"city\":\"Paris\",etc...}".clear()booleaninthashCode()names()static VariablesnewInstance(Variables arg) Set a single variable.Set a list variable.Set a map variable.setAll(JsonObject json) LikeaddAll(io.vertx.core.json.JsonObject)but overwrites previous variables.toString()static Variablesstatic Variablesvariables(JsonObject json) Create an instance populated from a JSON object:nullare conservedJsonArrayis converted toListJsonObjectis converted toMap<String, String>any other value is converted to a string Note that nested JSON elements are converted to a string, so { "user": { "first_name": "John", "last_name": "Doe", "address" : { "city": "Paris", etc... } } } flattens the JSON "address" to the string "{\"city\":\"Paris\",etc...}".
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
Variables
-
Variables
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
variables
- Returns:
- an empty instance
-
variables
Create an instance populated from a JSON object:nullare conservedJsonArrayis converted toListJsonObjectis converted toMap<String, String>- any other value is converted to a string
- Parameters:
json- the json that populates the returned variables- Returns:
- an instance populated from a JSON object
-
set
Set a single variable.- Parameters:
name- the variable namevalue- the variable value- Returns:
- a reference to this, so the API can be used fluently
-
set
Set a list variable.- Parameters:
name- the variable namevalue- the variable value- Returns:
- a reference to this, so the API can be used fluently
-
set
Set a map variable.- Parameters:
name- the variable namevalue- the variable value- Returns:
- a reference to this, so the API can be used fluently
-
setAll
LikeaddAll(io.vertx.core.json.JsonObject)but overwrites previous variables.- Parameters:
json-- Returns:
-
addAll
Populates with a JSON object:nullare conservedJsonArrayis converted toListJsonObjectis converted toMap<String, String>- any other value is converted to a string
- Parameters:
json- the json that populates the returned variables- Returns:
- a reference to this, so the API can be used fluently
-
clear
-
names
- Returns:
- the set of variable names
-
get
- Parameters:
name-- Returns:
- the value of the variable
name
-
getSingle
- Parameters:
name-- Returns:
- the single value of the variable
name
-
getList
- Parameters:
name-- Returns:
- the list value of the variable
name
-
getMap
- Parameters:
name-- Returns:
- the map value of the variable
name
-
newInstance
-