Package io.vertx.rxjava3.core.http
Interface HttpClient
- All Superinterfaces:
RxDelegate
- All Known Implementing Classes:
HttpClientAgent,HttpClientConnection
The API to interacts with an HTTP server.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Method Summary
Modifier and TypeMethodDescriptionio.reactivex.rxjava3.core.Completableclose()Close immediately (shutdown(0, TimeUnit.SECONDS).static HttpClientnewInstance(HttpClient arg) io.reactivex.rxjava3.core.Single<HttpClientRequest>request()Create an HTTP request to send to the server with the default host and port of the client.io.reactivex.rxjava3.core.Single<HttpClientRequest>request(HttpMethod method, int port, String host, String requestURI) Create an HTTP request to send to the server at thehostandport.io.reactivex.rxjava3.core.Single<HttpClientRequest>request(HttpMethod method, String requestURI) Create an HTTP request to send to the server at the default host and port.io.reactivex.rxjava3.core.Single<HttpClientRequest>request(HttpMethod method, String host, String requestURI) Create an HTTP request to send to the server at thehostand default port.io.reactivex.rxjava3.core.Single<HttpClientRequest>request(RequestOptions options) Create an HTTP request to send to the server.io.reactivex.rxjava3.core.CompletablerxClose()Close immediately (shutdown(0, TimeUnit.SECONDS).io.reactivex.rxjava3.core.Single<HttpClientRequest>Create an HTTP request to send to the server with the default host and port of the client.io.reactivex.rxjava3.core.Single<HttpClientRequest>rxRequest(HttpMethod method, int port, String host, String requestURI) Create an HTTP request to send to the server at thehostandport.io.reactivex.rxjava3.core.Single<HttpClientRequest>rxRequest(HttpMethod method, String requestURI) Create an HTTP request to send to the server at the default host and port.io.reactivex.rxjava3.core.Single<HttpClientRequest>rxRequest(HttpMethod method, String host, String requestURI) Create an HTTP request to send to the server at thehostand default port.io.reactivex.rxjava3.core.Single<HttpClientRequest>rxRequest(RequestOptions options) Create an HTTP request to send to the server.io.reactivex.rxjava3.core.CompletableShutdown with a 30 seconds timeout (shutdown(30, TimeUnit.SECONDS)).io.reactivex.rxjava3.core.CompletablerxShutdown(long timeout, TimeUnit unit) Callsshutdown().io.reactivex.rxjava3.core.Completableshutdown()Shutdown with a 30 seconds timeout (shutdown(30, TimeUnit.SECONDS)).io.reactivex.rxjava3.core.CompletableCallsshutdown().
-
Method Details
-
getDelegate
HttpClient getDelegate()- Specified by:
getDelegatein interfaceRxDelegate
-
request
io.reactivex.rxjava3.core.Single<HttpClientRequest> request()Create an HTTP request to send to the server with the default host and port of the client.- Returns:
- a future notified when the request is ready to be sent
-
rxRequest
io.reactivex.rxjava3.core.Single<HttpClientRequest> rxRequest()Create an HTTP request to send to the server with the default host and port of the client.- Returns:
- a future notified when the request is ready to be sent
-
request
Create an HTTP request to send to the server.- Parameters:
options- the request options- Returns:
- a future notified when the request is ready to be sent
-
rxRequest
Create an HTTP request to send to the server.- Parameters:
options- the request options- Returns:
- a future notified when the request is ready to be sent
-
request
io.reactivex.rxjava3.core.Single<HttpClientRequest> request(HttpMethod method, int port, String host, String requestURI) Create an HTTP request to send to the server at thehostandport.- Parameters:
method- the HTTP methodport- the porthost- the hostrequestURI- the relative URI- Returns:
- a future notified when the request is ready to be sent
-
rxRequest
io.reactivex.rxjava3.core.Single<HttpClientRequest> rxRequest(HttpMethod method, int port, String host, String requestURI) Create an HTTP request to send to the server at thehostandport.- Parameters:
method- the HTTP methodport- the porthost- the hostrequestURI- the relative URI- Returns:
- a future notified when the request is ready to be sent
-
request
io.reactivex.rxjava3.core.Single<HttpClientRequest> request(HttpMethod method, String host, String requestURI) Create an HTTP request to send to the server at thehostand default port.- Parameters:
method- the HTTP methodhost- the hostrequestURI- the relative URI- Returns:
- a future notified when the request is ready to be sent
-
rxRequest
io.reactivex.rxjava3.core.Single<HttpClientRequest> rxRequest(HttpMethod method, String host, String requestURI) Create an HTTP request to send to the server at thehostand default port.- Parameters:
method- the HTTP methodhost- the hostrequestURI- the relative URI- Returns:
- a future notified when the request is ready to be sent
-
request
Create an HTTP request to send to the server at the default host and port.- Parameters:
method- the HTTP methodrequestURI- the relative URI- Returns:
- a future notified when the request is ready to be sent
-
rxRequest
Create an HTTP request to send to the server at the default host and port.- Parameters:
method- the HTTP methodrequestURI- the relative URI- Returns:
- a future notified when the request is ready to be sent
-
shutdown
io.reactivex.rxjava3.core.Completable shutdown()Shutdown with a 30 seconds timeout (shutdown(30, TimeUnit.SECONDS)).- Returns:
- a future completed when shutdown has completed
-
rxShutdown
io.reactivex.rxjava3.core.Completable rxShutdown()Shutdown with a 30 seconds timeout (shutdown(30, TimeUnit.SECONDS)).- Returns:
- a future completed when shutdown has completed
-
close
io.reactivex.rxjava3.core.Completable close()Close immediately (shutdown(0, TimeUnit.SECONDS).- Returns:
- a future notified when the client is closed
-
rxClose
io.reactivex.rxjava3.core.Completable rxClose()Close immediately (shutdown(0, TimeUnit.SECONDS).- Returns:
- a future notified when the client is closed
-
shutdown
Callsshutdown().- Parameters:
timeout-unit-- Returns:
-
rxShutdown
Callsshutdown().- Parameters:
timeout-unit-- Returns:
-
newInstance
-