Class AuthorizationContext
java.lang.Object
io.vertx.rxjava3.ext.auth.authorization.AuthorizationContext
- All Implemented Interfaces:
RxDelegate
The AuthorizationContext contains properties that can be used to match
authorizations.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
ConstructorsConstructorDescriptionAuthorizationContext(AuthorizationContext delegate) AuthorizationContext(Object delegate) -
Method Summary
Modifier and TypeMethodDescriptionstatic AuthorizationContextFactory for Authorization Contextstatic AuthorizationContextFactory for Authorization ContextbooleaninthashCode()static AuthorizationContexttoString()user()Get the authenticated user
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
AuthorizationContext
-
AuthorizationContext
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
create
Factory for Authorization Context- Parameters:
user- a user- Returns:
- a AuthorizationContext instance
-
create
Factory for Authorization Context- Parameters:
user- a uservariables-- Returns:
- a AuthorizationContext instance
-
user
Get the authenticated user- Returns:
- the user
-
variables
- Returns:
- a Multimap containing variable names and values that can be resolved at runtime by
AuthorizationAuthorizations
-
newInstance
-