Package io.vertx.rxjava3.ext.bridge
Class BaseBridgeEvent
java.lang.Object
io.vertx.rxjava3.core.Promise<Boolean>
io.vertx.rxjava3.ext.bridge.BaseBridgeEvent
- All Implemented Interfaces:
RxDelegate
- Direct Known Subclasses:
BridgeEvent,BridgeEvent,BridgeEvent
Represents an event that occurs on the event bus bridge.
Please consult the documentation for a full explanation.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
FieldsFields inherited from class io.vertx.rxjava3.core.Promise
__typeArg_0 -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionvoidSet the result.voidbooleanio.reactivex.rxjava3.core.Single<Boolean>future()Get the raw JSON message for the event.voidhandle(AsyncResult<Boolean> asyncResult) Succeed or fail this promise with the event.inthashCode()static BaseBridgeEventio.reactivex.rxjava3.core.Single<Boolean>rxFuture()setRawMessage(JsonObject message) Override the raw JSON message for the event.voidtoString()booleantryComplete(Boolean result) LikePromise.complete(T, java.lang.Throwable)but returnsfalsewhen the promise is already completed instead of throwing anIllegalStateException, it returnstrueotherwise.type()Methods inherited from class io.vertx.rxjava3.core.Promise
complete, fail, fail, newInstance, newInstance, promise, succeed, tryComplete, tryFail, tryFail
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
BaseBridgeEvent
-
BaseBridgeEvent
-
-
Method Details
-
toString
- Overrides:
toStringin classio.vertx.rxjava3.core.Promise<Boolean>
-
equals
- Overrides:
equalsin classio.vertx.rxjava3.core.Promise<Boolean>
-
hashCode
public int hashCode()- Overrides:
hashCodein classio.vertx.rxjava3.core.Promise<Boolean>
-
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate- Overrides:
getDelegatein classio.vertx.rxjava3.core.Promise<Boolean>
-
complete
- Overrides:
completein classio.vertx.rxjava3.core.Promise<Boolean>
-
complete
Set the result. Any handler will be called, if there is one, and the promise will be marked as completed. Any handler set on the associated promise will be called.- Overrides:
completein classio.vertx.rxjava3.core.Promise<Boolean>- Parameters:
result- the result
-
succeed
- Overrides:
succeedin classio.vertx.rxjava3.core.Promise<Boolean>
-
tryComplete
LikePromise.complete(T, java.lang.Throwable)but returnsfalsewhen the promise is already completed instead of throwing anIllegalStateException, it returnstrueotherwise.- Overrides:
tryCompletein classio.vertx.rxjava3.core.Promise<Boolean>- Parameters:
result- the result- Returns:
falsewhen the future is already completed
-
future
- Overrides:
futurein classio.vertx.rxjava3.core.Promise<Boolean>- Returns:
- the associated with this promise, it can be used to be aware of the promise completion
-
rxFuture
- Overrides:
rxFuturein classio.vertx.rxjava3.core.Promise<Boolean>- Returns:
- the associated with this promise, it can be used to be aware of the promise completion
-
type
- Returns:
- the type of the event
-
getRawMessage
Get the raw JSON message for the event. This will be null for SOCKET_CREATED or SOCKET_CLOSED events as there is no message involved. If the returned message is modified,setRawMessage(io.vertx.core.json.JsonObject)should be called with the new message.- Returns:
- the raw JSON message for the event
-
setRawMessage
Override the raw JSON message for the event. It is ideally using it when publish back message from server to client in RECEIVE event- Parameters:
message- the raw message- Returns:
- this reference, so it can be used fluently
-
handle
Succeed or fail this promise with the event.- Overrides:
handlein classio.vertx.rxjava3.core.Promise<Boolean>- Parameters:
asyncResult- the async result to handle
-
newInstance
-