Package io.vertx.rxjava3.ext.web.handler
Class ChainAuthHandler
java.lang.Object
io.vertx.rxjava3.ext.web.handler.ChainAuthHandler
- All Implemented Interfaces:
Handler<RoutingContext>,RxDelegate,AuthenticationHandler
public class ChainAuthHandler
extends Object
implements RxDelegate, AuthenticationHandler, Handler<RoutingContext>
An auth handler that chains to a sequence of handlers.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
ConstructorsConstructorDescriptionChainAuthHandler(ChainAuthHandler delegate) ChainAuthHandler(Object delegate) -
Method Summary
Modifier and TypeMethodDescriptionadd(AuthenticationHandler other) Appends a auth provider to the chain.static ChainAuthHandlerall()Create a chain authentication handler that will assert that all handlers pass the verification.static ChainAuthHandlerany()Create a chain authentication handler that will assert that any handler passes the verification.booleanvoidhandle(RoutingContext event) Something has happened, so handle it.inthashCode()static ChainAuthHandlertoString()
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
ChainAuthHandler
-
ChainAuthHandler
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceAuthenticationHandler- Specified by:
getDelegatein interfaceRxDelegate
-
handle
Something has happened, so handle it.- Specified by:
handlein interfaceAuthenticationHandler- Specified by:
handlein interfaceHandler<RoutingContext>- Parameters:
event- the event to handle
-
all
Create a chain authentication handler that will assert that all handlers pass the verification.- Returns:
- a new chain authentication handler
-
any
Create a chain authentication handler that will assert that any handler passes the verification.- Returns:
- a new chain authentication handler
-
add
Appends a auth provider to the chain.- Parameters:
other- auth handler- Returns:
- self
-
newInstance
-