Class ConnectionInitEvent
java.lang.Object
io.vertx.rxjava3.core.Promise<Object>
io.vertx.rxjava3.ext.web.handler.graphql.ws.ConnectionInitEvent
- All Implemented Interfaces:
RxDelegate
public class ConnectionInitEvent
extends io.vertx.rxjava3.core.Promise<Object>
implements RxDelegate
-
Field Summary
FieldsFields inherited from class io.vertx.rxjava3.core.Promise
__typeArg_0 -
Constructor Summary
ConstructorsConstructorDescriptionConnectionInitEvent(ConnectionInitEvent delegate) ConnectionInitEvent(Object delegate) -
Method Summary
Modifier and TypeMethodDescriptionvoidSet the result.voidbooleanio.reactivex.rxjava3.core.Single<Object>future()voidhandle(AsyncResult<Object> asyncResult) Succeed or fail this promise with the event.inthashCode()message()Provides message content.static ConnectionInitEventio.reactivex.rxjava3.core.Single<Object>rxFuture()voidtoString()booleantryComplete(Object result) LikePromise.complete(T, java.lang.Throwable)but returnsfalsewhen the promise is already completed instead of throwing anIllegalStateException, it returnstrueotherwise.Methods inherited from class io.vertx.rxjava3.core.Promise
complete, fail, fail, newInstance, newInstance, promise, succeed, tryComplete, tryFail, tryFail
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
ConnectionInitEvent
-
ConnectionInitEvent
-
-
Method Details
-
toString
- Overrides:
toStringin classio.vertx.rxjava3.core.Promise<Object>
-
equals
- Overrides:
equalsin classio.vertx.rxjava3.core.Promise<Object>
-
hashCode
public int hashCode()- Overrides:
hashCodein classio.vertx.rxjava3.core.Promise<Object>
-
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate- Overrides:
getDelegatein classio.vertx.rxjava3.core.Promise<Object>
-
complete
- Overrides:
completein classio.vertx.rxjava3.core.Promise<Object>
-
complete
Set the result. Any handler will be called, if there is one, and the promise will be marked as completed. Any handler set on the associated promise will be called.- Overrides:
completein classio.vertx.rxjava3.core.Promise<Object>- Parameters:
result- the result
-
succeed
- Overrides:
succeedin classio.vertx.rxjava3.core.Promise<Object>
-
tryComplete
LikePromise.complete(T, java.lang.Throwable)but returnsfalsewhen the promise is already completed instead of throwing anIllegalStateException, it returnstrueotherwise.- Overrides:
tryCompletein classio.vertx.rxjava3.core.Promise<Object>- Parameters:
result- the result- Returns:
falsewhen the future is already completed
-
future
- Overrides:
futurein classio.vertx.rxjava3.core.Promise<Object>- Returns:
- the associated with this promise, it can be used to be aware of the promise completion
-
rxFuture
- Overrides:
rxFuturein classio.vertx.rxjava3.core.Promise<Object>- Returns:
- the associated with this promise, it can be used to be aware of the promise completion
-
message
Provides message content.- Returns:
- message
-
handle
Succeed or fail this promise with the event.- Overrides:
handlein classio.vertx.rxjava3.core.Promise<Object>- Parameters:
asyncResult- the async result to handle
-
newInstance
-