Class GrpcServerResponse<Req,​Resp>

    • Method Detail

      • write

        public io.reactivex.rxjava3.core.Completable write​(Resp data)
        Write some data to the stream.

        The data is usually put on an internal write queue, and the write actually happens asynchronously. To avoid running out of memory by putting too much on the write queue, check the WriteStream.writeQueueFull() method before writing. This is done automatically if using a .

        When the data is moved from the queue to the actual medium, the returned will be completed with the write result, e.g the future is succeeded when a server HTTP response buffer is written to the socket and failed if the remote client has closed the socket while the data was still pending for write.

        Specified by:
        write in interface WriteStream<Req>
        Overrides:
        write in class GrpcWriteStream<Resp>
        Parameters:
        data - the data to write
        Returns:
        a future completed with the write result
      • rxWrite

        public io.reactivex.rxjava3.core.Completable rxWrite​(Resp data)
        Write some data to the stream.

        The data is usually put on an internal write queue, and the write actually happens asynchronously. To avoid running out of memory by putting too much on the write queue, check the WriteStream.writeQueueFull() method before writing. This is done automatically if using a .

        When the data is moved from the queue to the actual medium, the returned will be completed with the write result, e.g the future is succeeded when a server HTTP response buffer is written to the socket and failed if the remote client has closed the socket while the data was still pending for write.

        Specified by:
        rxWrite in interface WriteStream<Req>
        Overrides:
        rxWrite in class GrpcWriteStream<Resp>
        Parameters:
        data - the data to write
        Returns:
        a future completed with the write result
      • end

        public io.reactivex.rxjava3.core.Completable end()
        Ends the stream.

        Once the stream has ended, it cannot be used any more.

        Specified by:
        end in interface WriteStream<Req>
        Overrides:
        end in class GrpcWriteStream<Resp>
        Returns:
        a future completed with the result
      • rxEnd

        public io.reactivex.rxjava3.core.Completable rxEnd()
        Ends the stream.

        Once the stream has ended, it cannot be used any more.

        Specified by:
        rxEnd in interface WriteStream<Req>
        Overrides:
        rxEnd in class GrpcWriteStream<Resp>
        Returns:
        a future completed with the result
      • end

        public io.reactivex.rxjava3.core.Completable end​(Resp data)
        Same as WriteStream.end() but writes some data to the stream before ending.
        Specified by:
        end in interface WriteStream<Req>
        Overrides:
        end in class GrpcWriteStream<Resp>
        Parameters:
        data - the data to write
        Returns:
        a future completed with the result
      • rxEnd

        public io.reactivex.rxjava3.core.Completable rxEnd​(Resp data)
        Same as WriteStream.end() but writes some data to the stream before ending.
        Specified by:
        rxEnd in interface WriteStream<Req>
        Overrides:
        rxEnd in class GrpcWriteStream<Resp>
        Parameters:
        data - the data to write
        Returns:
        a future completed with the result
      • status

        public GrpcServerResponse<Req,​Resp> status​(GrpcStatus status)
        Set the grpc status response
        Parameters:
        status - the status
        Returns:
        a reference to this, so the API can be used fluently
      • statusMessage

        public GrpcServerResponse<Req,​Resp> statusMessage​(String msg)
        Set the grpc status response message
        Parameters:
        msg - the message
        Returns:
        a reference to this, so the API can be used fluently
      • encoding

        public GrpcServerResponse<Req,​Resp> encoding​(String encoding)
        Description copied from class: GrpcWriteStream

        Set the stream encoding, e.g. identity or gzip,

        • The encoding must be set before sending any message, otherwise identity will be used.
        • The encoding should also match the opposite endpoint expectations.
        Overrides:
        encoding in class GrpcWriteStream<Resp>
        Parameters:
        encoding - the target message encoding
        Returns:
        a reference to this, so the API can be used fluently
      • format

        public GrpcServerResponse<Req,​Resp> format​(WireFormat format)
        Description copied from class: GrpcWriteStream
        Set the stream format, e.g. proto or json. It must be called before sending any message, otherwise proto will be used.
        Overrides:
        format in class GrpcWriteStream<Resp>
        Parameters:
        format - the message format
        Returns:
        a reference to this, so the API can be used fluently
      • acceptedEncodings

        public Set<String> acceptedEncodings()
        Returns:
        the set of accepted encodings sent by the client, note that identity should not be part of this set. This can be used to set the response #encoding(String) encoding to ensure the client will accept the encoding. This is a glorified wrapper for the grpc-accept-encoding header.
      • trailers

        public MultiMap trailers()
        Returns:
        the to write metadata trailers
      • setWriteQueueMaxSize

        public GrpcServerResponse<Req,​Resp> setWriteQueueMaxSize​(int maxSize)
        Description copied from interface: WriteStream
        Set the maximum size of the write queue to maxSize. You will still be able to write to the stream even if there is more than maxSize items in the write queue. This is used as an indicator by classes such as Pipe to provide flow control.

        The value is defined by the implementation of the stream, e.g in bytes for a NetSocket, etc...

        Specified by:
        setWriteQueueMaxSize in interface WriteStream<Req>
        Overrides:
        setWriteQueueMaxSize in class GrpcWriteStream<Resp>
        Parameters:
        maxSize - the max size of the write stream
        Returns:
        a reference to this, so the API can be used fluently
      • drainHandler

        public GrpcServerResponse<Req,​Resp> drainHandler​(Handler<Void> handler)
        Description copied from interface: WriteStream
        Set a drain handler on the stream. If the write queue is full, then the handler will be called when the write queue is ready to accept buffers again. See Pipe for an example of this being used.

        The stream implementation defines when the drain handler, for example it could be when the queue size has been reduced to maxSize / 2.

        Specified by:
        drainHandler in interface WriteStream<Req>
        Overrides:
        drainHandler in class GrpcWriteStream<Resp>
        Parameters:
        handler - the handler
        Returns:
        a reference to this, so the API can be used fluently
      • writeHead

        public io.reactivex.rxjava3.core.Completable writeHead()
        Send the response headers.
        Returns:
        a future notified by the success or failure of the write
      • rxWriteHead

        public io.reactivex.rxjava3.core.Completable rxWriteHead()
        Send the response headers.
        Returns:
        a future notified by the success or failure of the write
      • send

        public io.reactivex.rxjava3.core.Completable send​(Resp item)
      • rxSend

        public io.reactivex.rxjava3.core.Completable rxSend​(Resp item)
      • send

        public io.reactivex.rxjava3.core.Completable send​(io.reactivex.rxjava3.core.Flowable<Resp> body)
      • rxSend

        public io.reactivex.rxjava3.core.Completable rxSend​(io.reactivex.rxjava3.core.Flowable<Resp> body)