Package io.vertx.rxjava3.httpproxy
Class ProxyInterceptor
java.lang.Object
io.vertx.rxjava3.httpproxy.ProxyInterceptor
- All Implemented Interfaces:
RxDelegate
-
Field Summary
Fields -
Constructor Summary
ConstructorsConstructorDescriptionProxyInterceptor(ProxyInterceptor delegate) ProxyInterceptor(Object delegate) -
Method Summary
Modifier and TypeMethodDescriptionstatic ProxyInterceptorBuilderbuilder()Create a builder for implementing common HTTP interception hooks such as modifying headers or transforming the HTTP entity stream.booleanio.reactivex.rxjava3.core.Single<ProxyResponse>handleProxyRequest(ProxyContext context) Handle the proxy request at the stage of this interceptor.io.reactivex.rxjava3.core.CompletablehandleProxyResponse(ProxyContext context) Handle the proxy response at the stage of this interceptor.inthashCode()static ProxyInterceptorio.reactivex.rxjava3.core.Single<ProxyResponse>rxHandleProxyRequest(ProxyContext context) Handle the proxy request at the stage of this interceptor.io.reactivex.rxjava3.core.CompletablerxHandleProxyResponse(ProxyContext context) Handle the proxy response at the stage of this interceptor.toString()
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
ProxyInterceptor
-
ProxyInterceptor
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
builder
Create a builder for implementing common HTTP interception hooks such as modifying headers or transforming the HTTP entity stream.- Returns:
- a builder for common interception
-
handleProxyRequest
Handle the proxy request at the stage of this interceptor.- Parameters:
context- the proxy context- Returns:
- when the request has actually been sent to the origin
-
rxHandleProxyRequest
Handle the proxy request at the stage of this interceptor.- Parameters:
context- the proxy context- Returns:
- when the request has actually been sent to the origin
-
handleProxyResponse
Handle the proxy response at the stage of this interceptor.- Parameters:
context- the proxy context- Returns:
- when the response has actually been sent to the user-agent
-
rxHandleProxyResponse
Handle the proxy response at the stage of this interceptor.- Parameters:
context- the proxy context- Returns:
- when the response has actually been sent to the user-agent
-
newInstance
-