Package io.vertx.rxjava3.httpproxy
Class ProxyInterceptor
- java.lang.Object
-
- io.vertx.rxjava3.httpproxy.ProxyInterceptor
-
- All Implemented Interfaces:
RxDelegate
public class ProxyInterceptor extends Object implements RxDelegate
-
-
Field Summary
Fields Modifier and Type Field Description static TypeArg<ProxyInterceptor>__TYPE_ARG
-
Constructor Summary
Constructors Constructor Description ProxyInterceptor(ProxyInterceptor delegate)ProxyInterceptor(Object delegate)
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static ProxyInterceptorBuilderbuilder()Create a builder for implementing common HTTP interception hooks such as modifying headers or transforming the HTTP entity stream.booleanequals(Object o)ProxyInterceptorgetDelegate()io.reactivex.rxjava3.core.Single<ProxyResponse>handleProxyRequest(ProxyContext context)Handle the proxy request at the stage of this interceptor.io.reactivex.rxjava3.core.CompletablehandleProxyResponse(ProxyContext context)Handle the proxy response at the stage of this interceptor.inthashCode()static ProxyInterceptornewInstance(ProxyInterceptor arg)io.reactivex.rxjava3.core.Single<ProxyResponse>rxHandleProxyRequest(ProxyContext context)Handle the proxy request at the stage of this interceptor.io.reactivex.rxjava3.core.CompletablerxHandleProxyResponse(ProxyContext context)Handle the proxy response at the stage of this interceptor.StringtoString()
-
-
-
Field Detail
-
__TYPE_ARG
public static final TypeArg<ProxyInterceptor> __TYPE_ARG
-
-
Constructor Detail
-
ProxyInterceptor
public ProxyInterceptor(ProxyInterceptor delegate)
-
ProxyInterceptor
public ProxyInterceptor(Object delegate)
-
-
Method Detail
-
getDelegate
public ProxyInterceptor getDelegate()
- Specified by:
getDelegatein interfaceRxDelegate
-
builder
public static ProxyInterceptorBuilder builder()
Create a builder for implementing common HTTP interception hooks such as modifying headers or transforming the HTTP entity stream.- Returns:
- a builder for common interception
-
handleProxyRequest
public io.reactivex.rxjava3.core.Single<ProxyResponse> handleProxyRequest(ProxyContext context)
Handle the proxy request at the stage of this interceptor.- Parameters:
context- the proxy context- Returns:
- when the request has actually been sent to the origin
-
rxHandleProxyRequest
public io.reactivex.rxjava3.core.Single<ProxyResponse> rxHandleProxyRequest(ProxyContext context)
Handle the proxy request at the stage of this interceptor.- Parameters:
context- the proxy context- Returns:
- when the request has actually been sent to the origin
-
handleProxyResponse
public io.reactivex.rxjava3.core.Completable handleProxyResponse(ProxyContext context)
Handle the proxy response at the stage of this interceptor.- Parameters:
context- the proxy context- Returns:
- when the response has actually been sent to the user-agent
-
rxHandleProxyResponse
public io.reactivex.rxjava3.core.Completable rxHandleProxyResponse(ProxyContext context)
Handle the proxy response at the stage of this interceptor.- Parameters:
context- the proxy context- Returns:
- when the response has actually been sent to the user-agent
-
newInstance
public static ProxyInterceptor newInstance(ProxyInterceptor arg)
-
-