Uses of Class
io.vertx.rxjava3.httpproxy.ProxyContext
-
Packages that use ProxyContext Package Description io.vertx.rxjava3.httpproxy -
-
Uses of ProxyContext in io.vertx.rxjava3.httpproxy
Fields in io.vertx.rxjava3.httpproxy with type parameters of type ProxyContext Modifier and Type Field Description static TypeArg<ProxyContext>ProxyContext. __TYPE_ARGMethods in io.vertx.rxjava3.httpproxy that return ProxyContext Modifier and Type Method Description static ProxyContextProxyContext. newInstance(ProxyContext arg)Methods in io.vertx.rxjava3.httpproxy with parameters of type ProxyContext Modifier and Type Method Description io.reactivex.rxjava3.core.Single<HttpClientRequest>OriginRequestProvider. create(ProxyContext proxyContext)Create the to the origin server for a givenProxyContext.io.reactivex.rxjava3.core.Single<ProxyResponse>ProxyInterceptor. handleProxyRequest(ProxyContext context)Handle the proxy request at the stage of this interceptor.io.reactivex.rxjava3.core.CompletableProxyInterceptor. handleProxyResponse(ProxyContext context)Handle the proxy response at the stage of this interceptor.io.reactivex.rxjava3.core.Single<HttpClientRequest>OriginRequestProvider. rxCreate(ProxyContext proxyContext)Create the to the origin server for a givenProxyContext.io.reactivex.rxjava3.core.Single<ProxyResponse>ProxyInterceptor. rxHandleProxyRequest(ProxyContext context)Handle the proxy request at the stage of this interceptor.io.reactivex.rxjava3.core.CompletableProxyInterceptor. rxHandleProxyResponse(ProxyContext context)Handle the proxy response at the stage of this interceptor.Method parameters in io.vertx.rxjava3.httpproxy with type arguments of type ProxyContext Modifier and Type Method Description static OriginRequestProviderOriginRequestProvider. selector(Function<ProxyContext,io.reactivex.rxjava3.core.Single<SocketAddress>> selector)Creates a provider that selects the origin server based onProxyContext.
-