Class SecurityRequirement
java.lang.Object
io.vertx.rxjava3.openapi.contract.SecurityRequirement
- All Implemented Interfaces:
RxDelegate
A Security requirement is an object that contains the names of the security schemes that apply to the operation.
Each name has a list of scopes that apply to the operation.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
ConstructorsConstructorDescriptionSecurityRequirement(SecurityRequirement delegate) SecurityRequirement(Object delegate) -
Method Summary
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
SecurityRequirement
-
SecurityRequirement
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
size
public int size()How many requirements are present- Returns:
- size
-
getNames
Return the name at a given index- Returns:
- name
-
getScopes
Return the scopes for a given name- Parameters:
name-- Returns:
- name
-
isEmpty
public boolean isEmpty() -
newInstance
-