Package io.vertx.rxjava3.rabbitmq
Class RabbitMQClient
java.lang.Object
io.vertx.rxjava3.rabbitmq.RabbitMQClient
- All Implemented Interfaces:
RxDelegate
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionio.reactivex.rxjava3.core.Flowable<RabbitMQConfirmation>addConfirmListener(int maxQueueSize) Add a Confirm Listener to the channel.io.reactivex.rxjava3.core.CompletablebasicAck(long deliveryTag, boolean multiple) Acknowledge one or several received messages.io.reactivex.rxjava3.core.Single<RabbitMQConsumer>basicConsumer(String queue) io.reactivex.rxjava3.core.Single<RabbitMQConsumer>basicConsumer(String queue, QueueOptions options) Create a consumer with the givenoptions.io.reactivex.rxjava3.core.Single<RabbitMQMessage>Retrieve a message from a queue using AMQP.Basic.Getio.reactivex.rxjava3.core.CompletablebasicNack(long deliveryTag, boolean multiple, boolean requeue) Reject one or several received messages.io.reactivex.rxjava3.core.CompletablebasicPublish(String exchange, String routingKey, com.rabbitmq.client.BasicProperties properties, Buffer body) Publish a message.io.reactivex.rxjava3.core.CompletablebasicPublish(String exchange, String routingKey, Buffer body) Publish a message.io.reactivex.rxjava3.core.CompletablebasicPublishWithDeliveryTag(String exchange, String routingKey, com.rabbitmq.client.BasicProperties properties, Buffer body, Handler<Long> deliveryTagHandler) Publish a message.io.reactivex.rxjava3.core.CompletablebasicQos(int prefetchCount) Request a specific prefetchCount "quality of service" settings for this channel.io.reactivex.rxjava3.core.CompletablebasicQos(int prefetchCount, boolean global) Request a specific prefetchCount "quality of service" settings for this channel.io.reactivex.rxjava3.core.CompletablebasicQos(int prefetchSize, int prefetchCount, boolean global) Request specific "quality of service" settings.io.reactivex.rxjava3.core.CompletableEnables publisher acknowledgements on this channel.static RabbitMQClientcreate(io.vertx.rxjava3.core.Vertx vertx) Create and return a client configured with the default options.static RabbitMQClientcreate(io.vertx.rxjava3.core.Vertx vertx, RabbitMQOptions config) Create and return a client.booleanio.reactivex.rxjava3.core.CompletableexchangeBind(String destination, String source, String routingKey) Bind an exchange to an exchange.io.reactivex.rxjava3.core.CompletableBind an exchange to an exchange.io.reactivex.rxjava3.core.CompletableexchangeDeclare(String exchange, String type, boolean durable, boolean autoDelete) Declare an exchange.io.reactivex.rxjava3.core.CompletableexchangeDeclare(String exchange, String type, boolean durable, boolean autoDelete, JsonObject config) Declare an exchange with additional parameters such as dead lettering, an alternate exchange or TTL.io.reactivex.rxjava3.core.CompletableexchangeDelete(String exchange) Delete an exchange, without regard for whether it is in use or not.io.reactivex.rxjava3.core.CompletableexchangeUnbind(String destination, String source, String routingKey) Unbind an exchange from an exchange.io.reactivex.rxjava3.core.CompletableUnbind an exchange from an exchange.inthashCode()booleanCheck if a connection is openbooleanCheck if a channel is openio.reactivex.rxjava3.core.Single<Long>messageCount(String queue) Returns the number of messages in a queue ready to be delivered.static RabbitMQClientio.reactivex.rxjava3.core.CompletableBind a queue to an exchangeio.reactivex.rxjava3.core.CompletableBind a queue to an exchangeio.reactivex.rxjava3.core.Single<com.rabbitmq.client.AMQP.Queue.DeclareOk>queueDeclare(String queue, boolean durable, boolean exclusive, boolean autoDelete) Declare a queueio.reactivex.rxjava3.core.Single<com.rabbitmq.client.AMQP.Queue.DeclareOk>queueDeclare(String queue, boolean durable, boolean exclusive, boolean autoDelete, JsonObject config) Declare a queue with config optionsio.reactivex.rxjava3.core.Single<JsonObject>Actively declare a server-named exclusive, autodelete, non-durable queue.io.reactivex.rxjava3.core.Single<com.rabbitmq.client.AMQP.Queue.DeleteOk>queueDelete(String queue) Delete a queue, without regard for whether it is in use or has messages on itio.reactivex.rxjava3.core.Single<com.rabbitmq.client.AMQP.Queue.DeleteOk>queueDeleteIf(String queue, boolean ifUnused, boolean ifEmpty) Delete a queueio.reactivex.rxjava3.core.CompletablequeueUnbind(String queue, String exchange, String routingKey) Unbind a queue from an exchangeio.reactivex.rxjava3.core.CompletableUnbind a queue from an exchangeio.reactivex.rxjava3.core.CompletablerestartConnect(int attempts) restart the rabbitMQ connect.io.reactivex.rxjava3.core.Flowable<RabbitMQConfirmation>rxAddConfirmListener(int maxQueueSize) Add a Confirm Listener to the channel.io.reactivex.rxjava3.core.CompletablerxBasicAck(long deliveryTag, boolean multiple) Acknowledge one or several received messages.io.reactivex.rxjava3.core.Single<RabbitMQConsumer>rxBasicConsumer(String queue) io.reactivex.rxjava3.core.Single<RabbitMQConsumer>rxBasicConsumer(String queue, QueueOptions options) Create a consumer with the givenoptions.io.reactivex.rxjava3.core.Single<RabbitMQMessage>rxBasicGet(String queue, boolean autoAck) Retrieve a message from a queue using AMQP.Basic.Getio.reactivex.rxjava3.core.CompletablerxBasicNack(long deliveryTag, boolean multiple, boolean requeue) Reject one or several received messages.io.reactivex.rxjava3.core.CompletablerxBasicPublish(String exchange, String routingKey, com.rabbitmq.client.BasicProperties properties, Buffer body) Publish a message.io.reactivex.rxjava3.core.CompletablerxBasicPublish(String exchange, String routingKey, Buffer body) Publish a message.io.reactivex.rxjava3.core.CompletablerxBasicPublishWithDeliveryTag(String exchange, String routingKey, com.rabbitmq.client.BasicProperties properties, Buffer body, Handler<Long> deliveryTagHandler) Publish a message.io.reactivex.rxjava3.core.CompletablerxBasicQos(int prefetchCount) Request a specific prefetchCount "quality of service" settings for this channel.io.reactivex.rxjava3.core.CompletablerxBasicQos(int prefetchCount, boolean global) Request a specific prefetchCount "quality of service" settings for this channel.io.reactivex.rxjava3.core.CompletablerxBasicQos(int prefetchSize, int prefetchCount, boolean global) Request specific "quality of service" settings.io.reactivex.rxjava3.core.CompletableEnables publisher acknowledgements on this channel.io.reactivex.rxjava3.core.CompletablerxExchangeBind(String destination, String source, String routingKey) Bind an exchange to an exchange.io.reactivex.rxjava3.core.CompletableBind an exchange to an exchange.io.reactivex.rxjava3.core.CompletablerxExchangeDeclare(String exchange, String type, boolean durable, boolean autoDelete) Declare an exchange.io.reactivex.rxjava3.core.CompletablerxExchangeDeclare(String exchange, String type, boolean durable, boolean autoDelete, JsonObject config) Declare an exchange with additional parameters such as dead lettering, an alternate exchange or TTL.io.reactivex.rxjava3.core.CompletablerxExchangeDelete(String exchange) Delete an exchange, without regard for whether it is in use or not.io.reactivex.rxjava3.core.CompletablerxExchangeUnbind(String destination, String source, String routingKey) Unbind an exchange from an exchange.io.reactivex.rxjava3.core.CompletablerxExchangeUnbind(String destination, String source, String routingKey, Map<String, Object> arguments) Unbind an exchange from an exchange.io.reactivex.rxjava3.core.Single<Long>rxMessageCount(String queue) Returns the number of messages in a queue ready to be delivered.io.reactivex.rxjava3.core.CompletablerxQueueBind(String queue, String exchange, String routingKey) Bind a queue to an exchangeio.reactivex.rxjava3.core.CompletableBind a queue to an exchangeio.reactivex.rxjava3.core.Single<com.rabbitmq.client.AMQP.Queue.DeclareOk>rxQueueDeclare(String queue, boolean durable, boolean exclusive, boolean autoDelete) Declare a queueio.reactivex.rxjava3.core.Single<com.rabbitmq.client.AMQP.Queue.DeclareOk>rxQueueDeclare(String queue, boolean durable, boolean exclusive, boolean autoDelete, JsonObject config) Declare a queue with config optionsio.reactivex.rxjava3.core.Single<JsonObject>Actively declare a server-named exclusive, autodelete, non-durable queue.io.reactivex.rxjava3.core.Single<com.rabbitmq.client.AMQP.Queue.DeleteOk>rxQueueDelete(String queue) Delete a queue, without regard for whether it is in use or has messages on itio.reactivex.rxjava3.core.Single<com.rabbitmq.client.AMQP.Queue.DeleteOk>rxQueueDeleteIf(String queue, boolean ifUnused, boolean ifEmpty) Delete a queueio.reactivex.rxjava3.core.CompletablerxQueueUnbind(String queue, String exchange, String routingKey) Unbind a queue from an exchangeio.reactivex.rxjava3.core.CompletableUnbind a queue from an exchangeio.reactivex.rxjava3.core.CompletablerxRestartConnect(int attempts) restart the rabbitMQ connect.io.reactivex.rxjava3.core.CompletablerxStart()Start the rabbitMQ client.io.reactivex.rxjava3.core.CompletablerxStop()Stop the rabbitMQ client.io.reactivex.rxjava3.core.CompletableWait until all messages published since the last call have been either ack'd or nack'd by the broker.io.reactivex.rxjava3.core.CompletablerxWaitForConfirms(long timeout) Wait until all messages published since the last call have been either ack'd or nack'd by the broker; or until timeout elapses.io.reactivex.rxjava3.core.Completablestart()Start the rabbitMQ client.io.reactivex.rxjava3.core.Completablestop()Stop the rabbitMQ client.toString()io.reactivex.rxjava3.core.CompletableWait until all messages published since the last call have been either ack'd or nack'd by the broker.io.reactivex.rxjava3.core.CompletablewaitForConfirms(long timeout) Wait until all messages published since the last call have been either ack'd or nack'd by the broker; or until timeout elapses.
-
Field Details
-
__TYPE_ARG
-
-
Constructor Details
-
RabbitMQClient
-
RabbitMQClient
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
create
Create and return a client configured with the default options.- Parameters:
vertx- the vertx instance- Returns:
- the client
-
create
Create and return a client.- Parameters:
vertx- the vertx instanceconfig- the client config- Returns:
- the client
-
basicAck
public io.reactivex.rxjava3.core.Completable basicAck(long deliveryTag, boolean multiple) Acknowledge one or several received messages. Supply the deliveryTag from the AMQP.Basic.GetOk or AMQP.Basic.Deliver method containing the received message being acknowledged.- Parameters:
deliveryTag-multiple-- Returns:
-
rxBasicAck
public io.reactivex.rxjava3.core.Completable rxBasicAck(long deliveryTag, boolean multiple) Acknowledge one or several received messages. Supply the deliveryTag from the AMQP.Basic.GetOk or AMQP.Basic.Deliver method containing the received message being acknowledged.- Parameters:
deliveryTag-multiple-- Returns:
-
basicNack
public io.reactivex.rxjava3.core.Completable basicNack(long deliveryTag, boolean multiple, boolean requeue) Reject one or several received messages.- Parameters:
deliveryTag-multiple-requeue-- Returns:
-
rxBasicNack
public io.reactivex.rxjava3.core.Completable rxBasicNack(long deliveryTag, boolean multiple, boolean requeue) Reject one or several received messages.- Parameters:
deliveryTag-multiple-requeue-- Returns:
-
basicGet
Retrieve a message from a queue using AMQP.Basic.Get- Parameters:
queue-autoAck-- Returns:
-
rxBasicGet
Retrieve a message from a queue using AMQP.Basic.Get- Parameters:
queue-autoAck-- Returns:
-
basicConsumer
- Parameters:
queue-- Returns:
-
rxBasicConsumer
- Parameters:
queue-- Returns:
-
basicConsumer
public io.reactivex.rxjava3.core.Single<RabbitMQConsumer> basicConsumer(String queue, QueueOptions options) Create a consumer with the givenoptions.- Parameters:
queue- the name of a queueoptions- options for queue- Returns:
- a future completed with the operation status; if the operation succeeds you can begin to receive messages through an instance of
RabbitMQConsumer
-
rxBasicConsumer
public io.reactivex.rxjava3.core.Single<RabbitMQConsumer> rxBasicConsumer(String queue, QueueOptions options) Create a consumer with the givenoptions.- Parameters:
queue- the name of a queueoptions- options for queue- Returns:
- a future completed with the operation status; if the operation succeeds you can begin to receive messages through an instance of
RabbitMQConsumer
-
basicPublish
public io.reactivex.rxjava3.core.Completable basicPublish(String exchange, String routingKey, Buffer body) Publish a message. Publishing to a non-existent exchange will result in a channel-level protocol exception, which closes the channel. Invocations of Channel#basicPublish will eventually block if a resource-driven alarm is in effect.- Parameters:
exchange-routingKey-body-- Returns:
-
rxBasicPublish
public io.reactivex.rxjava3.core.Completable rxBasicPublish(String exchange, String routingKey, Buffer body) Publish a message. Publishing to a non-existent exchange will result in a channel-level protocol exception, which closes the channel. Invocations of Channel#basicPublish will eventually block if a resource-driven alarm is in effect.- Parameters:
exchange-routingKey-body-- Returns:
-
addConfirmListener
public io.reactivex.rxjava3.core.Flowable<RabbitMQConfirmation> addConfirmListener(int maxQueueSize) Add a Confirm Listener to the channel. Note that this will automatically call confirmSelect, it is not necessary to call that too.- Parameters:
maxQueueSize- maximum size of the queue of confirmations- Returns:
- a future completed with a stream of confirmations if the operation succeeds
-
rxAddConfirmListener
public io.reactivex.rxjava3.core.Flowable<RabbitMQConfirmation> rxAddConfirmListener(int maxQueueSize) Add a Confirm Listener to the channel. Note that this will automatically call confirmSelect, it is not necessary to call that too.- Parameters:
maxQueueSize- maximum size of the queue of confirmations- Returns:
- a future completed with a stream of confirmations if the operation succeeds
-
confirmSelect
public io.reactivex.rxjava3.core.Completable confirmSelect()Enables publisher acknowledgements on this channel. Can be called once during client initialisation. Calls to basicPublish() will have to be confirmed.- Returns:
-
rxConfirmSelect
public io.reactivex.rxjava3.core.Completable rxConfirmSelect()Enables publisher acknowledgements on this channel. Can be called once during client initialisation. Calls to basicPublish() will have to be confirmed.- Returns:
-
waitForConfirms
public io.reactivex.rxjava3.core.Completable waitForConfirms()Wait until all messages published since the last call have been either ack'd or nack'd by the broker. This will incur slight performance loss at the expense of higher write consistency. If desired, multiple calls to basicPublish() can be batched before confirming.- Returns:
-
rxWaitForConfirms
public io.reactivex.rxjava3.core.Completable rxWaitForConfirms()Wait until all messages published since the last call have been either ack'd or nack'd by the broker. This will incur slight performance loss at the expense of higher write consistency. If desired, multiple calls to basicPublish() can be batched before confirming.- Returns:
-
waitForConfirms
public io.reactivex.rxjava3.core.Completable waitForConfirms(long timeout) Wait until all messages published since the last call have been either ack'd or nack'd by the broker; or until timeout elapses. If the timeout expires a TimeoutException is thrown.- Parameters:
timeout-- Returns:
-
rxWaitForConfirms
public io.reactivex.rxjava3.core.Completable rxWaitForConfirms(long timeout) Wait until all messages published since the last call have been either ack'd or nack'd by the broker; or until timeout elapses. If the timeout expires a TimeoutException is thrown.- Parameters:
timeout-- Returns:
-
basicQos
public io.reactivex.rxjava3.core.Completable basicQos(int prefetchCount) Request a specific prefetchCount "quality of service" settings for this channel.- Parameters:
prefetchCount- maximum number of messages that the server will deliver, 0 if unlimited- Returns:
-
rxBasicQos
public io.reactivex.rxjava3.core.Completable rxBasicQos(int prefetchCount) Request a specific prefetchCount "quality of service" settings for this channel.- Parameters:
prefetchCount- maximum number of messages that the server will deliver, 0 if unlimited- Returns:
-
basicQos
public io.reactivex.rxjava3.core.Completable basicQos(int prefetchCount, boolean global) Request a specific prefetchCount "quality of service" settings for this channel.- Parameters:
prefetchCount- maximum number of messages that the server will deliver, 0 if unlimitedglobal- true if the settings should be applied to the entire channel rather than each consumer- Returns:
-
rxBasicQos
public io.reactivex.rxjava3.core.Completable rxBasicQos(int prefetchCount, boolean global) Request a specific prefetchCount "quality of service" settings for this channel.- Parameters:
prefetchCount- maximum number of messages that the server will deliver, 0 if unlimitedglobal- true if the settings should be applied to the entire channel rather than each consumer- Returns:
-
basicQos
public io.reactivex.rxjava3.core.Completable basicQos(int prefetchSize, int prefetchCount, boolean global) Request specific "quality of service" settings. These settings impose limits on the amount of data the server will deliver to consumers before requiring acknowledgements. Thus they provide a means of consumer-initiated flow control.- Parameters:
prefetchSize- maximum amount of content (measured in octets) that the server will deliver, 0 if unlimitedprefetchCount- maximum number of messages that the server will deliver, 0 if unlimitedglobal- true if the settings should be applied to the entire channel rather than each consumer- Returns:
-
rxBasicQos
public io.reactivex.rxjava3.core.Completable rxBasicQos(int prefetchSize, int prefetchCount, boolean global) Request specific "quality of service" settings. These settings impose limits on the amount of data the server will deliver to consumers before requiring acknowledgements. Thus they provide a means of consumer-initiated flow control.- Parameters:
prefetchSize- maximum amount of content (measured in octets) that the server will deliver, 0 if unlimitedprefetchCount- maximum number of messages that the server will deliver, 0 if unlimitedglobal- true if the settings should be applied to the entire channel rather than each consumer- Returns:
-
exchangeDeclare
public io.reactivex.rxjava3.core.Completable exchangeDeclare(String exchange, String type, boolean durable, boolean autoDelete) Declare an exchange.- Parameters:
exchange-type-durable-autoDelete-- Returns:
-
rxExchangeDeclare
public io.reactivex.rxjava3.core.Completable rxExchangeDeclare(String exchange, String type, boolean durable, boolean autoDelete) Declare an exchange.- Parameters:
exchange-type-durable-autoDelete-- Returns:
-
exchangeDeclare
public io.reactivex.rxjava3.core.Completable exchangeDeclare(String exchange, String type, boolean durable, boolean autoDelete, JsonObject config) Declare an exchange with additional parameters such as dead lettering, an alternate exchange or TTL.- Parameters:
exchange-type-durable-autoDelete-config-- Returns:
-
rxExchangeDeclare
public io.reactivex.rxjava3.core.Completable rxExchangeDeclare(String exchange, String type, boolean durable, boolean autoDelete, JsonObject config) Declare an exchange with additional parameters such as dead lettering, an alternate exchange or TTL.- Parameters:
exchange-type-durable-autoDelete-config-- Returns:
-
exchangeDelete
Delete an exchange, without regard for whether it is in use or not.- Parameters:
exchange-- Returns:
-
rxExchangeDelete
Delete an exchange, without regard for whether it is in use or not.- Parameters:
exchange-- Returns:
-
exchangeBind
public io.reactivex.rxjava3.core.Completable exchangeBind(String destination, String source, String routingKey) Bind an exchange to an exchange.- Parameters:
destination-source-routingKey-- Returns:
-
rxExchangeBind
public io.reactivex.rxjava3.core.Completable rxExchangeBind(String destination, String source, String routingKey) Bind an exchange to an exchange.- Parameters:
destination-source-routingKey-- Returns:
-
exchangeBind
public io.reactivex.rxjava3.core.Completable exchangeBind(String destination, String source, String routingKey, Map<String, Object> arguments) Bind an exchange to an exchange.- Parameters:
destination-source-routingKey-arguments-- Returns:
-
rxExchangeBind
public io.reactivex.rxjava3.core.Completable rxExchangeBind(String destination, String source, String routingKey, Map<String, Object> arguments) Bind an exchange to an exchange.- Parameters:
destination-source-routingKey-arguments-- Returns:
-
exchangeUnbind
public io.reactivex.rxjava3.core.Completable exchangeUnbind(String destination, String source, String routingKey) Unbind an exchange from an exchange.- Parameters:
destination-source-routingKey-- Returns:
-
rxExchangeUnbind
public io.reactivex.rxjava3.core.Completable rxExchangeUnbind(String destination, String source, String routingKey) Unbind an exchange from an exchange.- Parameters:
destination-source-routingKey-- Returns:
-
exchangeUnbind
public io.reactivex.rxjava3.core.Completable exchangeUnbind(String destination, String source, String routingKey, Map<String, Object> arguments) Unbind an exchange from an exchange.- Parameters:
destination-source-routingKey-arguments-- Returns:
-
rxExchangeUnbind
public io.reactivex.rxjava3.core.Completable rxExchangeUnbind(String destination, String source, String routingKey, Map<String, Object> arguments) Unbind an exchange from an exchange.- Parameters:
destination-source-routingKey-arguments-- Returns:
-
queueDeclareAuto
Actively declare a server-named exclusive, autodelete, non-durable queue.- Returns:
-
rxQueueDeclareAuto
Actively declare a server-named exclusive, autodelete, non-durable queue.- Returns:
-
queueBind
public io.reactivex.rxjava3.core.Completable queueBind(String queue, String exchange, String routingKey) Bind a queue to an exchange- Parameters:
queue-exchange-routingKey-- Returns:
-
rxQueueBind
public io.reactivex.rxjava3.core.Completable rxQueueBind(String queue, String exchange, String routingKey) Bind a queue to an exchange- Parameters:
queue-exchange-routingKey-- Returns:
-
queueBind
public io.reactivex.rxjava3.core.Completable queueBind(String queue, String exchange, String routingKey, Map<String, Object> arguments) Bind a queue to an exchange- Parameters:
queue-exchange-routingKey-arguments-- Returns:
-
rxQueueBind
public io.reactivex.rxjava3.core.Completable rxQueueBind(String queue, String exchange, String routingKey, Map<String, Object> arguments) Bind a queue to an exchange- Parameters:
queue-exchange-routingKey-arguments-- Returns:
-
queueUnbind
public io.reactivex.rxjava3.core.Completable queueUnbind(String queue, String exchange, String routingKey) Unbind a queue from an exchange- Parameters:
queue-exchange-routingKey-- Returns:
-
rxQueueUnbind
public io.reactivex.rxjava3.core.Completable rxQueueUnbind(String queue, String exchange, String routingKey) Unbind a queue from an exchange- Parameters:
queue-exchange-routingKey-- Returns:
-
queueUnbind
public io.reactivex.rxjava3.core.Completable queueUnbind(String queue, String exchange, String routingKey, Map<String, Object> arguments) Unbind a queue from an exchange- Parameters:
queue-exchange-routingKey-arguments-- Returns:
-
rxQueueUnbind
public io.reactivex.rxjava3.core.Completable rxQueueUnbind(String queue, String exchange, String routingKey, Map<String, Object> arguments) Unbind a queue from an exchange- Parameters:
queue-exchange-routingKey-arguments-- Returns:
-
messageCount
Returns the number of messages in a queue ready to be delivered.- Parameters:
queue-- Returns:
-
rxMessageCount
Returns the number of messages in a queue ready to be delivered.- Parameters:
queue-- Returns:
-
start
public io.reactivex.rxjava3.core.Completable start()Start the rabbitMQ client. Create the connection and the channel.- Returns:
-
rxStart
public io.reactivex.rxjava3.core.Completable rxStart()Start the rabbitMQ client. Create the connection and the channel.- Returns:
-
stop
public io.reactivex.rxjava3.core.Completable stop()Stop the rabbitMQ client. Close the connection and its channel.- Returns:
-
rxStop
public io.reactivex.rxjava3.core.Completable rxStop()Stop the rabbitMQ client. Close the connection and its channel.- Returns:
-
isConnected
public boolean isConnected()Check if a connection is open- Returns:
- true when the connection is open, false otherwise
-
restartConnect
public io.reactivex.rxjava3.core.Completable restartConnect(int attempts) restart the rabbitMQ connect.- Parameters:
attempts- number of attempts- Returns:
- a future notified when the operation is done with a result of the operation
-
rxRestartConnect
public io.reactivex.rxjava3.core.Completable rxRestartConnect(int attempts) restart the rabbitMQ connect.- Parameters:
attempts- number of attempts- Returns:
- a future notified when the operation is done with a result of the operation
-
isOpenChannel
public boolean isOpenChannel()Check if a channel is open- Returns:
- true when the connection is open, false otherwise
-
basicPublish
public io.reactivex.rxjava3.core.Completable basicPublish(String exchange, String routingKey, com.rabbitmq.client.BasicProperties properties, Buffer body) Publish a message. Publishing to a non-existent exchange will result in a channel-level protocol exception, which closes the channel. Invocations of Channel#basicPublish will eventually block if a resource-driven alarm is in effect.- Parameters:
exchange-routingKey-properties-body-- Returns:
-
rxBasicPublish
public io.reactivex.rxjava3.core.Completable rxBasicPublish(String exchange, String routingKey, com.rabbitmq.client.BasicProperties properties, Buffer body) Publish a message. Publishing to a non-existent exchange will result in a channel-level protocol exception, which closes the channel. Invocations of Channel#basicPublish will eventually block if a resource-driven alarm is in effect.- Parameters:
exchange-routingKey-properties-body-- Returns:
-
basicPublishWithDeliveryTag
public io.reactivex.rxjava3.core.Completable basicPublishWithDeliveryTag(String exchange, String routingKey, com.rabbitmq.client.BasicProperties properties, Buffer body, Handler<Long> deliveryTagHandler) Publish a message. Publishing to a non-existent exchange will result in a channel-level protocol exception, which closes the channel. Invocations of Channel#basicPublish will eventually block if a resource-driven alarm is in effect. The deliveryTagHandler will be called before the message is sent, which is necessary because the confirmation may arrive asynchronously before the resultHandler is called.- Parameters:
exchange-routingKey-properties-body-deliveryTagHandler- callback to capture the deliveryTag for this message. Note that this will be called synchronously in the context of the client before the result is known.- Returns:
-
rxBasicPublishWithDeliveryTag
public io.reactivex.rxjava3.core.Completable rxBasicPublishWithDeliveryTag(String exchange, String routingKey, com.rabbitmq.client.BasicProperties properties, Buffer body, Handler<Long> deliveryTagHandler) Publish a message. Publishing to a non-existent exchange will result in a channel-level protocol exception, which closes the channel. Invocations of Channel#basicPublish will eventually block if a resource-driven alarm is in effect. The deliveryTagHandler will be called before the message is sent, which is necessary because the confirmation may arrive asynchronously before the resultHandler is called.- Parameters:
exchange-routingKey-properties-body-deliveryTagHandler- callback to capture the deliveryTag for this message. Note that this will be called synchronously in the context of the client before the result is known.- Returns:
-
queueDeclare
public io.reactivex.rxjava3.core.Single<com.rabbitmq.client.AMQP.Queue.DeclareOk> queueDeclare(String queue, boolean durable, boolean exclusive, boolean autoDelete) Declare a queue- Parameters:
queue-durable-exclusive-autoDelete-- Returns:
-
rxQueueDeclare
public io.reactivex.rxjava3.core.Single<com.rabbitmq.client.AMQP.Queue.DeclareOk> rxQueueDeclare(String queue, boolean durable, boolean exclusive, boolean autoDelete) Declare a queue- Parameters:
queue-durable-exclusive-autoDelete-- Returns:
-
queueDeclare
public io.reactivex.rxjava3.core.Single<com.rabbitmq.client.AMQP.Queue.DeclareOk> queueDeclare(String queue, boolean durable, boolean exclusive, boolean autoDelete, JsonObject config) Declare a queue with config options- Parameters:
queue-durable-exclusive-autoDelete-config-- Returns:
-
rxQueueDeclare
public io.reactivex.rxjava3.core.Single<com.rabbitmq.client.AMQP.Queue.DeclareOk> rxQueueDeclare(String queue, boolean durable, boolean exclusive, boolean autoDelete, JsonObject config) Declare a queue with config options- Parameters:
queue-durable-exclusive-autoDelete-config-- Returns:
-
queueDelete
public io.reactivex.rxjava3.core.Single<com.rabbitmq.client.AMQP.Queue.DeleteOk> queueDelete(String queue) Delete a queue, without regard for whether it is in use or has messages on it- Parameters:
queue-- Returns:
-
rxQueueDelete
public io.reactivex.rxjava3.core.Single<com.rabbitmq.client.AMQP.Queue.DeleteOk> rxQueueDelete(String queue) Delete a queue, without regard for whether it is in use or has messages on it- Parameters:
queue-- Returns:
-
queueDeleteIf
public io.reactivex.rxjava3.core.Single<com.rabbitmq.client.AMQP.Queue.DeleteOk> queueDeleteIf(String queue, boolean ifUnused, boolean ifEmpty) Delete a queue- Parameters:
queue-ifUnused-ifEmpty-- Returns:
-
rxQueueDeleteIf
public io.reactivex.rxjava3.core.Single<com.rabbitmq.client.AMQP.Queue.DeleteOk> rxQueueDeleteIf(String queue, boolean ifUnused, boolean ifEmpty) Delete a queue- Parameters:
queue-ifUnused-ifEmpty-- Returns:
-
newInstance
-