Package io.vertx.rxjava3.sqlclient
Class PropertyKind<T>
java.lang.Object
io.vertx.rxjava3.sqlclient.PropertyKind<T>
- All Implemented Interfaces:
RxDelegate
The kind of the property, this can be used to fetch some specific property of the
execution result.
NOTE: This class has been automatically generated from the original non RX-ified interface using Vert.x codegen.
-
Field Summary
Fields -
Constructor Summary
ConstructorsConstructorDescriptionPropertyKind(PropertyKind delegate) PropertyKind(Object delegate, TypeArg<T> typeArg_0) -
Method Summary
Modifier and TypeMethodDescriptionstatic <T> PropertyKind<T>booleaninthashCode()name()static <T> PropertyKind<T>newInstance(PropertyKind arg) static <T> PropertyKind<T>newInstance(PropertyKind arg, TypeArg<T> __typeArg_T) toString()
-
Field Details
-
__TYPE_ARG
-
__typeArg_0
-
-
Constructor Details
-
PropertyKind
-
PropertyKind
-
-
Method Details
-
toString
-
equals
-
hashCode
public int hashCode() -
getDelegate
- Specified by:
getDelegatein interfaceRxDelegate
-
create
- Parameters:
name-type-- Returns:
- a property kind matching the provided
name, thetypecan be used to check the property value type or cast it to the expected type
-
name
- Returns:
- the property name
-
newInstance
-
newInstance
-