Package io.vertx.rxjava3.sqlclient
Class Transaction
- java.lang.Object
-
- io.vertx.rxjava3.sqlclient.Transaction
-
- All Implemented Interfaces:
RxDelegate
public class Transaction extends Object implements RxDelegate
A transaction.NOTE: This class has been automatically generated from the
originalnon RX-ified interface using Vert.x codegen.
-
-
Field Summary
Fields Modifier and Type Field Description static TypeArg<Transaction>__TYPE_ARG
-
Constructor Summary
Constructors Constructor Description Transaction(Transaction delegate)Transaction(Object delegate)
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description io.reactivex.rxjava3.core.Completablecommit()Commit the current transaction.io.reactivex.rxjava3.core.Completablecompletion()Return the transaction completionFuturethat succeeds when the transaction commits and fails withTransactionRollbackExceptionwhen the transaction rolls back.booleanequals(Object o)TransactiongetDelegate()inthashCode()static TransactionnewInstance(Transaction arg)io.reactivex.rxjava3.core.Completablerollback()Rollback the transaction and release the associated resources.io.reactivex.rxjava3.core.CompletablerxCommit()Commit the current transaction.io.reactivex.rxjava3.core.CompletablerxCompletion()Return the transaction completionFuturethat succeeds when the transaction commits and fails withTransactionRollbackExceptionwhen the transaction rolls back.io.reactivex.rxjava3.core.CompletablerxRollback()Rollback the transaction and release the associated resources.StringtoString()
-
-
-
Field Detail
-
__TYPE_ARG
public static final TypeArg<Transaction> __TYPE_ARG
-
-
Constructor Detail
-
Transaction
public Transaction(Transaction delegate)
-
Transaction
public Transaction(Object delegate)
-
-
Method Detail
-
getDelegate
public Transaction getDelegate()
- Specified by:
getDelegatein interfaceRxDelegate
-
commit
public io.reactivex.rxjava3.core.Completable commit()
Commit the current transaction.- Returns:
-
rxCommit
public io.reactivex.rxjava3.core.Completable rxCommit()
Commit the current transaction.- Returns:
-
rollback
public io.reactivex.rxjava3.core.Completable rollback()
Rollback the transaction and release the associated resources.- Returns:
-
rxRollback
public io.reactivex.rxjava3.core.Completable rxRollback()
Rollback the transaction and release the associated resources.- Returns:
-
completion
public io.reactivex.rxjava3.core.Completable completion()
Return the transaction completionFuturethat succeeds when the transaction commits and fails withTransactionRollbackExceptionwhen the transaction rolls back.- Returns:
- the transaction result
-
rxCompletion
public io.reactivex.rxjava3.core.Completable rxCompletion()
Return the transaction completionFuturethat succeeds when the transaction commits and fails withTransactionRollbackExceptionwhen the transaction rolls back.- Returns:
- the transaction result
-
newInstance
public static Transaction newInstance(Transaction arg)
-
-